--[[
	折扣商店
	wangming
	2017.4.26
]]
local DiscountShopLayer = class("DiscountShopLayer", function()
    local layer = cc.Sprite:create()
    layer:setContentSize( 720, 463 )
	return layer
end)

function DiscountShopLayer:create( params )
	return DiscountShopLayer.new( params )
end

function DiscountShopLayer:ctor( params )
    self._activityType = params.activityType
	self._size = self:getContentSize()
	self._buyRecords = params.buyRecords or {}
	local _tb = {}
	for k,v in pairs(params.table or {}) do
		table.insert(_tb, v)
	end
	self._status = _tb
	self:sortTb()

	self:initUI()
end

function DiscountShopLayer:sortTb()
	-- 李直说不需要排序
	do return end
	table.sort(self._status, function( a, b )
		local _timeA = tonumber(a.times) or 0
		local _timeB = tonumber(b.times) or 0
		local _numA = tonumber(self._buyRecords[tostring(a.id)]) or 0
		local _numB = tonumber(self._buyRecords[tostring(b.id)]) or 0
		_numA = _timeA - _numA
		_numB = _timeB - _numB
		if _numA ~= _numB then
			if _numA == 0 and _timeA ~= 0 then
				return false
			end
			if _numB == 0 and _timeB ~= 0 then
				return true
			end
		else

		end
		local _idA = tonumber(a.id) or 0
		local _idB = tonumber(b.id) or 0
		return _idA < _idB
	end)
end

function DiscountShopLayer:initUI()
	-- tableview
	local tableview = zc.ZCTableView:create( self._size )
    tableview:setBounceable( true )
    tableview:setInertia( true )
    tableview:setDirection( cc.SCROLLVIEW_DIRECTION_VERTICAL )
    tableview:setDelegate()
    tableview:setVerticalFillOrder( cc.TABLEVIEW_FILL_TOPDOWN )
    local cellWidth = self._size.width
    local cellHeight = 160
    local function cellSizeForTable(table, index) 
        return cellHeight, cellWidth
    end
    local function tableCellAtIndex(table, index)
        local cell = table:dequeueCell()
        -- 创建模板
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            self:buildCell( cell, cellWidth, cellHeight )
        end
        self:updateCell( cell, index + 1 )
        return cell
    end
    local function numberOfCellsInTableView()
    	return #self._status
    end
    tableview:registerScriptHandler( cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    tableview:registerScriptHandler( tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    tableview:registerScriptHandler( numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    self:addChild(tableview)
    self._tableview = tableview
    tableview:reloadData()

    local x
    local y
    local color1_
    local color2_
    if self._activityType == 0 then
    	x = self._size.width*0.5 + 180
    	y = self._size.height + 25
    	color1_ = cc.c3b(104, 63, 29)
    	color2_ = cc.c3b(223, 207, 196)
    else
    	x = self._size.width*0.5
    	y = self._size.height + 12
    	color1_ = cc.c3b(209, 148, 148)
    	color2_ = cc.c3b(223, 207, 196)
    end

    local _turnInfo = PlayerData:getActivityInfoById(18)
    if _turnInfo.openTime and _turnInfo.endTime then
        --活动时间
        local timeTip = zc.createLabel({
            text = zc.lang("activity_time") .. "：",
            fontSize = 18,
            ap = cc.p(1, 0.5),
            pos = cc.p(x, y),
            color = color1_,
            -- outLine = true,
        })
        self:addChild(timeTip)
        local _openTime = os.date("%m" .. zc.lang("date_month") .. "%d" .. zc.lang("date_day_1"), _turnInfo.openTime )
        local _endTime = os.date("%m" .. zc.lang("date_month") .. "%d" .. zc.lang("date_day_1"), _turnInfo.endTime )
        local timeLab = zc.createLabel({
            text = _openTime .. " ~ " .. _endTime,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(timeTip:getPositionX(), timeTip:getPositionY()),
            color = color2_,
            -- outLine = true
        })
        self:addChild(timeLab)
    end
end

function DiscountShopLayer:buildCell( cell, cellWidth, cellHeight )
	local _bg = zc.createSprite("res/Main/activity/cell_bg_0.png") 
	_bg:setPosition(cellWidth*0.5, cellHeight*0.5)
	cell:addChild(_bg)
	local bgSize = _bg:getContentSize()

	local _iconBg = ccui.Scale9Sprite:create(cc.rect(12, 11, 14, 10), "res/Main/role/common/name_bg.png")
    _iconBg:setContentSize(80, 80)
    _iconBg:setPosition(60, bgSize.height*0.5)
	_bg:addChild(_iconBg)
    local _icon = zc.createIconByData({
        data = {
            mainType = 1,
            type = 1,
            id = 1,
            num = 1,
        },
    })
    _icon:setPosition(_iconBg:getContentSize().width*0.5, _iconBg:getContentSize().height*0.5)
    _icon:setTouchEndedShowTip()
    _icon:setScale(0.6)
    _iconBg:addChild(_icon)

	local _buyInfoDi = zc.createSprite("res/Main/activity/discountShop/infoDi.png")
	_buyInfoDi:setAnchorPoint(0, 0)
	_buyInfoDi:setPosition(_iconBg:getPositionX() + _iconBg:getContentSize().width*0.5, bgSize.height*0.5)
	_bg:addChild(_buyInfoDi)

	local _infoSize = _buyInfoDi:getContentSize()
	local _xLab = zc.createLabel({
		text = "X",
		fontSize = 20,
		color = cc.c3b(243, 233, 171),
		pos = cc.p(_infoSize.width*0.5, _infoSize.height*0.5)
	})
	_buyInfoDi:addChild(_xLab)

	local _rewardNameLab = zc.createLabel({
		ap = cc.p(1, 0.5),
		fontSize = 20,
		color2 = cc.c3b(104, 63, 29),
		outLine = true,
		pos = cc.p(_xLab:getPositionX() - 30, _infoSize.height*0.5)
	})
	_buyInfoDi:addChild(_rewardNameLab)

	local _rewardNumLab = zc.createLabel({
		ap = cc.p(0, 0.5),
		fontSize = 20,
		color = cc.c3b(243, 233, 171),
		outLine = true,
		pos = cc.p(_xLab:getPositionX() + 30, _infoSize.height*0.5)
	})
	_buyInfoDi:addChild(_rewardNumLab)

	local _downY = -20
	local _yuanjiaTip = zc.createLabel({
		text = zc.lang("old_price") .. ":",
		ap = cc.p(0, 0.5),
		fontSize = 20,
		color = cc.c3b(65, 25, 25),
		pos = cc.p(20, _downY)
	})
	_buyInfoDi:addChild(_yuanjiaTip)
	local _yuanjiaNum = zc.createLabel({
		ap = cc.p(0, 0.5),
		fontSize = 20,
		outLine = true,
		pos = cc.p(_yuanjiaTip:getPositionX() + _yuanjiaTip:getContentSize().width + 5, _downY)
	})
	_buyInfoDi:addChild(_yuanjiaNum)

	local _yuanjiaImg = zc.createSprite()
	_yuanjiaImg:setAnchorPoint(0, 0.5)
	_yuanjiaImg:setPosition(_yuanjiaTip:getPositionX(), _downY)
	_buyInfoDi:addChild(_yuanjiaImg)

	local _zheTip = zc.createLabel({
		ap = cc.p(0, 0.5),
		fontSize = 20,
		color = cc.c3b(65, 25, 25),
		pos = cc.p(_infoSize.width*0.5, _downY)
	})
	_buyInfoDi:addChild(_zheTip)
	local _zheNum = zc.createLabel({
		ap = cc.p(0, 0.5),
		fontSize = 20,
		outLine = true,
		pos = cc.p(_zheTip:getPositionX() + _zheTip:getContentSize().width + 5, _downY)
	})
	_buyInfoDi:addChild(_zheNum)

	local _zheImg = zc.createSprite()
	_zheImg:setAnchorPoint(0, 0.5)
	_zheImg:setPosition(_zheNum:getPositionX(), _downY)
	_buyInfoDi:addChild(_zheImg)

	local _zheLimg = zc.createSprite("res/Main/activity/discountShop/zhekouLine.png")
	_zheLimg:setPosition(_infoSize.width*0.25, _downY)
	_buyInfoDi:addChild(_zheLimg)
	-- btn
	local _btn = zc.createCommomBtn({
		tag = 3,
		scale = 0.7,
		fontSize = 30,
		text = LANGUAGE_SHOP.buy_space,
		pos = cc.p(bgSize.width - 80, bgSize.height*0.5 - 15),
		endCallback = function()
			zc.sendHttp({
				apiName = "DiscountShop_buy",
				params = {id = cell.goodsId},
				successCallback = function(backData)
					backData.noAnimation = true
                	PlayerData:updataData( backData )
                	zc.createShowReward( backData )
                	if backData.buyRecords then
	                	self._buyRecords = backData.buyRecords or {}
	                end
                	self:sortTb()
					self._tableview:reloadDataAndScrollToCurrentCell()
				end,
			})
		end
	})
	_bg:addChild(_btn)

	local _leftTimesTip = zc.createLabel({
		text = LANGUAGE_ARENA.times_left .. ":",
        fontSize = 20,
        color = cc.c3b(79, 28, 28),
        ap = cc.p(0, 0.5),
        pos = cc.p(0, _btn:getPositionY() + 40),
	})
	_bg:addChild(_leftTimesTip)

	local _timesLab = zc.createLabel({
        fontSize = 20,
        outLine = true,
        color = display.COLOR_GREEN,
        color2 = cc.c3b(92, 44, 44),
        ap = cc.p(0, 0.5),
        pos = cc.p(0, _leftTimesTip:getPositionY()),
	})
	_bg:addChild(_timesLab)

	cell._bg = _bg
    cell._icon = _icon
    cell._rewardNameLab = _rewardNameLab
    cell._rewardNumLab = _rewardNumLab
    cell._yuanjiaNum = _yuanjiaNum
    cell._yuanjiaImg = _yuanjiaImg
    cell._zheTip = _zheTip
    cell._zheNum = _zheNum
    cell._zheImg = _zheImg
	cell._btn = _btn
	cell._leftTimesTip = _leftTimesTip
	cell._timesLab = _timesLab
end

function DiscountShopLayer:updateCell( cell, index )
	local _status = self._status[index]
	if not _status then
		return 
	end
	cell.goodsId = _status.id
	local _info = zc.updateIconByData(cell._icon, {
		data = {
            mainType = _status.itemType,
            type = _status.itemId,
            id = _status.itemId,
            num = _status.itemNum,
		},
	})
    cell._rewardNameLab:setString(_info.name)
    cell._rewardNumLab:setString(_status.itemNum)

    local _imgFile = zc.getImgByType(_status.priceType)
    local _price = tonumber(_status.price) or 0
    local _discount = tonumber(_status.discount) or 0

    cell._yuanjiaNum:setString(_price)
    cell._yuanjiaImg:setTexture(_imgFile)
    cell._yuanjiaImg:setPositionX(cell._yuanjiaNum:getPositionX() + cell._yuanjiaNum:getContentSize().width + 5)
    
    cell._zheTip:setString(_discount .. zc.lang("zi_zhejia") .. ":")
    cell._zheNum:setString(_price*_discount/10)
    cell._zheNum:setPositionX(cell._zheTip:getPositionX() + cell._zheTip:getContentSize().width + 5)
    cell._zheImg:setTexture(_imgFile)
    cell._zheImg:setPositionX(cell._zheNum:getPositionX() + cell._zheNum:getContentSize().width + 5)
    
    local _now = tonumber(self._buyRecords[tostring(_status.id)]) or 0
    local _max = tonumber(_status.times) or 0
    if _max ~= 0 then
    	cell._leftTimesTip:setVisible(true)
    	cell._timesLab:setVisible(true)
	    _now = _now > _max and _max or _now
	    if _now == _max then
	    	cell._timesLab:setColor(display.COLOR_RED)
	    	cell._btn:setEnable(false)
	    else
	    	cell._timesLab:setColor(display.COLOR_GREEN)
	    	cell._btn:setEnable(true)
	    end
	    cell._timesLab:setString((_max - _now) .. "/" .. _max)

	    local _totleW = cell._leftTimesTip:getContentSize().width + cell._timesLab:getContentSize().width
	    local _btnWidth = cell._btn:getBoundingBox().width
	    local _startX = cell._btn:getPositionX() + (_btnWidth - _totleW)*0.5 - 	_btnWidth*0.5
	    cell._leftTimesTip:setPositionX(_startX)
	    cell._timesLab:setPositionX(_startX + cell._leftTimesTip:getContentSize().width)
	else
    	cell._leftTimesTip:setVisible(false)
    	cell._timesLab:setVisible(false)
    	cell._btn:setEnable(true)
	end
end

return DiscountShopLayer