--[[
	招募积累界面
]]

local RecruitAccumulateLayer = class("RecruitAccumulateLayer", function()
    local layer = cc.Sprite:create()
    layer:setContentSize( 720, 463 )
	return layer
end)

function RecruitAccumulateLayer:create( params )
	return RecruitAccumulateLayer.new( params )
end

function RecruitAccumulateLayer:ctor( params )
	self:initData( params )
	self:initUI()
    self:freshUI()
end

function RecruitAccumulateLayer:initData( params )
    self._times = tonumber(params.info.times) or 0
    self._recruitDatas = {}
    self.activityType = params.activityType 
    for k,v in pairs(params.info.status or {}) do
        local _db = params.static[k]
        table.insert(self._recruitDatas, {
            id = tonumber(k) or 0,
            times = tonumber(_db.times) or 0,
            status = tonumber(v) or 0,
            vipDouble = _db.vipDouble,
            db = _db,
        })
    end
    table.sort(self._recruitDatas, function(a, b )
        return tonumber(a.id) < tonumber(b.id)
    end)
end

function RecruitAccumulateLayer:initUI( )
    local _bg
    if self.activityType == 2 then
        -- _bg = ccui.Scale9Sprite:create(cc.rect(1,1,650,380),"res/Main/activity/recruitAccumulation/active_bg_sprite.jpg")
        -- _bg:setContentSize(945,450)
        -- _bg:setPosition(cc.p(cc.p( self:getContentSize().width * 0.5 + 2, self:getContentSize().height * 0.5 + 30 )))
        _bg = zc.getSprite({
            src = "res/Main/activity/recruitAccumulation/active_bg_sprite.jpg",
            pos = cc.p(cc.p( self:getContentSize().width * 0.5 - 5, self:getContentSize().height * 0.5 + 30 )),
            ap = cc.p(0.5 , 0.5)
        })
        _bg:setScaleX(1.25)
        _bg:setScaleY(1.1)
    else
        _bg = zc.getSprite({
            src = "res/Main/activity/recruitAccumulation/active_bg_sprite.jpg",
            pos = cc.p(cc.p( self:getContentSize().width * 0.5 + 2, self:getContentSize().height * 0.5 + 30 )),
            ap = cc.p(0.5 , 0.5)    
        })
    end
	self:addChild(_bg)
    -- 将领详情
    local _details = zc.createLabel({
        text = zc.lang("hero_detail"),
        needSwallow = true,
        outLine = true,
        pixel = 2,
        fontSize = 18,
        endCallback = function()
            zc.createHeroInfoPop({heroId = 51, showHero = true})
        end,
        pos = cc.p(_bg:getContentSize().width - 50, 160),
        color = cc.c3b(255, 167, 48),
        })
    _bg:addChild(_details, 1)

  local _color = cc.c3b(0, 0, 0)
    local _line_1 = cc.DrawNode:create()
    local _underLineH = 2
    _line_1:drawPolygon({
        cc.p(-1, _underLineH),
        cc.p(_details:getContentSize().width + 1, _underLineH),
        cc.p(_details:getContentSize().width + 1, -_underLineH),
        cc.p(-1, -_underLineH ),
    }, 4, cc.c4f(_color.r/255, _color.g/255, _color.b/255, 1), 1, cc.c4f(_color.r/255, _color.g/255, _color.b/255, 1))
    _details:addChild(_line_1)

    local _color2 = cc.c3b(255, 167, 48)
    local _line_1 = cc.DrawNode:create()
    _line_1:drawLine(
        cc.p(0, 0), 
        cc.p(_details:getContentSize().width, 0), 
        cc.c4f(_color2.r/255, _color2.g/255, _color2.b/255, 1))
    _details:addChild(_line_1)
    
	-- scrollview
	local _size = _bg:getContentSize()
	local _nums = table.nums(self._recruitDatas)
	local _scrollH = 150
	local _normalPart = 10
    local _partCellW = 120
    local _partArrowW = 15
	local _view = zc.createScrollview({
        size = cc.size(_size.width, _scrollH),
        innerSize = cc.size(_nums*(_partCellW + _partArrowW) + _normalPart, _scrollH),
        pos = cc.p(0, 10),
    }) 
    _view:setInertiaScrollEnabled(false)
    _bg:addChild(_view)
    

    local _rewardDiSize = cc.size(80, 30)
    local _moveWidth = 0
    for i = 1, #self._recruitDatas do
    	local _btn = zc.createPushButton({
    		normalFile = "res/Main/activity/growUp/di_u.png",
    		
    		needEnableWhenMoving = true,
            scale = 0.8,
    		needSwallow = false,
    		noScaleAction = true,
    		pos = cc.p(_normalPart + (i - 1 + 0.5)*(_partCellW + _partArrowW), _scrollH*0.5),
    		endCallback = function()
	    		if self._recruitDatas[i].status == 2 then
	    			zc.tipInfo(LANGUAGE_TOLLGATEHERO.fetched)
	    			return
	    		end
                if self._recruitDatas[i].status == 0 then
                    local _award = ""
                    for j=1, 3 do
                        if self._recruitDatas[i].db["reward" .. j] and self._recruitDatas[i].db["reward" .. j] ~= "" then
                            if j == 1 then
                                _award =  self._recruitDatas[i].db["reward" .. j]
                            else
                                _award = _award .. "," .. self._recruitDatas[i].db["reward" .. j]
                            end
                        end
                    end
                    zc.createSourcePop("rewardPreview", "src/layer/task/RewardPreviewPop.lua",{award = _award})
                    return
                end
    			zc.sendHttp({
    				apiName = "RecruitAcc_recieve",
    				params = {id = i},
    				successCallback = function( backData )
                        backData.noAnimation = true
	    				PlayerData:updataData(backData)
                        zc.createShowReward(backData)

						self._recruitDatas[tonumber(i)].status = 2
    					self:freshUI()
    				end
				})
    		end
    	})
    	_view:addChild(_btn)

    	self._recruitDatas[i].btn = _btn
    	local _btnSize = _btn:getContentSize()
    	local _node1 = cc.Node:create()
    	_node1:setPosition(_btnSize.width*0.5, _btnSize.height*0.5 - 13)
    	_btn:addChild(_node1)
    	-- 箱子
        local armature = zc.getSpine("missionbox")
        armature:playAction("box3_lock", true)
        armature:setAnchorPoint(cc.p(0.5, 0.5))
        _node1:addChild(armature)
    	
    	self._recruitDatas[i].node1 = _node1
    	local _node2 = zc.createSprite("res/Main/activity/monthSign/fetched.png")
    	_node2:setPosition(_btnSize.width*0.5 - 3, _btnSize.height*0.5 + 10)
    	_btn:addChild(_node2, 2)
    	self._recruitDatas[i].node2 = _node2

    	local _lvDi = zc.createSprite("res/Main/activity/growUp/levelDi.png")
		_lvDi:setPosition(_btn:getPositionX(), 15)
    	_view:addChild(_lvDi)

	    local _lvLab = zc.createLabel({
	    	text = self._recruitDatas[i].times .. zc.lang("ci"),
	    	fontSize = 20,
	    	outLine = true,
	    	pos = cc.p(_lvDi:getContentSize().width*0.5, _lvDi:getContentSize().height*0.5)
	    })
	    _lvDi:addChild(_lvLab)
    	self._recruitDatas[i].lvLab = _lvLab
        -- 箭头
        if i ~= 1 then
            local _arrow = zc.createSprite("res/Main/activity/growUp/arrow_lock.png")
            _arrow:setPosition(_btn:getPositionX() - (_partCellW + _partArrowW)*0.5, _scrollH*0.5)
            _view:addChild(_arrow)
            self._recruitDatas[i].arrow = _arrow
        end
        if self._recruitDatas[i].status == 2 then
            _moveWidth = _btn:getPositionX()
        end
        -- vipDouble
        local _vip = tonumber(self._recruitDatas[i].vipDouble) or 0
        if _vip > 0 then
            local _limitDi =zc.createSprite("res/Main/activity/blackMarket/corner.png")
            _limitDi:setAnchorPoint(0, 1)
            _limitDi:setPosition(4, _btn:getContentSize().height)
            _btn:addChild(_limitDi, 1)
            local _limitLv = zc.createLabel({
                text = "V" .. _vip .. zc.lang("double"),
                fontSize = 18,
                outLine = true,
                color2 = cc.c3b(233, 64, 28),
                pos = cc.p(_limitDi:getContentSize().width*0.5 - 12, _limitDi:getContentSize().height*0.5 + 12),
            })  
            _limitLv:setRotation(-45)
            _limitDi:addChild(_limitLv, 1)
        end
    end


    local _px = -_moveWidth
    if _px > 0 then
    	_px = 0
	elseif _px < _size.width - _view:getInnerContainer():getContentSize().width then
		_px = _size.width - _view:getInnerContainer():getContentSize().width
    end 
    _view:setInnerContainerPosition(cc.p(_px, 0))

    -- bottom
    local bottom = ccui.Scale9Sprite:create(cc.rect(20, 10, 549, 71), "res/Main/role/trinket/sellDi.png")
    bottom:setContentSize(728, 80)
    bottom:setAnchorPoint(0, 0)
    bottom:setPosition(-10, -70)
    _bg:addChild( bottom )
    local bottomSize = bottom:getContentSize()
    -- 活动时间
    local timeBg = ccui.Scale9Sprite:create(cc.rect(12, 11, 14, 10), "res/Main/role/common/name_bg.png")
    timeBg:setContentSize(310, 40)
    timeBg:setAnchorPoint(0, 0.5)
    timeBg:setPosition(20, bottomSize.height*0.5)
    bottom:addChild(timeBg)
    cc.SpriteFrameCache:getInstance():addSpriteFrames("res/Main/home/homeUI.plist", "res/Main/home/homeUI.pvr.ccz")
    local _leftTipImg1 = zc.getSprite({
        src = "home_icon_info.png",
        plist = true,
        ap = cc.p(0, 0.5),
        pos = cc.p(-8, timeBg:getContentSize().height*0.5),
        scale = 0.5,
    })
    timeBg:addChild(_leftTipImg1)
    local _turnInfo = PlayerData:getActivityInfoById(14)
    if _turnInfo.openTime and _turnInfo.endTime then
        --活动时间
        local timeTip = zc.createLabel({
            text = zc.lang("activity_time") .. "：",
            fontSize = 20,
            ap = cc.p(0, 0.5),
            pos = cc.p(20, timeBg:getContentSize().height*0.5),
            color = cc.c3b(230,224,163),
        })
        timeBg:addChild(timeTip)
        local _openTime = os.date("%m" .. zc.lang("date_month") .. "%d" .. zc.lang("date_day_1"), _turnInfo.openTime )
        local _endTime = os.date("%m" .. zc.lang("date_month") .. "%d" .. zc.lang("date_day_1"), _turnInfo.endTime )
        local timeLab = zc.createLabel({
            text = _openTime .. " ~ " .. _endTime,
            fontSize = 20,
            ap = cc.p(0, 0.5),
            pos = cc.p(timeTip:getPositionX() + timeTip:getContentSize().width, timeBg:getContentSize().height*0.5),
            color = cc.c3b(230,224,163),
        })
        timeBg:addChild(timeLab)
    end


    -- 去招募按钮
    local _gotoRecruit = zc.createCommomBtn({
        text = zc.lang("go_zhaomu"),
        pos = cc.p(bottom:getContentSize().width - 100, bottomSize.height*0.5),
        listener = function ( )
            LayerManager.backToMainCity(false)
            zc.createCardExtract()
        end
        })
    bottom:addChild(_gotoRecruit)

    -- 招募几次记录
    local zhaomuTimeBg = zc.getScaleNode("res/Main/role/common/name_bg.png", cc.size(160, 30))
    zhaomuTimeBg:setAnchorPoint(1, 0.5)
    zhaomuTimeBg:setPosition(_gotoRecruit:getPositionX() - _gotoRecruit:getContentSize().width*0.5 - 10, bottomSize.height*0.5)
    bottom:addChild(zhaomuTimeBg)

    local zhaomu_times = zc.createRichLabel({
        text = string.format(zc.lang("zhaomu_times"), self._times),
        pos = cc.p(10, zhaomuTimeBg:getContentSize().height / 2),
        anchor = cc.p(0, 0.5),
        color = cc.c3b(233, 193, 117),
        fontSize = 18,
        }) 
    zhaomuTimeBg:addChild(zhaomu_times)

end

function RecruitAccumulateLayer:freshUI()
    for i = 1, #self._recruitDatas do
        local _info = self._recruitDatas[i]
        if _info.status == 0 then
            _info.lvLab:setColor(cc.c3b(197, 197, 197))
        else
            _info.lvLab:setColor(display.COLOR_YELLOW)
        end
        if _info.status == 2 then
            if i ~= 1 then
                _info.arrow:setTexture("res/Main/activity/growUp/arrow_lock.png")
            end
            -- selectedFile = "res/Main/activity/growUp/di_d.png",
            _info.node1:setVisible(false) -- node1箱子
            _info.node2:setVisible(true) -- node2已领取
            _info.btn:setEnable(false)   -- 按钮
            _info.btn:getStateNormal():setTexture("res/Main/activity/growUp/di_u.png")
        elseif _info.status == 1 then
            _info.node1:setVisible(true) 
            _info.node2:setVisible(false) 
            _info.btn:setEnable(true)
            _info.btn:getStateNormal():setTexture("res/Main/activity/growUp/di_d.png")
            if i ~= 1 then
                _info.arrow:setTexture("res/Main/activity/growUp/arrow_open.png")
            end
        elseif _info.status == 0 then
            if i ~= 1 then
                _info.arrow:setTexture("res/Main/activity/growUp/arrow_lock.png")
            end
            _info.node1:setVisible(true)
            _info.node2:setVisible(false)
            _info.btn:setEnable(true)
            _info.btn:getStateNormal():setTexture("res/Main/activity/growUp/di_u.png")
        end
    end
end

return RecruitAccumulateLayer