--[[
FileName 		LineChooseLayer.lua
ProjectName		HJ2

Created by wangming on 16-07-01
    
]]

local LineChooseLayer = class("LineChooseLayer", function()
	return ZCDialog:create(255*0.7)
end)

function LineChooseLayer:create( params )
	local _lay = LineChooseLayer.new(params)
	return _lay
end

function LineChooseLayer:onCleanup()
    local textureCache = cc.Director:getInstance():getTextureCache()
    textureCache:removeTextureForKey("res/Main/copy/lineChoose/bg_left.png")
    textureCache:removeTextureForKey("res/Main/copy/lineChoose/bg_right.png")
    textureCache:removeTextureForKey("res/Main/copy/lineChoose/labBg_left.png")
    textureCache:removeTextureForKey("res/Main/copy/lineChoose/labBg_right.png")
    for i=1, 3 do
    	textureCache:removeTextureForKey("res/Main/copy/lineChoose/title" .. i .. ".png")
    	textureCache:removeTextureForKey("res/Main/copy/lineChoose/talk" .. i .. ".png")
    end
end

function LineChooseLayer:ctor( params )
	self._tips = LANGUAGE_line_choose_tips()
	self._chooseCall = params.callBack
	self._nationId = params.nationId
	self._tollgateId = params.id
	self._data = gameData.getDataFromCacheWithPrimaryKey("chapter", params.id)
	self._wayInfo = string.split(self._data.way, ",")
	local _itemBgSize = cc.size(300, 250)
	self:initBaseUI(_itemBgSize)
	self:initChapterUI(_itemBgSize)

	local _swallow = ccui.Widget:create()
	_swallow:setContentSize( zc.width, zc.height )
	_swallow:setTouchEnabled( true )
	_swallow:setSwallowTouches( true )
	self:addChild( _swallow )

	self._leftLayer:setPosition( 0, zc.height/2 + 426 )
	self._leftLayer:runAction(
		cc.EaseExponentialOut:create( cc.MoveTo:create( 0.5, cc.p( 0, 0 ) ) )
	)
	self._rightLayer:setPosition( 0, zc.height/2 + 426 )
	self._rightLayer:runAction(
		cc.Sequence:create(
			cc.DelayTime:create( 0.3 ),
			cc.EaseExponentialOut:create( cc.MoveTo:create( 0.5, cc.p( 0, 0 ) ) ),
			cc.CallFunc:create(function()
				_swallow:removeFromParent()
				if self._nationId == 1 and self._tollgateId == 15 then
				    LayerManager.addShieldLayout(nil, 0.01)
			        self._leftLayer._leftBtn:setEnable(false)
			        self._rightLayer._rightBtn:setEnable(false)
			        performWithDelay(self, function()
			            self._leftLayer._leftBtn:setEnable(true)
			            self._rightLayer._rightBtn:setEnable(true)
			            -- if self._tollgateId == 2 then
				           --  getGuideManager():setCurrentGID(GuideKey.KEY_10001)
		            	-- elseif self._tollgateId == 7 then
				            getGuideManager():setCurrentGID(GuideKey.KEY_10010)
				        -- end
			            getGuideManager():setHeroFuncCallBack(function()
			                getGuideManager():setObjTarget(self._leftLayer._leftBtn)
			                getGuideManager():startGuide()
			            end)
			            getGuideManager():startGuide()
			        end, 0.01)
			    end
			end)
		)
	)
end

function LineChooseLayer:initBaseUI(_itemBgSize)
	local _leftLayer = cc.Layer:create()
	self:addChild(_leftLayer)
	self._leftLayer = _leftLayer
	local _rightLayer = cc.Layer:create()
	self:addChild(_rightLayer)
	self._rightLayer = _rightLayer
	----bg
	local _leftBg = zc.createSprite("res/Main/copy/lineChoose/bg_left.png")
	_leftBg:setAnchorPoint(1, 0.5)
	_leftBg:setPosition(zc.width*0.5, zc.height*0.5)
	self._leftLayer:addChild(_leftBg)
	local _rightBg = zc.createSprite("res/Main/copy/lineChoose/bg_right.png")
	_rightBg:setAnchorPoint(0, 0.5)
	_rightBg:setPosition(zc.width*0.5, zc.height*0.5)
	self._rightLayer:addChild(_rightBg)

	----title
	local _leftTitle = zc.createSprite("res/Main/copy/lineChoose/title" .. self._wayInfo[1] .. ".png")
	_leftTitle:setAnchorPoint(0, 1)
	_leftTitle:setPosition(20, zc.height - 20)
	self._leftLayer:addChild(_leftTitle, 1)
	local _rightTitle = zc.createSprite("res/Main/copy/lineChoose/title" .. self._wayInfo[2] .. ".png")
	_rightTitle:setAnchorPoint(1, 1)
	_rightTitle:setPosition(zc.width - 20, zc.height - 20)
	self._rightLayer:addChild(_rightTitle, 1)


	local _leftHeroDi = zc.createSprite("res/Main/smithy/make/make_weapon_bg.png")
	_leftHeroDi:setScale(0.75)
	_leftHeroDi:setPosition(zc.width*0.5 - 320, zc.height*0.5 + 120)
	self._leftLayer:addChild(_leftHeroDi)
	self._leftHeroDi = _leftHeroDi
	local _rightHeroDi = zc.createSprite("res/Main/smithy/make/make_weapon_bg.png")
	_rightHeroDi:setScale(0.75)
	_rightHeroDi:setPosition(zc.width*0.5 + 320, zc.height*0.5 + 120)
	self._rightLayer:addChild(_rightHeroDi)
	self._rightHeroDi = _rightHeroDi
	----itemBg
	local _leftItemBg = zc.getScaleNode("res/Main/copy/lineChoose/itemBg_left.png", _itemBgSize)
	_leftItemBg:setPosition(zc.width*0.5 - 300, zc.height*0.5 - 80)
	self._leftLayer:addChild(_leftItemBg)
	self._leftItemBg = _leftItemBg
	local _rightItemBg = zc.getScaleNode("res/Main/copy/lineChoose/itemBg_right.png", _itemBgSize)
	_rightItemBg:setPosition(zc.width*0.5 + 300, zc.height*0.5 - 80)
	self._rightLayer:addChild(_rightItemBg)
	self._rightItemBg = _rightItemBg

	----nameBg
	local _leftNameBg = zc.createSprite("res/Main/copy/lineChoose/labBg_left.png")
	_leftNameBg:setAnchorPoint(0, 0)
	_leftNameBg:setPosition(_leftItemBg:getPositionX() - _itemBgSize.width*0.5 - 30, _leftItemBg:getPositionY() + _itemBgSize.height*0.5 + 5)
	self._leftLayer:addChild(_leftNameBg)
	local _leftTTF = zc.createLabel({
		text = LANGUAGE_TOLLGATEHERO.chance_drop,
		outLine = true,
		fontSize = 20,
		ap = cc.p(0, 0.5),
		color = display.COLOR_YELLOW,
		pos = cc.p(40, _leftNameBg:getContentSize().height*0.5)
	})
	_leftNameBg:addChild(_leftTTF)
	local _rightNameBg = zc.createSprite("res/Main/copy/lineChoose/labBg_right.png")
	_rightNameBg:setAnchorPoint(0, 0)
	_rightNameBg:setPosition(_rightItemBg:getPositionX() - _itemBgSize.width*0.5 + 15, _rightItemBg:getPositionY() + _itemBgSize.height*0.5 + 5)
	self._rightLayer:addChild(_rightNameBg)
	local _rightTTF = zc.createLabel({
		text = LANGUAGE_TOLLGATEHERO.chance_drop,
		outLine = true,
		fontSize = 20,
		ap = cc.p(0, 0.5),
		color = display.COLOR_YELLOW,
		pos = cc.p(40, _rightNameBg:getContentSize().height*0.5)
	})
	_rightNameBg:addChild(_rightTTF)


	----btn
	local _leftBtn = zc.createCommomBtn({
		tag = 1,
		text = zc.lang("chuangguan"),
		pos = cc.p(zc.width*0.5 - 260, zc.height*0.5 - 260),
		endCallback = function()
			if self._chooseCall then
				self._chooseCall(1)
			end
		end
	})
	self._leftLayer:addChild(_leftBtn)
	self._leftLayer._leftBtn = _leftBtn
	local _rightBtn = zc.createCommomBtn({
		tag = 1,
		text = zc.lang("chuangguan"),
		pos = cc.p(zc.width*0.5 + 260, zc.height*0.5 - 260),
		endCallback = function()
			if self._chooseCall then
				self._chooseCall(2)
			end
		end
	})
	self._rightLayer:addChild(_rightBtn)
	self._rightLayer._rightBtn = _rightBtn

	----desc
	local _leftDesc = zc.createLabel({
		text = self._tips[tonumber(self._wayInfo[1])],
		outLine = true,
		fontSize = 20,
		pos = cc.p(zc.width*0.5 - 260, zc.height*0.5 - 300)
	})
	self._leftLayer:addChild(_leftDesc)
	local _rightDesc = zc.createLabel({
		text = self._tips[tonumber(self._wayInfo[2])],
		outLine = true,
		fontSize = 20,
		pos = cc.p(zc.width*0.5 + 260, zc.height*0.5 - 300)
	})
	self._rightLayer:addChild(_rightDesc)
end

function LineChooseLayer:initChapterUI(_itemBgSize)
	local _bossIds = string.split(self._data.boss, ",")
	local _bossLeft = gameData.getDataFromCacheWithPrimaryKey("hero", _bossIds[1])
	local _bossRight = gameData.getDataFromCacheWithPrimaryKey("hero", _bossIds[2])

	local _leftName_pre = zc.createLabel({
		text = zc.lang("shouguan") .. "BOSS:",
		outLine = true,
		fontSize = 22,
		ap = cc.p(1, 0.5),
		color = display.COLOR_YELLOW,
		pos = cc.p(self._leftHeroDi:getPositionX() - 0, self._leftHeroDi:getPositionY() - 10)
	})
	self._leftLayer:addChild(_leftName_pre)
	local _leftName = zc.createLabel({
		text = _bossLeft.name,
		outLine = true,
		fontSize = 22,
		ap = cc.p(0, 0.5),
		pos = cc.p(self._leftHeroDi:getPositionX() - 0, self._leftHeroDi:getPositionY() - 10)
	})
	self._leftLayer:addChild(_leftName)

	local _rightName_pre = zc.createLabel({
		text = zc.lang("shouguan") .. "BOSS:",
		outLine = true,
		fontSize = 22,
		ap = cc.p(1, 0.5),
		color = display.COLOR_YELLOW,
		pos = cc.p(self._rightHeroDi:getPositionX() - 0, self._rightHeroDi:getPositionY() - 10)
	})
	self._rightLayer:addChild(_rightName_pre)
	local _rightName = zc.createLabel({
		text = _bossRight.name,
		outLine = true,
		fontSize = 22,
		ap = cc.p(0, 0.5),
		pos = cc.p(self._rightHeroDi:getPositionX() - 0, self._rightHeroDi:getPositionY() - 10)
	})
	self._rightLayer:addChild(_rightName)


	local _leftArm = zc.battle.createHeroArmature({
		fileName = _bossLeft.modelId,
		async = true,
		asyncCallback = function(_armature, fileName, num)
	        if _armature then
	            if num and tonumber(num) and tonumber(num) == 0 then
	                _armature:setOpacity(0)
	                _armature:runAction(cc.FadeIn:create(0.2))
	            end
	            _armature:getAnimation():play("idle")
	        end
    	end
    })
    _leftArm:setPosition(self._leftHeroDi:getPositionX(), self._leftHeroDi:getPositionY() + 10)	
    _leftArm:setScaleX(-1)
    self._leftLayer:addChild(_leftArm)
	local _leftTalk = zc.createSprite("res/Main/copy/lineChoose/talk" .. self._wayInfo[1] .. ".png")
	_leftTalk:setAnchorPoint(0, 0)
	_leftTalk:setPosition(self._leftHeroDi:getPositionX() + 50, self._leftHeroDi:getPositionY() + 90)
	self._leftLayer:addChild(_leftTalk)

    local _rightArm = zc.battle.createHeroArmature({
		fileName = _bossRight.modelId,
		async = true,
		asyncCallback = function(_armature, fileName, num)
	        if _armature then
	            if num and tonumber(num) and tonumber(num) == 0 then
	                _armature:setOpacity(0)
	                _armature:runAction(cc.FadeIn:create(0.2))
	            end
	            _armature:getAnimation():play("idle")
	        end
    	end
    })
    _rightArm:setPosition(self._rightHeroDi:getPositionX(), self._rightHeroDi:getPositionY() + 10)	
    self._rightLayer:addChild(_rightArm)	
	local _rightTalk = zc.createSprite("res/Main/copy/lineChoose/talk" .. tostring(self._wayInfo[2]) .. ".png")
	_rightTalk:setAnchorPoint(1, 0)
	_rightTalk:setPosition(self._rightHeroDi:getPositionX() - 50, self._rightHeroDi:getPositionY() + 90)
	self._rightLayer:addChild(_rightTalk)


    local _leftItems = string.split(self._data.dropLeft, ",")
    local _a, _b = math.modf(#_leftItems/3)
    if _b > 0 then
    	_a = _a + 1
    end 
	local _height = _a*90
	if _height < _itemBgSize.height then
		_height = _itemBgSize.height
	end
	local _leftView = zc.createScrollview({
        size = _itemBgSize,
        innerSize = cc.size(_itemBgSize.width, _height),
        dir = ccui.ScrollViewDir.vertical,
        bar = false,
        bounceEnable = true,
    })
	self._leftItemBg:addChild(_leftView)
    for i=1, #_leftItems do
    	local _tmpData = gameData.getDataFromCacheWithPrimaryKey("item", _leftItems[i])
        local _r = math.modf((i-1)/3)
    	local _icon = zc.createIconByData({
	        data = {
	            mainType = zc.mainTypeProp,
	            type = _tmpData.id,
	            id = _tmpData.id,
	        },
	        showDetailPop = true,
	        pos = cc.p(55 + ((i - 1)%3)*94, _height - 55 - _r*90),
		})
		_icon:setScale(0.7)
		_leftView:addChild(_icon)
    end

    local _rightItems = string.split(self._data.dropRight, ",")
    local _a, _b = math.modf(#_rightItems/3)
    if _b > 0 then
    	_a = _a + 1
    end 
	local _height = _a*90
	if _height < _itemBgSize.height then
		_height = _itemBgSize.height
	end
	local _rightView = zc.createScrollview({
        size = _itemBgSize,
        innerSize = cc.size(_itemBgSize.width, _height),
        dir = ccui.ScrollViewDir.vertical,
        bar = false,
        bounceEnable = true,
    })
	self._rightItemBg:addChild(_rightView)
    for i=1, #_rightItems do
    	local _tmpData = gameData.getDataFromCacheWithPrimaryKey("item", _rightItems[i])
        local _r = math.modf((i-1)/3)
    	local _icon = zc.createIconByData({
	        data = {
	            mainType = zc.mainTypeProp,
	            type = _tmpData.id,
	            id = _tmpData.id,
	        },
	        showDetailPop = true,
	        pos = cc.p(55 + ((i - 1)%3)*94, _height - 55 - _r*90),
		})
		_icon:setScale(0.7)
		_rightView:addChild(_icon)
    end

end


return LineChooseLayer