--[[
	物品掉落途径弹窗
	唐实聪
	2016.5.7
]]

local ItemDropPop = class("ItemDropPop",function()
	return ZCPopLayer:create()
end)

function ItemDropPop:create(data)
    return ItemDropPop.new(data)
end

function ItemDropPop:ctor(data)
    self:show(true)
    self:initData( data )
	self:initUI()
end

function ItemDropPop:initData( data )
    self._name = ""
    self._needNum = data.needNum
    self._backInitParams = data.backInitParams
    -- 进入副本的回调
    self._copyCallback = data.copyCallback
    -- 关闭弹窗的回调
    if data.hideCallback then
        self:setHideCallback(data.hideCallback)
    end
    -- 物品的数据
    self._itemId = tonumber( data.itemId ) or 0
    self._itemType = tonumber( data.itemType ) or 0
    local itemData = gameData.getDataFromCacheWithPrimaryKey("item", self._itemId)
    -- dump( itemData )
    -- 判断物品类型
    self._dropList = {}
    if table.nums( itemData ) > 0 then
        -- 有物品数据
        local _source = tonumber( itemData.source ) or 3
        if _source == 1 then
            -- 武神塔
            self._dropList[#self._dropList + 1] = {
                id = 1,
                icon = "wushenTower",
                name = zc.lang("cailiao_copy"),
                status = PlayerData:getHouseInfoByHouseId(15) and true or false,
                dropType = 1,
            }
        elseif _source == 2 then
            -- 多人副本
            self:buildMultiDropData()
        elseif _source == 3 then
            -- 副本掉落
            self:buildDropData()
        end
    end

    self._size = self:getContentSize()
end
-- 副本掉落
function ItemDropPop:buildDropData()
    -- 查找掉落数据
    local awardId = {}
    local _data = gameData.getDataFromCache("drop_award", {itemId = self._itemId, itemType = self._itemType})
    if next(_data) ~= nil then
        if _data.id then
            awardId[#awardId + 1] = tostring( _data.id )
        else
            for i, v in ipairs(_data) do
                awardId[#awardId + 1] = tostring( v.id )
            end
        end
    end
    -- 掉落途径数据
    if #awardId > 0 then
        -- 构造关卡对应的章节和副本类型数据
        local chapterData = {}
        for i, v in ipairs( gameData.getAllDataWithNoClone( "chapter" ) ) do
            chapterData[tostring( v.id )] = tonumber( v.nationId )
        end
        -- 玩家关卡通关数据
        local tollgateList = PlayerData:getCopyInfo()
        for i, v in ipairs( gameData.getAllDataWithNoClone( "tollgate" ) ) do
            -- 关卡掉落数据
            local dropFlag = false
            local dropData = string.split( v.commonDrop, "," )
            for j, u in ipairs( awardId ) do
                for k, w in ipairs( dropData ) do
                    if u == w then
                        dropFlag = true
                        break
                    end
                end
                if dropFlag then
                    break
                end
            end
            -- 如果掉落，检查这关是否打过
            if dropFlag then
                -- 副本类型
                local nationId = chapterData[tostring( v.chapterId )]
                local nationData = tollgateList[nationId] or {}
                -- 章节
                local chapterId = tonumber( v.chapterId )
                local chapterData = nationData[chapterId] or {}
                -- 关卡
                local tollgateId = tonumber( v.id )
                local tollgateData = {}
                for k, w in ipairs( chapterData["tollgates"] or {} ) do
                    if tonumber( w.tollgateId ) == tollgateId then
                        tollgateData = w
                        break
                    end
                end
                -- 状态
                local status = tonumber( tollgateData["status"] ) or 0
                local data = {
                    id = v.id,
                    icon = v.icon,
                    name = v.name,
                    chapterId = v.chapterId,
                    nationId = nationId,
                    dropType = 0,
                }
                if status == 2 then
                    -- 已通关
                    data.status = true
                else
                    -- 未通关
                    data.status = false
                end
                self._dropList[#self._dropList + 1] = data
            end
        end
    end
end
-- 多人副本
function ItemDropPop:buildMultiDropData()
    -- 查找掉落数据
    local awardId = {}
    local _data = gameData.getDataFromCache("drop_award", {itemId = self._itemId, itemType = self._itemType})
    if next(_data) ~= nil then
        if _data.id then
            awardId[#awardId + 1] = tostring( _data.id )
        else
            for i, v in ipairs(_data) do
                awardId[#awardId + 1] = tostring( v.id )
            end
        end
    end
    -- 掉落途径数据
    if #awardId > 0 then
        -- 玩家关卡通关数据
        local tollgateList = PlayerData:getCopyInfo()
        -- 建筑等级
        local _level = tonumber( PlayerData:getHouseInfoByHouseId(15).level ) or 0
        -- 判断多人副本是否开启
        local _open = zc.getFunctionStatus( 19, false )
        for i, v in ipairs( gameData.getAllDataWithNoClone( "tollgateTeam" ) ) do
            -- 每一关的掉落
            local dropData = string.split( v.commonDrop, "," )
            local dropFlag = false
            for j, u in ipairs( awardId ) do
                -- 关卡掉落数据
                for k, w in ipairs( dropData ) do
                    if u == w then
                        dropFlag = true
                        break
                    end
                end
            end
            -- 如果掉落，检查这关是否可以打
            if dropFlag then
                local data = {
                    id = v.id,
                    icon = "wushenTower",
                    name = v.name,
                    dropType = 2,
                }
                if _open then
                    -- 多人副本开启
                    local _status = PlayerData:getCurTollGateStatus( v.activateId )
                    if _status == 2 and _level >= tonumber( v.houseLevel ) then
                        -- 已通关
                        data.status = true
                    else
                        -- 未通关
                        data.status = false
                    end
                else
                    -- 多人副本未开启
                    data.status = false
                end
                self._dropList[#self._dropList + 1] = data
            end
        end
    end
    -- dump( self._dropList, "self._dropList" )
end

function ItemDropPop:initUI()
    -- bg
    local bg = ccui.Scale9Sprite:create( cc.rect( 36, 34, 3, 4 ), "res/Main/common/common_inner21.png" )
    bg:setContentSize( 313, 420 )
    bg:setPosition( self._size.width/2, self._size.height/2 )
	self:addContent(bg)
	local bgSize = bg:getContentSize()
    -- 顶部
    local topBg = ccui.Scale9Sprite:create( cc.rect( 30, 27, 3, 3 ), "res/Main/common/common_up_bg.png" )
    topBg:setContentSize( bgSize.width - 13, 80 )
    topBg:setAnchorPoint( 0.5, 1 )
    topBg:setPosition( bgSize.width/2, bgSize.height - 5 )
    bg:addChild( topBg )
    local topBgSize = topBg:getContentSize()
    local laceNum = math.floor( topBg:getContentSize().width/41 )
    for i = 1, laceNum do
        local lace = cc.Sprite:create( "res/Main/wushenTower/common_head_bg.png" )
        lace:setPosition( topBgSize.width/2 - laceNum*41/2 + 41*( i - 0.5 ), topBgSize.height/2 )
        topBg:addChild( lace )
    end
	-- 关闭按钮
	local close = zc.createBackButton({
        pos = cc.p(bgSize.width-10, bgSize.height-10),
        listener = function ()
            self:hide()
        end,
    })
    bg:addChild(close)
    --道具
	local item, itemInfo = zc.createIconByData({
        data = {
            mainType = self._itemType,
            type = self._itemId, 
            id = self._itemId,
            -- quality = self._color,
        }, 
        pos = cc.p(50, topBgSize.height/2 ), 
    })
    item:setScale(0.55)
    topBg:addChild(item)
    self._name = itemInfo.name
    local name = zc.createLabel({
    	text = itemInfo.name,
    	fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(90, topBgSize.height/2 + 20 ),
        stroke = true,
    })
    topBg:addChild(name)
    local ownText = zc.createLabel({
    	text = zc.lang("curr_have").."：",
    	fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(90, topBgSize.height/2 - 15 ),
        stroke = true,
    })
    topBg:addChild(ownText)
    local ownNum = zc.createLabel({
    	text = zc.getNumByTypeId(self._itemType, self._itemId),
    	fontSize = 20,
        ap = cc.p(0, 0.5),
        pos = cc.p(185, topBgSize.height/2 - 15 ),
        stroke = true,
    })
    topBg:addChild(ownNum)

    -- 底部
    local bottomBg = ccui.Scale9Sprite:create( cc.rect( 16, 15, 3, 3 ), "res/Main/common/common_middle_bg.png" )
    bottomBg:setContentSize( bgSize.width - 16, bgSize.height - topBgSize.height - 10 )
    bottomBg:setAnchorPoint( 0.5, 0 )
    bottomBg:setPosition( bgSize.width/2, 5 )
    bg:addChild( bottomBg )
    local bottomBgSize = bottomBg:getContentSize()
    if #self._dropList > 0 then
        -- tableview
        local myTableView = zc.ZCTableView:create(cc.size(bottomBgSize.width, bottomBgSize.height - 10))
        myTableView:setDirection(cc.SCROLLVIEW_DIRECTION_VERTICAL)
        myTableView:setPosition(cc.p(0, 5))
        myTableView:setDelegate()
        self._myTableView = myTableView
        myTableView:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)
        local cellWidth = bottomBgSize.width
        local cellHeight = 75
        local function cellSizeForTable(table, index) 
            return cellHeight, cellWidth
        end
        local function tableCellAtIndex(table, index) 
            local cell = myTableView:dequeueCell()
            -- 创建模板
            if cell == nil then
                cell = zc.ZCTableViewCell:new()
                self:buildCell(cell, index, cellWidth, cellHeight)
            end
            -- 更新界面
            self:updateCell(cell, index)
            return cell
        end
        local function numberOfCellsInTableView()
            return #self._dropList
        end
        myTableView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX)
        myTableView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX)
        myTableView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
        bottomBg:addChild(myTableView)
        myTableView:reloadData()
    else
        -- 没有掉落
        local empty = cc.Sprite:create( "res/Main/common/empty.png" )
        empty:setPosition( bottomBgSize.width/2, bottomBgSize.height/2 )
        bottomBg:addChild(empty)
    end
end


function ItemDropPop:buildCell(cell, index, cellWidth, cellHeight)
    -- 背景
    local cellBg = cc.Sprite:create( "res/Main/bag/new/bag_item_bg.png" )
    cellBg:setPosition( cellWidth/2, cellHeight/2 )
    cell:addChild(cellBg)
    cell._cellBg = cellBg
    local cellBgSize = cellBg:getContentSize()
    -- 图标
    local icon = cc.Sprite:create()
    cellBg:addChild(icon)
    cell._icon = icon
    -- 功能名字
    local func = zc.createLabel({
        fontSize = 20,
        pos = cc.p(cellBgSize.width/2-30, 37),
        color = display.COLOR_BLACK,
    })
    cellBg:addChild( func )
    cell._func = func
    -- 副本名字
    local nation = zc.createLabel({
    	fontSize = 20,
        pos = cc.p(cellBgSize.width/2-30, 50),
        color = display.COLOR_BLACK,
    })
    cellBg:addChild( nation )
    cell._nation = nation
    -- 关卡名字
    local tollgate = zc.createLabel({
        fontSize = 20,
        pos = cc.p(cellBgSize.width/2-30, 25),
        color = display.COLOR_BROWN,
    })
    cellBg:addChild( tollgate)
    cell._tollgate = tollgate
    --前往按钮
    local goBtn = zc.createPushButton({
        touchSize = cc.size( 90, 50 ),
        pos = cc.p(237, cellBgSize.height/2), 
        anchor = cc.p(0.5, 0.5),
        fontSize = 20,
        endCallback = function()
            -- 前往副本的回调
            if self._copyCallback then
                self._copyCallback()
            end
            self:goDrop(index)
        end
    })
    cellBg:addChild(goBtn)
    cell._goBtn = goBtn
    goBtn:setContentSize(cc.size( 90, 50 ))
    local goLabel = zc.createLabel({
        fontSize = 20,
        ap = cc.p(0.5, 0.5),
        pos = cc.p(goBtn:getPosition()),
        stroke = true,
    })
    cellBg:addChild( goLabel)
    cell._goLabel = goLabel
end
function ItemDropPop:updateCell(cell, index)
    local data = self._dropList[index + 1]
    local cellBgSize = cell._cellBg:getContentSize()
    if data.dropType == 0 then
        -- 副本掉落
        cell._icon:setTexture("res/Main/copy/"..data.icon..".png")
        cell._icon:setScale(90/cell._icon:getContentSize().width)
        cell._icon:setPosition( 40, cellBgSize.height/2 )
        cell._func:setText("")
        cell._nation:setText(data.nationId == 1 and zc.lang("noraml_chapter") or zc.lang("elite_chapter"))
        cell._tollgate:setText(data.name)
        if data.status then
            cell._goLabel:setText(zc.lang("goto_rightnow"))
            cell._goLabel:setColor( display.COLOR_WHITE )
            cell._goBtn:setEnable( true )
        else
            cell._goLabel:setText(zc.lang("un_finish_tollgate"))
            cell._goLabel:setColor( display.COLOR_RED )
            cell._goBtn:setEnable( false )
        end
    elseif data.dropType == 1 then
        -- 武神塔
        cell._icon:setTexture("res/Main/copy/"..data.icon..".png")
        cell._icon:setScale(65/cell._icon:getContentSize().width)
        cell._icon:setPosition( 50, cellBgSize.height/2 + 10 )
        cell._func:setText(data.name)
        cell._nation:setText("")
        cell._tollgate:setText("")
        if data.status then
            cell._goLabel:setText(zc.lang("goto_rightnow"))
            cell._goLabel:setColor( display.COLOR_WHITE )
            cell._goBtn:setEnable( true )
        else
            cell._goLabel:setText( LANGUAGE_TOLLGATEHERO.not_open )
            cell._goLabel:setColor( display.COLOR_RED )
            cell._goBtn:setEnable( false )
        end
    elseif data.dropType == 2 then
        -- 多人副本
        cell._icon:setTexture("res/Main/copy/"..data.icon..".png")
        cell._icon:setScale(65/cell._icon:getContentSize().width)
        cell._icon:setPosition( 50, cellBgSize.height/2 + 10 )
        cell._func:setText("")
        cell._nation:setText(zc.lang("multi_copy"))
        cell._tollgate:setText(data.name)
        if data.status then
            cell._goLabel:setText(zc.lang("goto_rightnow"))
            cell._goLabel:setColor( display.COLOR_WHITE )
            cell._goBtn:setEnable( true )
        else
            cell._goLabel:setText(LANGUAGE_TOLLGATEHERO.not_open)
            cell._goLabel:setColor( display.COLOR_RED )
            cell._goBtn:setEnable( false )
        end
    end
end
-- 跳转
function ItemDropPop:goDrop(index)
    local data = self._dropList[index + 1]
    if data.dropType == 0 then
        -- 副本掉落
        -- 打开扫荡
        local dropInfo = {
            mainType = self._itemType,
            itemId = self._itemId,
            needNum = self._needNum,
            name = self._name,
        }
        local _backInitParams = self._backInitParams
        self:hide()
        zc.createTollgateLayer({
            nationId = data.nationId,
            tollgateId = data.chapterId,
            enemyid = data.id,
            dropInfo = dropInfo,
            backInitParams = _backInitParams,
        })
    elseif data.dropType == 1 then
        -- 武神塔
        self:hide()
        zc.createWushenshilian()
    elseif data.dropType == 2 then
        -- 多人副本
        self:hide()
        zc.createMultiCopyMainScene( data.id )
    else
        self:hide()
    end
end

return ItemDropPop
