--[[
-- 国家仓库
-- @author lph
-- Creation  2016-3-24
]]
local CountryWarehousePop = class("CountryWarehousePop", function ()
    return ZCPopLayer:create() 
end);

function CountryWarehousePop:create(params)
	local _CountryWarehouse = CountryWarehousePop.new(params)
	return _CountryWarehouse
end

function CountryWarehousePop:ctor(params)
    self:initData(params)
	self:initUI()
    self:show(false)
end

function CountryWarehousePop:initData(params)
    self._memberData = params.memberData
    self._countryData = params.countryData or {}
    self._country_announcement = self._countryData.announcement      --公告
    self._country_positionId = self._countryData.countryPositionId   --职位
    self._country_name = self._countryData.name                      --国家名称
    self._country_level = self._countryData.level                    --国家等级
    self._country_exp = self._countryData.exp                        --国家经验
    self._country_expLimit = self._countryData.expLimit              --下一级升级所需经验
    self._join_time = self._countryData.joinTime                     --加入国家时间
    self._salaryTime = self._countryData.salaryTime                  --发放俸禄的时间
    self._rank = self._countryData.rank or 1                         --国家排名
    --国库等级
    self._warehouseLevel = 1

    local function _getData( data )
        local _dataTemp = {}
        _dataTemp.money_levelLimit = data.level --effectValue1
        _dataTemp.money_valueLimit = data.effectValue1
        _dataTemp.wood_levelLimit = data.level
        _dataTemp.wood_valueLimit = data.effectValue1
        _dataTemp.ore_levelLimit = data.level
        _dataTemp.ore_valueLimit = data.effectValue1
        return _dataTemp
    end

    --组装数据
    local _types = {113, 114, 115}
    local _dataTemp = {}

    local _techInfo = self._countryData.techInfo or {}
    _techInfo = _techInfo.techs or {}
    for i=1,#_techInfo do
        local _techId = _techInfo[i].techId
        local _level = _techInfo[i].level
        local _data = gameData.getDataFromCache("country_tech_level",{level = _level, techId = _techId})  --科技等级
        if next(_data) ~= nil then
            for j=1, 3 do
                if _data.effectId1 == _types[j] then
                    local _data2 = gameData.getDataFromCache("country_tech_level",{effectId1 = _data.effectId1, level = _level+1})  --科技等级
                    if next(_data2) == nil then
                        _data2 = _data
                    end
                    _dataTemp[j] = _getData(_data2)
                end
            end
        end
    end

    for i=1,3 do
        if not _dataTemp[i] then
            _dataTemp[i] = {}
        end
    end


    --计算发放俸禄数量
    local _my_money_mum = self:getCountrySalary(self._country_positionId,self._countryData.money)
    local _my_wood_mum = self:getCountrySalary(self._country_positionId,self._countryData.wood)
    local _my_ore_mum = self:getCountrySalary(self._country_positionId,self._countryData.ore)
    self._warehouseData = {
        {
            name = zc.lang("country_money_reserves"),
            my_num = _my_money_mum,
            num = self._countryData.money,
            numLimit = self._countryData.moneyLimit,
            _type = 2,
            levelLimit = _dataTemp[1].money_levelLimit or 5,
            valueLimit = _dataTemp[1].money_valueLimit or 99999,
            dataTemp = _dataTemp,
            _isOpen = true,
        },
        {
            name = zc.lang("country_wood_reserves"),
            my_num = _my_wood_mum,
            num = self._countryData.wood,
            numLimit = self._countryData.woodLimit,
            _type = 9,
            levelLimit = _dataTemp[2].wood_levelLimit or 1,
            valueLimit = _dataTemp[2].wood_valueLimit or 99999,
            dataTemp = _dataTemp,
            _isOpen = false,
        },
        {
            name = zc.lang("country_ore_reserves"),
            my_num = _my_ore_mum,
            num = self._countryData.ore,
            numLimit = self._countryData.oreLimit,
            _type = 10,
            levelLimit = _dataTemp[3].ore_levelLimit or 1,
            valueLimit = _dataTemp[3].ore_valueLimit or 99999,
            dataTemp = _dataTemp,
            _isOpen = false,
        }
    }
end

function CountryWarehousePop:initUI()
	--通用背景
    local _warehouse_bg = zc.createSprite("res/Main/common/popBg/popBg_blue.png")
    _warehouse_bg:setPosition(zc.width*0.5, zc.height*0.5)
    self:addContent(_warehouse_bg)
    self._warehouse_bg = _warehouse_bg
    local popBgSize = _warehouse_bg:getContentSize()
    local _bianImg = zc.getScaleNode("res/Main/common/frame.png", cc.size(popBgSize.width, popBgSize.height))
    _bianImg:setPosition(popBgSize.width*0.5, popBgSize.height*0.5)
    _bianImg:setName("bianImg")
    _warehouse_bg:addChild(_bianImg, 1)
    local _b_sideImg = zc.getScaleNode("res/Main/common/popBg/shadow_b.png", cc.size(popBgSize.width + 22, 31))
    _b_sideImg:setAnchorPoint(0, 1)
    _b_sideImg:setPosition(0, 2)
    _warehouse_bg:addChild(_b_sideImg, -1)
    local _r_sideImg = zc.getScaleNode("res/Main/common/popBg/shadow_r.png", cc.size(32, 31 + popBgSize.height))
    _r_sideImg:setAnchorPoint(0, 1)
    _r_sideImg:setPosition(popBgSize.width - 5, popBgSize.height+2)
    _warehouse_bg:addChild(_r_sideImg, -1)

    --标题
    local _warehouse_title = zc.getSprite({
        src = "res/Main/country/warehouse/warehouse_title.png",
        pos = cc.p(-30, _warehouse_bg:getContentSize().height - 10),
        ap = cc.p(0,0.5)
    })
    _warehouse_bg:addChild(_warehouse_title, 10)
    --左侧背景
    local _warehouse_left_bg = zc.getSprite({
        src = "res/Main/country/warehouse/warehouse_left_bg.jpg",
        ap = cc.p(0,0),
        pos = cc.p(10, 33) 
    })
    _warehouse_bg:addChild(_warehouse_left_bg)
    local _boxSpine = zc.createSpine({
        fileName = "guojiacangku",
        actName = "shock",
        loop = true,
        needInit = false,
    })
    _boxSpine:setPosition(cc.pMul(cc.pFromSize(_warehouse_left_bg:getContentSize()), 0.5))
    _warehouse_bg:addChild(_boxSpine)
    local exclamationBtn = zc.createPushButton({
        normalFile = "res/Main/common/button/exclamation_u.png",
        selectedFile = "res/Main/common/button/exclamation_d.png",
        needSwallow = true,
        touchScale = 0.9,
        endCallback = function()
            zc.createRulePop(7)
        end,
        pos = cc.p(_warehouse_left_bg:getContentSize().width-35, _warehouse_left_bg:getContentSize().height - 30)
    })
    _warehouse_left_bg:addChild(exclamationBtn)
    --下方信息
    local progressDi = ccui.Scale9Sprite:create( cc.rect( 589/2, 0, 1, 91 ), "res/Main/role/trinket/sellDi.png")
    progressDi:setContentSize( cc.size(362, 56) )
    progressDi:setAnchorPoint(cc.p(0, 0))
    progressDi:setPosition(cc.p(8, 9))
    _warehouse_bg:addChild(progressDi)
    self._progressDi = progressDi

    local tab_split_y = zc.createSprite("res/Main/common/tab_split_y.png")
    tab_split_y:setAnchorPoint(0.5, 0)
    tab_split_y:setPosition(_warehouse_left_bg:getPositionX()+_warehouse_left_bg:getContentSize().width+2, 9)
    _warehouse_bg:addChild(tab_split_y)
    tab_split_y:setScaleY(469/493)
    --右侧背景
    local _warehouse_right_bg = zc.getSprite({
        src = "res/Main/country/main/country_pop_right_bg.png",
        ap = cc.p(1,0),
        pos = cc.p(_warehouse_bg:getContentSize().width-7, 8) 
    })
    _warehouse_bg:addChild(_warehouse_right_bg)
    self._warehouse_right_bg = _warehouse_right_bg
    --右侧文字背景
    local _text_bg = zc.getSprite({
        src = "res/Main/country/warehouse/warehouse_text_bg.png",
        pos = cc.p(_warehouse_right_bg:getBoundingBox().width/2, 440),
        ap = cc.p(0.5,0.5)
    })
    _warehouse_right_bg:addChild(_text_bg)
    --国家等级
    local _string = zc.lang("country_warehouse_level") .. " :"
    if APP_REVIEW then
        _string = _string .. " " .. zc.lang("level") .. " " .. self._country_level
    else
        _string = _string .. " Lv " .. self._country_level
    end
    local _warehouse_level_label = zc.createLabel({
        text = _string,
        fontSize = 22,
        ap = cc.p(0,0.5),
        outLine = true,
        pos = cc.p(15, 28),
    })
    _text_bg:addChild(_warehouse_level_label)
    --官职
    local _position_name = ""
    local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", self._country_positionId)
    if next(_data) ~= nil then
        _position_name = _data.name
    end
    local _country_position_label = zc.createLabel({
        text = zc.lang("country_position") .. ": " .. _position_name,
        fontSize = 22,
        ap = cc.p(0,0.5),
        outLine = true,
        pos = cc.p(200+80, 28),
    })
    _text_bg:addChild(_country_position_label)
    --关闭按钮
    local _closeButton = zc.createBackButton({
        pos = cc.p(_warehouse_bg:getBoundingBox().width-10  , _warehouse_bg:getBoundingBox().height), 
        listener = function () 
            LayerManager.removeLayout(true)
        end,
    })
    _warehouse_bg:addChild(_closeButton, 10)

    --仓库列表
    self:initWarehouseList()
end


function CountryWarehousePop:initWarehouseList()
    local _tableSize = cc.size(500, 390)
    local _tableView = zc.ZCTableView:create(_tableSize)
    _tableView:setPosition(5, 10)
    _tableView:setInertia(true)
    _tableView:setBounceable(true)
    _tableView:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL)
    _tableView:setDelegate()
    _tableView:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    self._warehouse_right_bg:addChild(_tableView)
    self._warehouseTable = _tableView

    local _cellSize = cc.size(500, 160)

    local function numberOfCellsInTableView( table )
        return  #self._warehouseData
    end
    local function cellSizeForTable( table, index )
        return _cellSize.height , _cellSize.width
    end
    local function tableCellAtIndex( table, index )
        local cell = table:dequeueCell()
        if cell then
            cell:removeAllChildren()
        else
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(_cellSize)
        end

        local _di = zc.getSprite({
            src = "res/Main/country/techinfo/techinfo_item_bg.png",
            ap = cc.p(0,0.5),
            pos = cc.p(13, 75),
        })

        cell:addChild(_di)
        self:createOneCell(_di, index)
        return cell
    end
    _tableView:registerScriptHandler(numberOfCellsInTableView, cc.NUMBER_OF_CELLS_IN_TABLEVIEW )
    _tableView:registerScriptHandler(cellSizeForTable, cc.TABLECELL_SIZE_FOR_INDEX )
    _tableView:registerScriptHandler(tableCellAtIndex, cc.TABLECELL_SIZE_AT_INDEX )
    _tableView:reloadData()
end

function CountryWarehousePop:createOneCell( cell, index )
    local _salary_data = self._warehouseData[index+1]
    if _salary_data then
        local cellSize = cell:getContentSize()

        local titleBg = zc.createSprite("res/Main/smithy/cast_text_bg.png")
        titleBg:setAnchorPoint(0, 0.5)
        titleBg:setPosition(0, cellSize.height + 15)
        cell:addChild(titleBg)

        local titleLab = zc.createRichLabel({
            text = _salary_data.name,
            fontSize = 20,
        })
        titleLab:setAnchorPoint(0, 0.5)
        titleLab:setPosition(20, titleBg:getContentSize().height/2)
        titleLab:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
        titleBg:addChild(titleLab)

        local item = zc.createIconByData({
            data = {
                mainType = zc.mainTypeResource,
                type = _salary_data._type, 
                id = _salary_data._type,
            }, 
            pos = cc.p(53, cellSize.height/2), 
        })
        item:setScale(82/125)
        cell:addChild(item)

        local _shadowInfobg1 = ccui.Scale9Sprite:create( cc.rect( 12, 11, 14, 10 ), "res/Main/role/common/name_bg.png" )
        _shadowInfobg1:setContentSize( cc.size(215, 30) )
        _shadowInfobg1:setAnchorPoint( 0, 0.5 )
        _shadowInfobg1:setPosition( 100, cellSize.height/2 + 20 )
        cell:addChild( _shadowInfobg1 )

        local _shadowInfobg2 = ccui.Scale9Sprite:create( cc.rect( 12, 11, 14, 10 ), "res/Main/role/common/name_bg.png" )
        _shadowInfobg2:setContentSize( cc.size(215, 30) )
        _shadowInfobg2:setAnchorPoint( 0, 0.5 )
        _shadowInfobg2:setPosition( 100, cellSize.height/2 - 20 )
        cell:addChild( _shadowInfobg2 )

        local curLab = zc.createLabel({
            text = zc.lang("curr_level") .. "：" .. zc.getLevelTipShow() .. "1",
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(10, _shadowInfobg1:getContentSize().height/2 ),
        })
        _shadowInfobg1:addChild(curLab)

        local chubeilab = zc.createLabel({
            text = zc.lang("reserve_totle_num") .. "：",
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
            pos = cc.p(10, _shadowInfobg2:getContentSize().height/2 ),
        })
        _shadowInfobg2:addChild(chubeilab)
        local _src = zc.getImgByType(_salary_data._type)
        local _resImg = zc.getSprite({
            src = _src,
            ap = cc.p(0,0.5),
            pos = cc.p(chubeilab:getPositionX()+chubeilab:getContentSize().width + 5, chubeilab:getPositionY() ),
            scale = 0.7,
        })
        _shadowInfobg2:addChild(_resImg)
        local _res_num_label = zc.createLabel({
            text = _salary_data.num or 0,
            fontSize = 18,
            ap = cc.p(0,0.5),
            outLine = true,
            pos = cc.p(_resImg:getPositionX()+_resImg:getContentSize().width/2 + 10, chubeilab:getPositionY()),
        })
        _shadowInfobg2:addChild(_res_num_label)
        
        if _salary_data._isOpen then
            --国库上限
            local _text_1 = zc.createLabel({
                text = zc.lang("country_warehouse_up_to"),
                fontSize = 16,
                ap = cc.p(0,0.5),
                stroke = false,
                pos = cc.p(75, -12),
                -- color = display.COLOR_GOLD,
                color = cc.c3b(132,128,125),
            })
            cell:addChild(_text_1)
            local _text_2 = zc.createLabel({
                text = "Lv" .. _salary_data.levelLimit,
                fontSize = 18,
                ap = cc.p(0,0.5),
                outLine = true,
                pos = cc.p(75+_text_1:getContentSize().width, -12),
                color = display.COLOR_RED,
            })
            cell:addChild(_text_2)
            local _text_3 = zc.createLabel({
                text = zc.lang("country_reserves_up_limit_to") .. _salary_data.valueLimit,
                fontSize = 16,
                ap = cc.p(0,0.5),
                stroke = false,
                pos = cc.p(75+_text_1:getContentSize().width+_text_2:getContentSize().width, -12),
                -- color = display.COLOR_GOLD,
                color = cc.c3b(132,128,125),
            })
            cell:addChild(_text_3)
        end

        --时间描述
        local _time_desc_label = zc.createLabel({
            text = "",
            fontSize = 18,
            ap = cc.p(0,0.5),
            outLine = true,
            pos = cc.p(330 + 25, 49),
            color = display.COLOR_GREEN,
        })
        cell:addChild(_time_desc_label)
        local _timeDiff =  self._salaryTime - PlayerData:getTime()
        

        if _salary_data._isOpen then
            --俸禄发放倒计时
            local _str_time = ""
            local _timeDiff = self._salaryTime - PlayerData:getTime()
            local _timeStr = zc.getTimeHMS(_timeDiff)
            _time_desc_label:setString(_timeStr)
            schedule(_time_desc_label,function()
                _timeDiff = _timeDiff - 1
                _time_desc_label:setText(zc.getTimeHMS(_timeDiff))
                if _timeDiff <=0 then
                    _timeDiff = 24 * 60 * 60
                end
            end,1.0)
            _time_desc_label:setPositionY( 35 )
            local fafang = zc.createLabel({
                text = zc.lang("send_count_time") .. "：",
                outLine = true,
                fontSize = 16,
                ap = cc.p(0, 0.5),
                pos = cc.p(280+55, 70),
            })
            cell:addChild(fafang)

            --progress
            self:initProgressTimer(_salary_data)
        else
            zc.setGray(cell, true)
            zc.setGray(titleBg, true)
            zc.setGray(_shadowInfobg1, true)
            zc.setGray(_shadowInfobg2, true)
            zc.setGray(_resImg, true)
            local newParmas = {
                data = {
                    mainType = zc.mainTypeResource,
                    type = _salary_data._type, 
                    id = _salary_data._type,
                },
                showGray = true,
            }
            zc.updateIconByData(item,newParmas)

            titleLab:setColor(display.COLOR_DEEPGRAY)
            curLab:setColor(display.COLOR_DEEPGRAY)
            chubeilab:setColor(display.COLOR_DEEPGRAY)
            _res_num_label:setColor(display.COLOR_DEEPGRAY)
        end
    end
end

function CountryWarehousePop:initProgressTimer(_salaryData)
    if self._hasInit then
        return
    end
    self._hasInit = true
    local _bg = self._progressDi
    local _diSize = _bg:getContentSize()

    local my_num = tonumber(_salaryData.my_num) --自己能够分得的数量
    local num = tonumber(_salaryData.num) --本国家拥有的储量
    local numLimit = tonumber(_salaryData.numLimit) --仓库储量
    --test
    -- my_num = 30000
    -- num = 50000
    -- numLimit = 300000
    ------------
    -- 进度条背景
    local progressBg = zc.getScaleNode("res/Main/country/main/progressBg.png", cc.size(336, 36))
    progressBg:setAnchorPoint( 0.5, 0.5 )
    progressBg:setPosition(_diSize.width/2, _diSize.height/2)
    progressBg:setName("progressBg")
    _bg:addChild( progressBg, 0)

    -- 模板
    local stencil = zc.getScaleNode("res/Main/country/main/progressBg.png", cc.size(336, 36))
    stencil:setAnchorPoint( 0, 0.5 )

    -- 底板1
    local plus = zc.getScaleNode("res/Main/country/main/progress2.png", cc.size(360, 36))
    plus:setAnchorPoint( 1, 0.5 )
    local posKey1 = (num)/numLimit >= 1 and 1 or (num)/numLimit
    plus:setPosition( cc.p(posKey1*(progressBg:getContentSize().width), 0) )

    -- 底板2
    local progress = zc.getScaleNode("res/Main/country/main/progress1.png", cc.size(360, 36))
    progress:setAnchorPoint( 1, 0.5 )
    local posKey = my_num/numLimit >= 1 and 1 or my_num/numLimit
    progress:setPosition( cc.p(posKey*(progressBg:getContentSize().width), 0) )

    local jindutiao_1 = zc.getSpine("jindutiao_1")
    jindutiao_1:playAction("animation", true)
    jindutiao_1:setPosition(cc.p(progress:getContentSize().width-85, progress:getContentSize().height/2))
    progress:addChild(jindutiao_1)

    -- clippingNode
    local clippingNode = cc.ClippingNode:create()
    clippingNode:addChild( plus )
    clippingNode:addChild( progress )
    clippingNode:setStencil( stencil )
    clippingNode:setInverted( false )
    clippingNode:setAlphaThreshold( 0.5 )
    progressBg:addChild( clippingNode )
    clippingNode:setPosition(0, 36/2)

    ---------------------------------
    --up
    local _upLine = zc.createSpine({
        fileName = "xingongnengyindao",
        needInit = false,
    })
    local _up_x = posKey*(progressBg:getContentSize().width) - 5
    if _up_x < 0 then
        _up_x = 0
    end
    _upLine:setPosition( cc.p(_up_x, 26) )
    _upLine:playAction( "cangku_youshang", true )
    progressBg:addChild(_upLine,2)
    local chubeilab = zc.createLabel({
        text = zc.lang("my_salary") .. "：",
        fontSize = 18,
        ap = cc.p(0, 0.5),
        pos = cc.p(8, 55 ),
        color = cc.c3b(72,222,243),
        outLine = true,
    })
    _upLine:addChild(chubeilab)
    local _src = zc.getImgByType(_salaryData._type)
    local _resImg = zc.getSprite({
        src = _src,
        ap = cc.p(0,0.5),
        pos = cc.p(chubeilab:getPositionX()+chubeilab:getContentSize().width + 5, chubeilab:getPositionY() ),
        scale = 0.7,
    })
    _upLine:addChild(_resImg)
    local _res_num_label = zc.createLabel({
        text = _salaryData.my_num or 0,
        -- text = 1000,
        fontSize = 20,
        ap = cc.p(0,0.5),
        stroke = false,
        outLine = true,
        pixel = 1.5,
        pos = cc.p(_resImg:getPositionX()+_resImg:getContentSize().width/2 + 10, chubeilab:getPositionY()),
    })
    _upLine:addChild(_res_num_label)

    --down

    local _down_act = "cangku_you"
    local _down_beginX = 12
    local _justX = false
    if posKey1 > 0.38 then
        _down_act = "cangku_zuo"
        _down_beginX = -220
        _justX = true
    end
    local _down_x = posKey1*(progressBg:getContentSize().width) - 5
    if _down_x < 0 then
        _down_x = 0 
    end
    local pos = progressBg:convertToWorldSpace(cc.p(_down_x, 8))

    local _downLine = zc.createSpine({
        fileName = "xingongnengyindao",
        needInit = false,
    })
    _downLine:setPosition( pos )
    _downLine:playAction( _down_act, true )
    self:addChild(_downLine, 10)
    local chubeilab = zc.createLabel({
        text = zc.lang("country_reserve") .. "：",
        fontSize = 18,
        ap = cc.p(0, 0.5),
        pos = cc.p(_down_beginX, -28 ),
        color = cc.c3b(72,222,243),
        outLine = true,
    })
    _downLine:addChild(chubeilab)
    local _src = zc.getImgByType(_salaryData._type)
    local _resImg = zc.getSprite({
        src = _src,
        ap = cc.p(0,0.5),
        pos = cc.p(chubeilab:getContentSize().width + 5, chubeilab:getContentSize().height/2 ),
        scale = 0.7,
    })
    chubeilab:addChild(_resImg)
    local _res_num_label = zc.createLabel({
        text = zc.getWan( tonumber(_salaryData.num)) .."/".. zc.getWan(_salaryData.numLimit),
        -- text = zc.getWan(888888) .."/"..zc.getWan( tonumber(_salaryData.numLimit)),
        fontSize = 18,
        ap = cc.p(0,0.5),
        pos = cc.p(_resImg:getPositionX()+_resImg:getContentSize().width/2 + 10, chubeilab:getContentSize().height/2),
        color = display.COLOR_GREEN,
        outLine = true,
        pixel = 1.5,
    })
    chubeilab:addChild(_res_num_label) 
    if _justX then
        local _res_num_label_w = _res_num_label:getContentSize().width
        chubeilab:setPositionX( chubeilab:getPositionX() - (_res_num_label_w-90) )
    end
end

--计算俸禄
function CountryWarehousePop:getCountrySalary(_position,_totalResNum)
    local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", _position)
    local _rate = 1
    if next(_data) ~= nil then
        _rate = _data.salary
    end
    local _rate_sum = 0
    for k,v in pairs(self._memberData) do
        local _data = gameData.getDataFromCacheWithPrimaryKey("country_position", v.countryPositionId)
        local _rate = 1
        if next(_data) ~= nil then
            _rate = _data.salary
        end
        _rate_sum = _rate_sum + _rate
    end
    local _my_num = _rate/_rate_sum*_totalResNum
    return math.floor(_my_num)
end


return CountryWarehousePop

