--[[
	FileName: GrabMineMapSecondLayer.lua
	Author: andong
	Date: 2016-12-06
	Purpose: 国家抢矿二级地图界面
]]
local GrabMineMapSecondLayer = class( "GrabMineMapSecondLayer", function ()
    return zc.createNormalDialog()
end)
function GrabMineMapSecondLayer:create(parmas)
	return GrabMineMapSecondLayer.new(parmas)
end
function GrabMineMapSecondLayer:ctor(parmas)
	self:initData(parmas)
	self:initUI()
end

function GrabMineMapSecondLayer:initData(parmas)
    local parmas = parmas or {}
    if parmas and parmas.callback then
        self._callback = parmas.callback
    end

    self._areaIndex = tonumber(parmas.area) or 1 --区域

    self:refreshData()
end
function GrabMineMapSecondLayer:refreshData()
    self._secondMineInfo = {}
    local _allMineInfo = PlayerData:getCountryMineData() or {}
    local mineInfo = _allMineInfo[self._areaIndex] or {}
    self._secondMineInfo = mineInfo.mineList or {}
    --
    self:setStaticData()
end
function GrabMineMapSecondLayer:setStaticData()
    local anchorPosList = {
        [1] = {anchor=cc.p(1,0),pos=cc.p(zc.width,0)},
        [2] = {anchor=cc.p(0,0),pos=cc.p(0,0)},
        [3] = {anchor=cc.p(1,1),pos=cc.p(zc.width,zc.height)},
        [4] = {anchor=cc.p(0,1),pos=cc.p(0,zc.height)},
        [5] = {anchor=cc.p(0.5,0.5),pos=cc.p(zc.width/2,zc.height/2)},
    }
    self._anchorPos = anchorPosList[self._areaIndex] or anchorPosList[1]
    local _areaStatic = gameData.getDataFromCache("mine", {["region"]=self._areaIndex} )
    self._areaStatic = _areaStatic
    self._iconScale = 1
    --是不是自己的国家占领的矿
    self._countryInfo = PlayerData:getCountryInfo() or {}
    self._countryName = self._countryInfo.name or ""
end
function GrabMineMapSecondLayer:initUI()
    local bgPath = "res/Main/country/grabMine/mine_bg_"..self._areaIndex..".jpg"
    if not zc.checkFileExist(bgPath) then
        bgPath = "res/Main/country/grabMine/mine_bg_1.jpg"
    end

    local bg = zc.createSprite(bgPath)
    bg:setAnchorPoint(self._anchorPos.anchor)
    bg:setPosition( self._anchorPos.pos )
    self:addChild( bg )
    self._backGround = bg

    --初始化通用icon
    self:initCommonIcon()
    --初始化聊天icon
    self:initChatIcon()
    --初始化右下角button
    self:initButtonList()
    --初始化地图上的建筑和连线
    self:initMapBuildingAndLine()

    --刷新
    self:refreshUIState()
end

function GrabMineMapSecondLayer:refreshAllDataAndUI(_goArea)
    self._areaIndex = tonumber(_goArea) or 5 --区域
    self:refreshData()
    local bgPath = "res/Main/country/grabMine/mine_bg_"..self._areaIndex..".jpg"
    if not zc.checkFileExist(bgPath) then
        bgPath = "res/Main/country/grabMine/mine_bg_1.jpg"
    end
    self._backGround:setTexture(bgPath)
    self._lineSpineList = {}
    self._buildingList = {}
    self._emptyFlagList = {}
    
    self._lineLayer:removeFromParent()
    self._buildingLayer:removeFromParent()
    --初始化地图上的建筑和连线
    self:initMapBuildingAndLine()
    --刷新
    self:refreshUIState()
end
function GrabMineMapSecondLayer:initCommonIcon()

    local commonIconBg = zc.createSprite()
    commonIconBg:setContentSize(zc.width,zc.height)
    commonIconBg:setPosition(zc.width/2,zc.height/2)
    self:addChild(commonIconBg, 4)

    local countTimeBg = zc.createPushButton({
        normalFile = "res/Main/country/grabMine/getBg.png",
        needSwallow = true,
        noScaleAction = true,
    })
    countTimeBg:setAnchorPoint(0, 0.5)
    countTimeBg:setPosition(0, zc.height/2+40)
    commonIconBg:addChild(countTimeBg, 4)
    self._countTimeBg = countTimeBg
    self._countTimeBgIsOpen = true

    local GrabMineMapFirstLayer = zc.getScene("GrabMineMapFirstLayer")
    local timeList = GrabMineMapFirstLayer:getTimeList()
    for i = 1, #timeList do
        local v = timeList[i]
        local mienNameLab = zc.createLabel({
            text = v.name,
            fontSize = 20,
            ap = cc.p(0, 0.5),
            pos = cc.p(42, countTimeBg:getContentSize().height - 33 - (i-1)*75),
            color = zc.getColorByQuality( i+1 ),
        })
        countTimeBg:addChild(mienNameLab)
        local timeLab = zc.createLabel({
            text = zc.getTimeHMS(v.lastTime),
            fontSize = 20,
            ap = cc.p(0, 0.5),
            pos = cc.p(42, countTimeBg:getContentSize().height- 60 - (i-1)*75),
            color = zc.getColorByQuality( i+1 ),
        })
        countTimeBg:addChild(timeLab)
        countTimeBg["timeLab"..i] = timeLab
    end



    local function moveCountTimeBg()
        self:openAttribute()
        if self._arrowBtn then
            local _normal = self._arrowBtn._arrowImg
            if self._countTimeBgIsOpen then
                _normal:setRotation( 0 )
            else
                _normal:setRotation( 180 )
            end
        end
    end
    local scaleSize = cc.size(60, 200)
    -- local myScale9 = zc.getScaleNode("res/Main/setting/scale9_1.png", scaleSize)
    local myScale9 = zc.createSprite()
    myScale9:setContentSize( scaleSize )
    local arrowImg = zc.createSprite("res/Main/country/grabMine/getArrow.png")
    arrowImg:setPosition(scaleSize.width/2, scaleSize.height-30)
    myScale9:addChild(arrowImg)
    local arrowBtn = zc.createPushButton({
        normalNode = myScale9,
        pos = cc.p(173,182),
        endCallback = function()
            moveCountTimeBg()
        end
    })
    countTimeBg:addChild(arrowBtn)
    arrowBtn._arrowImg = arrowImg
    self._arrowBtn = arrowBtn

    --test
    -- moveCountTimeBg()

    local exclamationBtn = zc.createPushButton({
        normalFile = "res/Main/common/button/exclamation_u.png",
        selectedFile = "res/Main/common/button/exclamation_d.png",
        needSwallow = true,
        touchScale = 0.9,
        endCallback = function()
            zc.createRulePop(12)
        end,
        anchor = cc.p(0.5, 0.5),
        pos = cc.p(35, 95)
    })
    commonIconBg:addChild(exclamationBtn, 4)


    local itemBg = cc.Sprite:create("res/Main/copy/leftTimesBg.png")
    itemBg:setAnchorPoint(0, 0.5)
    itemBg:setPosition(65, exclamationBtn:getPositionY())
    commonIconBg:addChild(itemBg, 4)

    local tipLab = zc.createLabel({
        text = zc.lang("seize_times"),
        stroke = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(36, itemBg:getContentSize().height/2),
        color = display.COLOR_WHITE,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    itemBg:addChild(tipLab)

    local starNumLab = zc.createLabel({
        outLine = true,
        fontSize = 24,
        ap = cc.p(0, 0.5),
        pos = cc.p(tipLab:getPositionX()+tipLab:getContentSize().width, tipLab:getPositionY()),
        color = display.COLOR_GREEN,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    itemBg:addChild(starNumLab)
    self._fightNumsLab = starNumLab
    self:refreshFightTimes()

    local addTimesBtn = zc.createPushButton({
        normalFile = "res/Main/common/button/common_btn2_u.png",
        selectedFile = "res/Main/common/button/common_btn2_d.png",
        disableFile = "res/Main/common/button/common_btn2_g.png",
        needSwallow = true,
        endCallback = function()
            local function getMsg()
                local priceInfo = zc.getConsumePriceData( 50, self._fightTimes.timesLimit+1 ) or {}
                local price = priceInfo.price or 0
                return LANGUAGE_SEIZE_BUYGOLD(price)
            end
            local comfirm
            local function buyTime()
                zc.sendHttp({
                    apiName = "CountryMine_buyFightTime",
                    successCallback = function (net_data)
                        zc.tipInfo(zc.lang("tips_buy_success"))
                        PlayerData:updataData( net_data )
                        PlayerData:setCountryMineFightTimes({freeTimes=net_data.freeTimes,timesLimit=net_data.timesLimit})
                        self:refreshFightTimes()

                        comfirm:setMsg(getMsg())
                    end
                })
            end
            comfirm = ZCConfirmDialog:createWithParams({
                title = zc.lang("prompt"),
                msg = getMsg(),
                showDi = true,
                isHide = false,
                leftCallback = function() 
                    comfirm:hide()
                end,
                rightCallback = function()
                    buyTime()
                end
            })
            self:addChild(comfirm, 11)
        end,
        pos = cc.p(280, itemBg:getPositionY()),
    })
    commonIconBg:addChild(addTimesBtn, 4)
end
function GrabMineMapSecondLayer:timeAction( timeList )
    if not timeList then
        return
    end
    for i = 1, #timeList do
        local v = timeList[i]
        if v.lastTime then
            local timeLab = self._countTimeBg["timeLab"..i]
            if not tolua.isnull(timeLab) then
                local _timeTss = v.lastTime
                if _timeTss < 0 then
                    _timeTss = 0
                end
                timeLab:setString(zc.getTimeHMS(_timeTss))
            end
        end
    end
end
function GrabMineMapSecondLayer:refreshFightTimes()
    self._fightTimes = PlayerData:getCountryMineFightTimes()
    self._fightNumsLab:setString(self._fightTimes.freeTimes)
end
--打开属性加成显示
function GrabMineMapSecondLayer:openAttribute()
    if self._attributeIsMoving then
        return
    end
    self._attributeIsMoving = true
    local direction = 1
    if self._countTimeBgIsOpen then
        self._countTimeBgIsOpen = false
        direction = -1
    else
        self._countTimeBgIsOpen = true
    end
    local _arr = {}
    local _per = 150/19
    for i = 1, 19 do
        _arr[#_arr+1] = cc.MoveBy:create(0.01, cc.p(direction*_per, 0))
    end
    _arr[#_arr+1] = cc.CallFunc:create(function() self._attributeIsMoving = false end)
    self._countTimeBg:runAction(cc.Sequence:create(_arr))
end
function GrabMineMapSecondLayer:initChatIcon()
    -- 聊天
    self._chatLayer = requires("src/layer/chat/ChatLeadTipsPop.lua").create()
    self._chatLayer:setPosition( 0, 0 )
    self:addChild( self._chatLayer, 4 )
end
function GrabMineMapSecondLayer:updateChatPanelView(chanel)
    if self._chatLayer then
        self._chatLayer:updateTableView()
    end
end
function GrabMineMapSecondLayer:initButtonList()
    self._bottomButtonLay = requires("src/layer/mainCity/MainBottomBtnsLayer.lua"):create({
        isBack = true,
        -- needToDefault = true,
        showList = {jiaose="1",beibao="1",guojia="1",bingqi="1",buzhen="1"},
    })
    self:addChild(self._bottomButtonLay, 4)
end
function GrabMineMapSecondLayer:initMapBuildingAndLine()
    --线层
    local lineLayer = zc.createSprite()
    lineLayer:setContentSize(1136, 640)
    lineLayer:setAnchorPoint(self._anchorPos.anchor)
    lineLayer:setPosition(self._anchorPos.pos)
    self:addChild(lineLayer)
    self._lineLayer = lineLayer

    self:initMapLines()

    --建筑层
    local buildingLayer = zc.createSprite()
    buildingLayer:setContentSize(1136, 640)
    buildingLayer:setAnchorPoint(self._anchorPos.anchor)
    buildingLayer:setPosition(self._anchorPos.pos)
    self:addChild(buildingLayer)
    self._buildingLayer = buildingLayer

    self:initMapBuilding()
    self:initEmptyFlagBuilding() --空位旗子

end
function GrabMineMapSecondLayer:getLinePos()
    local _lienPosList = {
        [1] = {
            {pos=cc.p(973, 2),spineArea="4_gebi_", area=4},
        },
        [2] = {
            {pos=cc.p(204, 13),spineArea="5_xueshan_", area=5},
            {pos=cc.p(77, 56),spineArea="4_xueshan_", area=4},
        },
        [3] = {
            {pos=cc.p(1152, 581),spineArea="5_huoshan_", area=4},
            {pos=cc.p(1029, 598),spineArea="4_huoshan_", area=4},
        },
        [4] = {
            {pos=cc.p(279, 585),spineArea="5_zhaoze_", area=4},
            {pos=cc.p(152, 566),spineArea="4_zhaoze_", area=4},
        },
        [5] = {
            {pos=cc.p(307, 387),spineArea="4_gebi_", area=4},
            {pos=cc.p(487, 419),spineArea="5_gebi_", area=5},
            {pos=cc.p(670, 426),spineArea="4_xueshan_", area=4},
            {pos=cc.p(787, 365),spineArea="5_xueshan_", area=5},
            {pos=cc.p(348, 236),spineArea="4_huoshan_", area=4},
            {pos=cc.p(493, 185),spineArea="5_huoshan_", area=4},
            {pos=cc.p(663, 197),spineArea="4_zhaoze_", area=4},
            {pos=cc.p(773, 228),spineArea="5_zhaoze_", area=4},
        },
    }
    return _lienPosList[self._areaIndex]
end
function GrabMineMapSecondLayer:getCondition(_act)
    --from占领的地方，to可以去占领的地方
    local _conditionList = {
        ["1_gebi_"] = {from=6,to={[33]=33}},
        ["2_gebi_"] = {from=7,to={[33]=33,[34]=34}},
        ["3_gebi_"] = {from=8,to={[34]=34}},
        ["4_gebi_"] = {from=33,to={[41]=41}},
        ["5_gebi_"] = {from=34,to={[41]=41}},
        ["1_xueshan_"] = {from=14,to={[35]=35}},
        ["2_xueshan_"] = {from=15,to={[35]=35,[36]=36}},
        ["3_xueshan_"] = {from=16,to={[36]=36}},
        ["4_xueshan_"] = {from=35,to={[41]=41}},
        ["5_xueshan_"] = {from=36,to={[41]=41}},
        ["1_huoshan_"] = {from=22,to={[37]=37}},
        ["2_huoshan_"] = {from=23,to={[37]=37,[38]=38}},
        ["3_huoshan_"] = {from=24,to={[38]=38}},
        ["4_huoshan_"] = {from=37,to={[41]=41}},
        ["5_huoshan_"] = {from=38,to={[41]=41}},
        ["1_zhaoze_"] = {from=30,to={[39]=39}},
        ["2_zhaoze_"] = {from=31,to={[39]=39,[40]=40}},
        ["3_zhaoze_"] = {from=32,to={[40]=40}},
        ["4_zhaoze_"] = {from=39,to={[41]=41}},
        ["5_zhaoze_"] = {from=40,to={[41]=41}},
    }
    return _conditionList[_act] or 0
end
function GrabMineMapSecondLayer:initMapLines()
    local lineBg = self._lineLayer
    self._lineSpineList = {}
    local _lineTypeList = self:getLinePos()
    local _lineNums = #_lineTypeList
    for i = 1, _lineNums do
        local _lienTypeInfo = _lineTypeList[i]
        local _area = _lienTypeInfo["spineArea"]

        local _lineSpine = zc.createSpine({
            fileName = "kuangqu",
            actName = _area.."stop",
            loop = true,
            removeCallback = function() end
        })
        _lineSpine:setPosition(_lienTypeInfo.pos)
        lineBg:addChild(_lineSpine)
        _lineSpine:setScale(self._iconScale)

        self._lineSpineList[i] = {}
        self._lineSpineList[i]._spine = _lineSpine
        self._lineSpineList[i]._actNamePrefix = _area
        self._lineSpineList[i]._oldState = "stop"
        self._lineSpineList[i]._condition = self:getCondition(_area)

        ---------- test
        local test = false
        if test then
            local lineBtn = ccui.ImageView:create("res/Main/common/common_inner16.png")
            lineBtn:setAnchorPoint(cc.p(0.5, 0.5))
            lineBtn:setPosition(_lienTypeInfo.pos)
            lineBg:addChild(lineBtn)
            -- lineBtn:setScale(0.5)
            local myLab = zc.createLabel({
                text = i,
                outLine = true,
                fontSize = 20,
                pos = cc.p(lineBtn:getContentSize().width/2, lineBtn:getContentSize().height/2),
            })
            lineBtn:addChild(myLab)
            lineBtn:setTouchEnabled(true)
            local _partPoint
            lineBtn:addTouchEventListener(function ( sender, eventType )
                if eventType == ccui.TouchEventType.began then
                    _partPoint = sender:getTouchBeganPosition()
                    lineBtn:setLocalZOrder(4)
                    return true
                elseif eventType == ccui.TouchEventType.moved then 
                    local _movePoint = sender:getTouchMovePosition()
                    local _pos = cc.pSub(_movePoint, _partPoint)
                    _pos = cc.pAdd(_pos, cc.p(lineBtn:getPosition()))
                    _partPoint = _movePoint
                    lineBtn:setPosition(_pos.x, _pos.y)
                    _lineSpine:setPosition(_pos.x, _pos.y)
                else
                 local pos = sender:getTouchEndPosition()
                 -- print("sender end pos -----------log--------ad-------------".."cc.p("..pos.x..", "..pos.y..")")
                     for m = 1, _lineNums do
                     local _b = self._lineSpineList[m]
                     local pos = cc.p( math.floor(_b:getPositionX()), math.floor(_b:getPositionY()) )
                     -- print("all line end pos -----------log--------ad-------------  "..m.."  cc.p("..pos.x..", "..pos.y..")")
                 end
                end 
            end)
        end

    end
end

function GrabMineMapSecondLayer:getAreaBuildingPos()

    self._flagJustPos = {
        [1] = cc.p(46,15),
        [2] = cc.p(43,8),
        [3] = cc.p(53,9),
        [4] = cc.p(122,-26),
    }

    self._occupyFlagJustPos = {
        [1] = cc.p(-5,20),
        [2] = cc.p(-10,8),
        [3] = cc.p(-8,0),
        [4] = cc.p(7, -12),
    }

    self._eff_kuangInfo = {
        [1] = {scale=1.2,justx=-14,justy=-17},    
        [2] = {scale=1.2,justx=-8,justy=-18},    
        [3] = {scale=1.5,justx=-14,justy=-14},    
        [4] = {scale=2.2,justx=-3,justy=-51},    
    }
    --
    local _areaPosList = {
        [1] = {
            {pos=cc.p(233, 223),tag=1, area=1,id=1},
            {pos=cc.p(552, 274),tag=1, area=1,id=2},
            {pos=cc.p(296, 396),tag=1, area=1,id=4},
            {pos=cc.p(826, 398),tag=1, area=1,id=3},
            {pos=cc.p(552, 435),tag=1, area=1,id=5},
            {pos=cc.p(769, 216),tag=2, area=1,id=7},
            {pos=cc.p(1050,282),tag=2, area=1,id=8},
            {pos=cc.p(499, 113),tag=2, area=1,id=6},
        },
        [2] = {
            {pos=cc.p(906, 171),tag=1, area=2,id=10,zorder=7},
            {pos=cc.p(806, 296),tag=1, area=2,id=11, zorder=3},
            {pos=cc.p(455, 477),tag=1, area=2,id=13, zorder=1},
            {pos=cc.p(598, 363),tag=1, area=2,id=9, zorder=2},
            {pos=cc.p(962, 406),tag=1, area=2,id=12, zorder=1},
            {pos=cc.p(429, 227),tag=2, area=2,id=15, zorder=5},
            {pos=cc.p(254, 351),tag=2, area=2,id=14, zorder=4},
            {pos=cc.p(676, 140),tag=2, area=2,id=16,zorder=6},
        },
        [3] = {
            {pos=cc.p(129, 299),tag=1, area=3,id=17},
            {pos=cc.p(469, 271),tag=1, area=3,id=20},
            {pos=cc.p(275, 211),tag=1, area=3,id=18},
            {pos=cc.p(379, 439),tag=1, area=3,id=19},
            {pos=cc.p(663, 181),tag=1, area=3,id=21},
            {pos=cc.p(764, 368),tag=2, area=3,id=23},
            {pos=cc.p(641, 508),tag=2, area=3,id=22},
            {pos=cc.p(996, 281),tag=2, area=3,id=24},
        },
        [4] = {
            {pos=cc.p(438, 199),tag=1, area=4,id=25},
            {pos=cc.p(703, 171),tag=1, area=4,id=26},
            {pos=cc.p(912, 196),tag=1, area=4,id=29},
            {pos=cc.p(730, 337),tag=1, area=4,id=27},
            {pos=cc.p(895, 432),tag=1, area=4,id=28},
            {pos=cc.p(223, 308),tag=2, area=4,id=30},
            {pos=cc.p(685, 506),tag=2, area=4,id=32},
            {pos=cc.p(431, 373),tag=2, area=4,id=31},
        },
        [5] = {
            {pos=cc.p(439, 515),tag=3, area=5,id=34},
            {pos=cc.p(199, 474),tag=3, area=5,id=33},
            {pos=cc.p(749, 501),tag=3, area=5,id=35},
            {pos=cc.p(211, 194),tag=3, area=5,id=37},
            {pos=cc.p(486, 114),tag=3, area=5,id=38},
            {pos=cc.p(761, 122),tag=3, area=5,id=39},
            {pos=cc.p(992, 395),tag=3, area=5,id=36},
            {pos=cc.p(966, 171),tag=3, area=5,id=40},
            {pos=cc.p(570, 364),tag=4, scale=1.2,id=41,zorder=1},
        },
    }
    return _areaPosList[self._areaIndex]
end
function GrabMineMapSecondLayer:initMapBuilding()

    local buildingBg = self._buildingLayer

    local _areaTypeInfo = self:getAreaBuildingPos()
    local areaNums = #_areaTypeInfo -- 区域数量
    self._buildingNums = areaNums

    self._buildingList = {}

    for i = 1, areaNums do

        local typeInfo = _areaTypeInfo[i]
        local _path = "res/Main/country/grabMine/building_"..typeInfo.tag..".png"
        typeInfo.path = _path
        local building = zc.createSprite(_path)
        building:setScale(typeInfo.scale and typeInfo.scale or self._iconScale)

        typeInfo.zorder = typeInfo.zorder and typeInfo.zorder or 1
        local buildingButton = self:getBuildingButton(building, typeInfo)
        buildingBg:addChild(buildingButton, typeInfo.zorder)

        local _btnId = tonumber(typeInfo.id) or 1
        self._buildingList[_btnId] = {}
        self._buildingList[_btnId]._btn = buildingButton
        self._buildingList[_btnId]._typeInfo =typeInfo
    end
end
function GrabMineMapSecondLayer:initEmptyFlagBuilding()
    local _emptyFlagInfoList = {
        [1] = {
            {pos= cc.p(1071, 130), id=34, _goArea = 5},
            {pos= cc.p(831, 96), id=33, _goArea = 5},
        },
        [2] = {
            {pos= cc.p(140, 150), id=35, _goArea = 1},
            {pos= cc.p(371, 85), id=36, _goArea = 1},
        },
        [3] = {
            {pos= cc.p(1103, 540), id=38, _goArea = 1},
            {pos= cc.p(885, 570), id=37, _goArea = 1},
        },
        [4] = {
            {pos= cc.p(241, 525), id=39, _goArea = 1},
            {pos= cc.p(434, 549), id=40, _goArea = 1},
        },
    }
    self._emptyFlagList = {}
    local _emptyFlagInfo = _emptyFlagInfoList[self._areaIndex]
    if not _emptyFlagInfo then
        return
    end

    for i = 1, #_emptyFlagInfo do
        local _info = _emptyFlagInfo[i]
        local _flagBtn = zc.createPushButton({
            normalNode = zc.createSprite("res/Main/country/grabMine/occupyFlag_blue.png"),
            pos = _info.pos,
            needSwallow = true,
            endCallback = function()
                self:refreshAllDataAndUI(5)
            end
        })
        self._buildingLayer:addChild(_flagBtn, 1)
        _flagBtn:setScale(self._iconScale)

        local _index = #self._emptyFlagList + 1
        self._emptyFlagList[_index] = {}
        self._emptyFlagList[_index]._flag = _flag
        self._emptyFlagList[_index]._info = _info

        local test = false
        if test then
            local buildingBtn = ccui.ImageView:create("res/Main/country/grabMine/occupyFlag_blue.png")
            buildingBtn:setAnchorPoint(cc.p(0.5, 0.5))
            buildingBtn:setPosition( _info.pos )
            buildingBtn:setScale(self._iconScale)
            self._buildingLayer:addChild(buildingBtn, 1)
            buildingBtn:setTouchEnabled(true)
            local myLab = zc.createLabel({
                text = _info.id,
                stroke = true,
                fontSize = 22,
                pos = cc.p(buildingBtn:getContentSize().width/2, buildingBtn:getContentSize().height/2),
            })
            buildingBtn:addChild(myLab)
            buildingBtn:addTouchEventListener(function ( sender, eventType )
                if eventType == ccui.TouchEventType.began then
                    self._partPoint = sender:getTouchBeganPosition()
                    buildingBtn:setLocalZOrder(4)
                    return true
                elseif eventType == ccui.TouchEventType.moved then 
                    local _movePoint = sender:getTouchMovePosition()
                    local _pos = cc.pSub(_movePoint, self._partPoint)
                    _pos = cc.pAdd(_pos, cc.p(buildingBtn:getPosition()))
                    self._partPoint = _movePoint
                    buildingBtn:setPosition(_pos.x, _pos.y)
                else
                    local pos = sender:getTouchEndPosition()
                    local pos = cc.p(buildingBtn:getPositionX(),buildingBtn:getPositionY())
                    print("-----------log--------ad-------------", _info.pos.x, _info.pos.y)
                    print("sender end pos -----------log--------ad-------------".."cc.p("..(pos.x)..", "..(pos.y)..")")
                end
            end)
        end
    end
end
--弹银币动画
function GrabMineMapSecondLayer:getJingBiAction(_gradeList)
    -- do return end
    local _gradeList = _gradeList or {}
    for m, n in pairs(self._buildingList) do
        if n and n._btn and n._typeInfo then
            local _btn = n._btn
            local _typeInfo = n._typeInfo
            --结算类型
            if _typeInfo.tag and _gradeList[_typeInfo.tag] then
                local jingbi = zc.createSpine({
                    fileName = "jingbi",
                    actName = "animation",
                    loop = false,
                    needInit = false,
                    removeCallback = function() end,
                    autoRemove = true,
                })
                jingbi:setScale(self._iconScale*0.7)
                local jingbiPos
                if n.jingbiPos then
                    jingbiPos = n.jingbiPos
                else
                    jingbiPos = _btn:convertToWorldSpace(cc.p(_btn:getContentSize().width/2,_btn:getContentSize().height/2))
                    n.jingbiPos = jingbiPos
                end
                jingbi:setPosition(jingbiPos)
                self:addChild(jingbi, 3)
            end
        end
    end
end

function GrabMineMapSecondLayer:getBuildingButton(_node, _info)
    local buildingButton = zc.createPushButton({
        normalNode = _node,
        pos = _info.pos,
        needSwallow = true,
        endCallback = function()
            local function refresh()
                self:refreshUIState()
                self:refreshFightTimes()
            end
            local function goBattle() --去战斗页面，删除倒计时
                local GrabMineMapFirstLayer = zc.getScene("GrabMineMapFirstLayer")
                if GrabMineMapFirstLayer then
                    GrabMineMapFirstLayer:deleteShowLay()
                    GrabMineMapFirstLayer:setNowFightState(true)
                end
            end
            zc.createGrabMineInfoPop({
                area=self._areaIndex,
                mineId=_info.id,
                callback=refresh,
                goBattle=goBattle,
                popName = "GrabMineInfoPop",
            })
        end
    })
    --占领状态
    local stateList = {}
    for i = 1, 3 do
        local occupyState = zc.createSprite("res/Main/country/grabMine/occupy_1.png")
        occupyState:setPosition(self._occupyFlagJustPos[_info.tag].x+buildingButton:getContentSize().width/2+(i-2)*37, buildingButton:getContentSize().height+self._occupyFlagJustPos[_info.tag].y)
        buildingButton:addChild(occupyState, 1)
        stateList[i] = occupyState
    end
    buildingButton._stateList = stateList

    --name
    local nameBg = zc.getScaleNode("res/Main/role/common/shadow_bg.png", cc.size(130, 30))
    nameBg:setAnchorPoint(0.5, 0.5)
    nameBg:setPosition(buildingButton:getContentSize().width/2, 0)
    buildingButton:addChild(nameBg)
    buildingButton._nameBg = nameBg

    local nameLab = zc.createLabel({
        fontSize = 17,
        ap = cc.p(0.5, 0.5),
        pos = cc.p(nameBg:getContentSize().width/2, nameBg:getContentSize().height/2),
        color = cc.c3b(255,252,201),
    })
    nameBg:addChild(nameLab)
    buildingButton._nameLab = nameLab


    local _flag = zc.createSprite("res/Main/country/grabMine/occupyFlag_red.png")
    _flag:setAnchorPoint(0.5, 0.5)
    _flag:setPosition(_info.pos.x+self._flagJustPos[_info.tag].x, _info.pos.y+self._flagJustPos[_info.tag].y)
    self._buildingLayer:addChild(_flag,  _info.zorder+1 )
    _flag:setScale(self._iconScale)
    buildingButton._flag = _flag
    local _flagName = zc.createLabel({
        outLine = true,
        fontSize = 28,
        ap = cc.p(0, 0.5),
        pos = cc.p(_flag:getContentSize().width/2-15, _flag:getContentSize().height - 40),
        color = display.COLOR_WHITE,
        color2 = display.COLOR_BLACK,
        align = kCCTextAlignmentCenter,
        pixel = 1.3
    })
    _flag:addChild(_flagName)
    buildingButton._flagName = _flagName

    return buildingButton
end
--判断是否占领
function GrabMineMapSecondLayer:isOccupy(_data)
    if not _data then
        return false
    end
    for i = 1, 3 do
        if _data["userId"..i] and tonumber(_data["userId"..i]) and tonumber(_data["userId"..i]) > 0 then
            return true
        end
    end
    return false
end
function GrabMineMapSecondLayer:refreshUIState()
    self:refreshMineState()
    self:refreshLineState()
    self:refreshEmptyFalgState()
end
--刷新建筑状态
function GrabMineMapSecondLayer:refreshMineState()
    local selfCountryOccupy = PlayerData:getSelfCountryOccupy()
    local selfOccupyData = PlayerData:getSelfOccupyedMine() or {}
    local selfOccupyId = selfOccupyData[1] or 0

    for i = 1, self._buildingNums do
        local _mineData = self._secondMineInfo[i] or {}
        local _mineId = tonumber(_mineData.countryMineId) or 1

        local buildingBtnInfo = self._buildingList[_mineId]

        if buildingBtnInfo and buildingBtnInfo._btn and buildingBtnInfo._typeInfo then
            local _buildingButton = buildingBtnInfo._btn
            local _typeInfo = buildingBtnInfo._typeInfo
            local _normal = _buildingButton:getStateNormal()
            _buildingButton:stopAllActions()

            -- 判断是否被占领
            local _isOccupy = self:isOccupy(_mineData)

            if _isOccupy then
                _buildingButton._flag:setVisible(true)
                if selfCountryOccupy[_typeInfo.id] then
                    _buildingButton._flag:setTexture("res/Main/country/grabMine/occupyFlag_blue.png")
                else
                    _buildingButton._flag:setTexture("res/Main/country/grabMine/occupyFlag_red.png")
                end
                _buildingButton._nameBg:setVisible(true)
                _buildingButton._nameLab:setString(_mineData["countryName"])
                local _strName = _mineData["countryName"]
                _strName = string.sub(_strName,1,3)
                _buildingButton._flagName:setString(_strName)
                local _flagNameWidth =  _buildingButton._flagName:getContentSize().width or 0 --以汉字做为标准(宽度32)
                _buildingButton._flagName:setPositionX(_buildingButton._flag:getContentSize().width/2-15 - (_flagNameWidth-32)/2)
            else
                _buildingButton._nameBg:setVisible(false)
                _buildingButton._flag:setVisible(false)
            end

            local _stateList = _buildingButton._stateList or {}
            for i = 1, #_stateList do
                if _isOccupy then
                    _stateList[i]:setVisible(true)
                    if _mineData["userId"..i] and tonumber(_mineData["userId"..i]) > 0 then
                        _stateList[i]:setTexture("res/Main/country/grabMine/occupy_2.png")
                    else
                        _stateList[i]:setTexture("res/Main/country/grabMine/occupy_1.png")
                    end
                else
                    _stateList[i]:setVisible(false)
                end
            end

            --如果是自己占领的矿
            if selfOccupyId ~= 0 then
                if _typeInfo.id == selfOccupyId then
                    local eff_kuang = self._buildingLayer:getChildByName("self_eff_kuang")
                    if not eff_kuang then
                        eff_kuang = zc.createSpine({
                            fileName = "eff_kuang",
                            actName = "animation",
                            loop = true,
                            removeCallback = function() end
                        })
                        eff_kuang:setName("self_eff_kuang")
                        self._buildingLayer:addChild(eff_kuang, 0)
                    end
                    local _scale = self._eff_kuangInfo[_typeInfo.tag].scale or 1
                    local _jsutX = self._eff_kuangInfo[_typeInfo.tag].justx or 0
                    local _justY = self._eff_kuangInfo[_typeInfo.tag].justy or 0
                    eff_kuang:setPosition(_typeInfo.pos.x+_jsutX, _typeInfo.pos.y+_justY)
                    eff_kuang:setScale(_scale*self._iconScale)
                    eff_kuang:setLocalZOrder(_typeInfo.zorder-1)
                end
            end
        end
    end
    if not selfOccupyId or selfOccupyId == 0 then
        local self_eff_kuang = self._buildingLayer:getChildByName("self_eff_kuang")
        if self_eff_kuang then
            self_eff_kuang:removeFromParent()
        end
    end
end
--刷新空位旗子状态
function GrabMineMapSecondLayer:refreshEmptyFalgState()
    do return end
    local selfCountryOccupy = PlayerData:getSelfCountryOccupy()
    for i = 1, #self._emptyFlagList do
        local v = self._emptyFlagList[i]
        if v and v._flag and v._info then
            local _flag = v._flag
            local _info = v._info
            if selfCountryOccupy[_info.id] then
                _flag:setVisible(true)
            else
                _flag:setVisible(false)
            end
        end
    end    
end
--刷新路线状态
function GrabMineMapSecondLayer:refreshLineState()
    --自己国家占领的矿
    local selfCountryOccupy = PlayerData:getSelfCountryOccupy()
    for i = 1, #self._lineSpineList do
        local _lineSpine = self._lineSpineList[i]._spine
        local _actName = self._lineSpineList[i]._actNamePrefix
        local _oldState = self._lineSpineList[i]._oldState
        local _condition = self._lineSpineList[i]._condition

        local _from = _condition.from or {} --由什么而亮
        local _to = _condition.to or {} 

        if selfCountryOccupy[_from] then
            local endAct = "start"
            local _countryOccupyState = true
            for k,v in pairs(_to) do
                if v and type(v) == "number" then
                    if not selfCountryOccupy[v] then
                        _countryOccupyState = false
                        break
                    end
                end
            end
            if _countryOccupyState then
                endAct = "open"
            end
            if _oldState == "stop" then
                _lineSpine:playAction(_actName.."idle", false)
                self._lineSpineList[i]._oldState = "idle"
                _lineSpine:registerSpineEventHandler( function ( event )
                    if event.animation == _actName.."idle" then
                        _lineSpine:playAction(_actName..endAct, true)
                        self._lineSpineList[i]._oldState = endAct
                    end
                end, sp.EventType.ANIMATION_COMPLETE)
            else
                _lineSpine:playAction(_actName..endAct, true)
                self._lineSpineList[i]._oldState = endAct
            end
        else
            _lineSpine:playAction(_actName.."stop", true)
            self._lineSpineList[i]._oldState = "stop"
        end
    end
end
function GrabMineMapSecondLayer:onCleanup()
    if self._callback and type(self._callback) == "function" then
        self._callback()
    end

end
function GrabMineMapSecondLayer:onEnter( ... )
    if self._notInit then
        self:refreshFightTimes()
        local GrabMineMapFirstLayer = zc.getScene("GrabMineMapFirstLayer")
        if GrabMineMapFirstLayer then
            GrabMineMapFirstLayer:setNowFightState(false)
        end
    end
    self._notInit = true
end

return GrabMineMapSecondLayer