--[[
    FileName: GrabFoodRewardPop.lua
    Author: wangming
    Date: 2017-03-17
    Purpose: 抢粮成就奖励弹窗
]]
local GrabFoodRewardPop = class( "GrabFoodRewardPop", function ()
    return ZCPopLayer:create()
end)

function GrabFoodRewardPop:create(params)
    local _pop = GrabFoodRewardPop.new(params)
    _pop:show()
    return _pop
end

function GrabFoodRewardPop:ctor(params)
    self._achievement = params.achievement or {}
    self._nowNum = tonumber(params.nowNum) or 0

    self._status = 0

    local _bg = zc.createNormalPop({
        tag = 1,
        titleSrc = "res/Main/common/tipTitle/chengjiujiangli.png",
        bianZOrder = 1,
        height = 450, 
        width = 490,
    })
    _bg:setPosition(zc.width*0.5 ,zc.height*0.5)
    self:addContent(_bg)

    local _bgSize = _bg:getContentSize()
    local _close = zc.createBackButton({
        pos = cc.p(_bgSize.width - 10, _bgSize.height - 10),
        listener = function () 
            self:hide()
        end,
    })
    _bg:addChild(_close, 1)

    local _bottomBgSize = cc.size(455, 350)
    local _bottomBg = zc.createGeneralPopScale({
        tag = 3,
        width = _bottomBgSize.width,
        height = _bottomBgSize.height,
    })
    _bottomBg:setAnchorPoint(0.5, 0)
    _bottomBg:setPosition(_bgSize.width*0.5, 15)
    _bg:addChild(_bottomBg)


    local myTable = zc.ZCTableView:create(_bottomBgSize)
    myTable:setPosition(0, 0)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    _bottomBg:addChild(myTable)

    self._totalCount = table.nums(self._achievement)

    local _cellH = 145
    local function cellSizeForTable(table,idx)
        return _cellH, _bottomBgSize.width
    end

    local function numberOfCellsInTableView()
        return table.nums(self._achievement)
    end

    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(cc.size(_bottomBgSize.width, _cellH))

            local _di = zc.createSprite("res/Main/grabFood/cellDi.png")
            _di:setPosition(_bottomBgSize.width*0.5, _cellH*0.5)
            cell:addChild(_di)
            cell.di = _di
            local _diSize = _di:getContentSize()

            local _labelSize = cc.size(230, 30)
            local _nameDi = zc.getScaleNode("res/Main/role/common/name_bg.png", _labelSize)
            _nameDi:setAnchorPoint(0, 1)
            _nameDi:setPosition(20, _diSize.height - 8)
            _di:addChild(_nameDi)

            local _tipLabel = zc.createLabel({
                text = zc.lang("count_food_num_achieve"),
                color = cc.c3b(222, 153, 108),
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(5, _labelSize.height*0.5),
            })
            _nameDi:addChild(_tipLabel)

            local _numLabl = zc.createLabel({
                fontSize = 20,
                ap = cc.p(1, 0.5),
                pos = cc.p(_labelSize.width - 5, _labelSize.height*0.5),
            })
            _nameDi:addChild(_numLabl)
            cell.numLabl = _numLabl

            local _scrollView = zc.createScrollview({
                size = cc.size(_labelSize.width, 80),
                pos = cc.p(_nameDi:getPositionX(), 10),
            }) 
            _di:addChild(_scrollView)
            _scrollView:setSwallowTouches(false)
            cell.scrollView = _scrollView

            local _getBtn = zc.createCommomBtn({
                tag = 1,
                text = zc.lang("fetch_2"),
                pos = cc.p(360, 42),
                needEnableWhenMoving = true,
                needSwallow = false,
                endCallback = function() end,
            })
            _di:addChild(_getBtn)
            cell.getBtn = _getBtn

            local _getImg = zc.createSprite("res/Main/activity/monthSign/fetched.png")
            _getImg:setPosition(_getBtn:getPositionX(), _diSize.height*0.5)
            _di:addChild(_getImg)
            cell.getImg = _getImg

            local _nowNumLab = zc.createLabel({
                ap = cc.p(1, 0),
                fontSize = 24,
                outLine = true,
                pos = cc.p(_getBtn:getPositionX(), _getBtn:getPositionY() + 40)
            })
            _di:addChild(_nowNumLab)
            cell.nowNumLab = _nowNumLab

            local _maxNumLab = zc.createLabel({
                color = cc.c3b(246, 202, 148),
                fontSize = 24,
                outLine = true,
                ap = cc.p(0, 0),
                pos = cc.p(_getBtn:getPositionX(), _getBtn:getPositionY() + 40)
            })
            _di:addChild(_maxNumLab)
            cell.maxNumLab = _maxNumLab
        end

        local _status = tonumber(self._achievement[tostring(nowIdx)]) or 0 
        local _db = gameData.getDataFromCacheWithPrimaryKey("foodAchievement", nowIdx)
        cell.numLabl:setString(zc.getWan(_db.conditions))

        local _height = cell.scrollView:getContentSize().height
        local _partW = _height
        local _goodsInfo = string.split(_db.awards or "", ",")
        cell.scrollView:setInnerContainerSize(cc.size(#_goodsInfo*_partW, _height))
        cell.scrollView:removeAllChildren()
        for i = 1, #_goodsInfo do
            local _info = string.split(_goodsInfo[i] or "", "|")
            local _icon = zc.createIconByData({
                data = {
                    mainType = _info[1],
                    type = _info[2],
                    id = _info[2],
                    num = _info[3],
                },
                pos = cc.p(_partW*0.5 + (i - 1)*_partW, _height*0.5),
            })
            _icon:setScale(0.6)
            _icon:setTouchEndedShowTip()
            cell.scrollView:addChild(_icon)
        end

        cell.getImg:setVisible(_status == 2)
        cell.getBtn:setVisible(_status ~= 2)
        cell.maxNumLab:setVisible(_status ~= 2)
        cell.nowNumLab:setVisible(_status ~= 2)

        cell.maxNumLab:setString(zc.getWan(_db.conditions))
        cell.nowNumLab:setString(zc.getWan(self._nowNum) .. "/")
        if _status == 0 then
            cell.nowNumLab:setColor(display.COLOR_RED)
            cell.getBtn:setEnable(false)
            cell.getBtn:setText(zc.lang("un_achieve"))
        elseif _status == 1 then
            self._status = 1
            cell.nowNumLab:setColor(display.COLOR_GREEN)
            cell.getBtn:setEnable(true)
            cell.getBtn:setText(zc.lang("fetch_2"))
            cell.getBtn:setTouchEndedCall(function()
                zc.sendHttp({
                    apiName = "GrabFood_getAchievement",
                    params = {id = nowIdx},
                    successCallback = function(backData)
                        backData.noAnimation = true
                        PlayerData:updataData(backData)
                        zc.createShowReward(backData)
                        self._status = 0

                        self._achievement = backData.achievement or {}
                        self._myTableview:reloadDataAndScrollToCurrentCell()
                    end,
                })
            end)
        end

        if nowIdx == self._totalCount then
            PlayerData:updateRedDotData(3, self._status)
            zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_FOODSRED, data = {}})
        end
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    myTable:reloadData()
    self._myTableview = myTable

end

function GrabFoodRewardPop:onEnter()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_14611 then
        local function _callBack()
            getGuideManager():setFuncGuideOver()
        end
        getGuideManager():setHeroFuncCallBack(_callBack)
        getGuideManager():startGuide()
    end
end


return GrabFoodRewardPop