--[[
FileName 		HouseSpriteBase.lua
ProjectName		HJ2

Created by wangming on 16-06-15
    
]]

local HouseEntityPop = class("HouseEntityPop", function()
	return ZCDialog:create(0)
end)

function HouseEntityPop:create( build )
	local _pop = HouseEntityPop.new(build)
	_pop:playOpenAnimate()
	return _pop
end

function HouseEntityPop:onCleanup()
    if self._build then
        if self._build:getHouseId() ~= 0 and not self._build:isResourcesBuild() then
            if self._build._clickAction then
                self._build:stopAction(self._build._clickAction)
            end
            self._build._clickAction = nil
            self._build:setColor(cc.c3b(255, 255, 255))
        end

        if self._build._mainCity.taskLayer then
            self._build._mainCity.taskLayer:checkGuideHand(true)
        end
        self._build._mainCity:checkShowFuben()
    end
    self:removeAllChildren()
    if self._isOver then
        return
    end
    self._isOver = true
    self:resetAll()
end

function HouseEntityPop:ctor( build )
    self:setTouchEndedCallback(function()
        if self._isPlaying then
            return
        end
        self:playRetractAnimate()
    end)
    cc.SpriteFrameCache:getInstance():addSpriteFrames("res/Main/home/homeUI.plist", "res/Main/home/homeUI.pvr.ccz")
	self._build = build
    self._mainCity = zc.getScene("mainCity")
    self._bottomButtonList = {}

    local _di = zc.getScaleNode("house_entityDi.png", cc.size(zc.width, 88), true)
    _di:setAnchorPoint(0.5, 0)
    _di:setPosition(zc.width*0.5, 0)
    self:addChild(_di)

   	self:initBtns()
    table.sort(self._bottomButtonList, function( a, b )
        return a:getPositionX() > b:getPositionX()
    end)
    local _partX = 137


    --英雄试炼这个需要改下位置，太多了
    if #self._bottomButtonList > 8 then
        _partX = 137*0.9
    end

    local _startX = zc.width*0.5 + (#self._bottomButtonList - 0.5) * _partX * 0.5 - 30
    for i=1, #self._bottomButtonList do
        local _btn = self._bottomButtonList[i]
        self:reorderChild(_btn, 1)
        _btn:setPositionX(_startX - (i - 1) * _partX)
        if i ~= #self._bottomButtonList then
            local _pic = zc.getSprite({
                src = "res/Main/home/house_entityBtnDi.png",
                pos = cc.p(_btn:getPositionX() - _partX*0.5, _btn:getPositionY()),
            })
            self:addChild(_pic, 2)
        end
    end

    if self._build then
        if self._build:getHouseId() == 0 or self._build:isResourcesBuild() then
            return
        end
        if self._build._clickAction then
            self._build:stopAction(self._build._clickAction)
        end
        self._build:setColor(cc.c3b(255, 255, 255))
        self._build._clickAction = cc.RepeatForever:create(cc.Sequence:create(
            cc.TintTo:create(0.6, 150, 150, 150),
            cc.TintTo:create(0.6, 255, 255, 255)
        ))
        self._build:runAction(self._build._clickAction)
    end
end

function HouseEntityPop:initBtns()
 	local _build = self._build
	local _houseId, _level = _build:getHouseIdAndLevel()
    local _status = _build._houseData and _build._houseData.status or 0
    local justX, justY = zc.width*0.5, 80
	local _flag, _SpeedUpPropList = zc.judgeHouseSpeedUpProp()
    local function _createStatus1( haveSpeedBtn )
        local _have = haveSpeedBtn == nil and true or haveSpeedBtn
        -- 详情
        local _detailBtn = self:getDetailBtn()
        _detailBtn:setPosition(-80 + justX, justY)

        if _have then
            -- 道具加速
            local _tspeedBtn = self:getTSpeedBtn()
            _tspeedBtn:setPosition(justX, justY)
            -- 元宝加速
            local _gspeedBtn = self:getGSpeedBtn()
            _gspeedBtn:setPosition(80 + justX, justY)
        end
    end

    local _flag = self:isBuildingFullFevel(_houseId, _level)
    local function _createNormal(haveSpeedBtn, haveUpLevel)
        local _have = haveSpeedBtn == nil and true or haveSpeedBtn
        local _have2 = haveUpLevel == nil and true or haveUpLevel
        if _have then
            -- 道具加速
            local _tspeedBtn = self:getTSpeedBtn()
            _tspeedBtn:setPosition(0, justY)

            -- 元宝加速
            local _gspeedBtn = self:getGSpeedBtn()
            _gspeedBtn:setPosition(55 + justX, justY)
        end

        -- 详情
        local _detailBtn = self:getDetailBtn()
        _detailBtn:setPosition(-90 + justX, justY)
        
        if _have2 and not _flag then
            -- 升级
            local _upLevelBtn = self:getUpLevelBtn()
            _upLevelBtn:setPosition(justX, justY)
        end

        -- 帮助
        local _str_text = zc.lang("enter")
        local _str_img = "home_icon_enter.png"
        if _build:isResourcesBuild() then
            if self._build._isSpeeding then
                _str_text = zc.lang("speed_up_left")
            else
                _str_text = zc.lang("speed_up")
            end
            _str_img = "home_icon_speed.png"
        elseif _houseId == 8 then
            _str_text = zc.lang("go_train")
        elseif _houseId == 9 then
            _str_text = zc.lang("go_recruit")
        elseif _houseId == 11 then
            _str_text = zc.lang("god_weapon")
            _str_img = "home_icon_godWeapon.png"
        elseif _houseId == 14 then
            _str_text = zc.lang("bingfa")
            _str_img = "home_icon_book.png"
        elseif _houseId == 15 then
            _str_text = zc.lang("multi_copy")
            _str_img = "home_icon_enter.png"
        end
        local _helpBtn = self:getHelpBtn(_str_text, _str_img)
        _helpBtn:setPosition(90 + justX, justY)   
    end

    --具体建筑单独处理
    local function _doUpingNormal()
        _createNormal(true, false)
        self._DetailsButton:setPosition(-115 + justX, justY)
        self._speedUpPopButton:setPosition(-40 + justX, justY)
        self._speedUpButton:setPosition(40 + justX, justY)
        self._HelpButton:setPosition(115 + justX, justY)
    end

    local function _doNormal(isCheckFlag, haveNoUp )
        local _haveNoUp = haveNoUp == nil and false or haveNoUp
        local _check = isCheckFlag == nil and true or false
        local _createFlag = (not _check or not _flag) and false or true
        if _haveNoUp then
            _createFlag = false
        end
        _createNormal(false, _createFlag)
        if not _createFlag then 
            self._DetailsButton:setPosition(-50 + justX, justY)
            self._HelpButton:setPosition(40 + justX, justY)
        end
        if helpName and self._HelpButton then
            self._HelpButton:getChildren()[1]:setString(helpName)
        end
    end

    if _houseId == 0 then
        local _buildInfos = {6, 7}
        for i=1, #_buildInfos do
            local _typeId = _buildInfos[i]
            local _num, _limit = self:getHouseBuildLimit(_typeId)
            local _btn = self:getBtnByInfo({
                text = LANGUAGE_getHouseNameById(_typeId) .. " " .. _num .. "/" .. _limit,
                callback = function () 
                    if _num == _limit then
                        return
                    end
                    local _currentGID = getGuideManager():getCurrentGID()
                    if _currentGID == GuideKey.KEY_6014 
                      or _currentGID == GuideKey.KEY_6017 then
                        zc.setGuideFuncNextStep(_currentGID, false)
                    end
                    local _build = self._build
                    zc.showEntityTouchPop()
                    _build:showButtonAction(3, _typeId)
                end,
                icon = i == 1 and "home_icon_wood.png" or "home_icon_mineral.png",
            })
            _btn:setPosition(0 + justX + justY, justY)
            if _num == _limit then
                _btn:setEnable(false)
            end
            local _currentGID = getGuideManager():getCurrentGID()
            if _typeId == 6 and _currentGID == GuideKey.KEY_6014 then
                self:enterHouseGuideFunc(_btn)
            elseif _typeId == 7 and _currentGID == GuideKey.KEY_6017 then
                self:enterHouseGuideFunc(_btn)
            elseif _typeId == 6 and _currentGID == GuideKey.KEY_OVER then
                local datas = PlayerData:getTaskData()[1] or {}
                for k,v in pairs(datas) do
                    if v.taskId == GuideTask33Key then
                        local _guideHand = zc.createSpine({
                            fileName = "shou",
                            actName = "shou",
                        })
                        _guideHand:setScale(0.8)
                        _guideHand:setPosition(cc.pMul(cc.pFromSize(_btn:getContentSize()), 0.5))
                        _btn:addChild(_guideHand, 10)
                        break
                    end
                end
            end
        end
    elseif _houseId == 1 then--主城
        if _status == 1 then
            _createStatus1(false)
        elseif _status == 2 then
            _doUpingNormal()
        else
            _doNormal()        
        end
        self:getFetterRegionalMapBtn()    
        self:freshBtnPos(self._fetterRegionalMap, cc.p(185 + justX, justY))
        self:freshBtnPos(self._HelpButton, cc.p(190 + justX, justY))
        self:enterHouseGuideFunc(self._HelpButton)
    elseif _houseId == 3 then   --码头
        if _status == 1 then
            _createStatus1()
        elseif _status == 2 then
            _doUpingNormal()
        else
            _doNormal()
        end
        --新手引导
        self:enterHouseGuideFunc(self._HelpButton)
    elseif _houseId == 4 then   --传承塔
        if _status == 1 then
            _createStatus1(false)
        else
            _doNormal(false, true)
        end
        --新手引导
        self:enterHouseGuideFunc(self._HelpButton)
    elseif _houseId == 8 then   --校场
        if _status == 2 then
            _doUpingNormal()

        elseif _status == 1 then
            _createStatus1()
        else
            _doNormal()
        end
        --新手引导
        self:enterHouseGuideFunc(self._HelpButton)
    elseif _houseId == 9 then   --酒馆       
        if _status == 2 then
            _createNormal(true, false)
            self:getGenralManualBtn()
            self._DetailsButton:setPosition(-150 + justX, justY)
            self._speedUpPopButton:setPosition(-80 + justX, justY)
            self._speedUpButton:setPosition(0 + justX, justY)
            self:freshBtnPos(self._genralManualBtn, cc.p(80 + justX, justY))
            self._HelpButton:setPosition(150 + justX, justY)
        elseif _status == 1 then
            _createStatus1()
        else
            _createNormal(false, not _flag)
            self:getGenralManualBtn()
            if _flag then
                self._DetailsButton:setPosition(-90 + justX, justY)
                self:freshBtnPos(self._genralManualBtn, cc.p(0 + justX, justY))
                self._HelpButton:setPosition(90 + justX, justY)
            else
                self._DetailsButton:setPosition(-115 + justX, justY)
                self:freshBtnPos(self._UpgradeButton, cc.p(-40 + justX, justY))
                self:freshBtnPos(self._genralManualBtn, cc.p(40 + justX, justY))
                self._HelpButton:setPosition(115 + justX, justY)
            end
        end
        --新手引导
        local _currentGID = getGuideManager():getCurrentGID()
        if _currentGID == GuideKey.KEY_14403 then
            self:enterHouseGuideFunc(self._genralManualBtn)
        else
            self:enterHouseGuideFunc(self._HelpButton)
        end
    elseif _houseId == 10 then  --贸易  
        if _status == 1 then
            _createStatus1(false)
        else
            _doNormal(false, true)
            self:getSoulFeteBtn()
            self:freshBtnPos(self._soulFete, cc.p(0 + justX, justY))
            self:freshBtnPos(self._HelpButton, cc.p(90 + justX, justY))
        end
        --新手引导
        self:enterHouseGuideFunc(self._soulFete)
    elseif _houseId == 11 then  --铁匠铺
        if _status == 2 then
            _doUpingNormal()
            self:getSmithyClearBtn()
            self:getSmithyBookBtn()
            self:getWeaponCastBtn()
            self:getMakeBtn()

            self:freshBtnPos(self._make, cc.p(190 + justX, justY)) --打造
            self:freshBtnPos(self._smithyClear, cc.p(185 + justX, justY))
            self:freshBtnPos(self._smithyBook, cc.p(195 + justX, justY))
            self:freshBtnPos(self._HelpButton, cc.p(200 + justX, justY))
            self:freshBtnPos(self._weaponCastBtn, cc.p(210 + justX, justY))
        elseif _status == 1 then
            _createStatus1()
        else
            _doNormal()
            self:getSmithyClearBtn()
            self:getSmithyBookBtn()
            self:getWeaponCastBtn()
            self:getMakeBtn()

            self:freshBtnPos(self._make, cc.p(190 + justX, justY)) --打造
            self:freshBtnPos(self._smithyClear, cc.p(185 + justX, justY))
            self:freshBtnPos(self._smithyBook, cc.p(195 + justX, justY))
            self:freshBtnPos(self._HelpButton, cc.p(200 + justX, justY))
            self:freshBtnPos(self._weaponCastBtn, cc.p(210 + justX, justY))
        end
        --新手引导
        local _currentGID = getGuideManager():getCurrentGID()
        print("_currentGID .....: " .. _currentGID)
        if _currentGID == GuideKey.KEY_11202 then
            self:enterHouseGuideFunc(self._smithyBook)
        elseif inArray(_currentGID, GuideGroup.BTN_JINRU) then
            self:enterHouseGuideFunc(self._HelpButton)
        elseif _currentGID == GuideKey.KEY_14904 then
            self:enterHouseGuideFunc(self._make)
        elseif _currentGID == GuideKey.KEY_15104 then
            self:enterHouseGuideFunc(self._HelpButton)
            -- 可能得设置下一步吧。。。
        end
    elseif _houseId == 12 then  --商店
        if _status == 1 then
            _createStatus1(false)
        else
            _doNormal(false, true)
        end
    elseif _houseId == 13 then  -- 演武榜
        if _status == 1 then
            _createStatus1()
        elseif _status == 2 then
        else
            _doNormal(false, true)
            self:getGodFightBtn()
            self:freshBtnPos(self._godFight, cc.p(190 + justX, justY))
            self:freshBtnPos(self._HelpButton, cc.p(200 + justX, justY))
            local _currentGID = getGuideManager():getCurrentGID()
            print("_currentGID : ")
            if _currentGID == GuideKey.KEY_12211 then
                self:enterHouseGuideFunc(self._HelpButton)
            elseif _currentGID == GuideKey.KEY_14503 then
                self:enterHouseGuideFunc(self._godFight)
            end
        end
    elseif _houseId == 14 then --研究院
        local function _checkHelp()
            if zc.getFunctionStatus(20) then
               return
            end
            for k,v in pairs(self._bottomButtonList) do
                if v == self._HelpButton then
                    table.remove(self._bottomButtonList, k)
                    break
                end
            end
            self._HelpButton:removeFromParent()
            self._HelpButton = nil  
        end
        if _status == 1 then
            _createStatus1()
            _checkHelp()
        elseif _status == 2 then
            _createNormal(true, false)
            _checkHelp()
            self:getQunTower()
            self:getSmithyPracticeBtn()

            self._DetailsButton:setPosition(-150 + justX, justY)
            self._speedUpPopButton:setPosition(-80 + justX, justY)
            self._speedUpButton:setPosition(0 + justX, justY)
            self:freshBtnPos(self._smithyPractice, cc.p(190 + justX, justY))
            self:freshBtnPos(self._HelpButton, cc.p(80 + justX, justY))
            self:freshBtnPos(self._qunxiong, cc.p(150 + justX, justY))
        else
            _createNormal(false, not _flag)
            _checkHelp()
            self:getSmithyPracticeBtn()
            self:getQunTower()
            self._DetailsButton:setPosition(-115 + justX, justY)
            self:freshBtnPos(self._smithyPractice, cc.p(190 + justX, justY))
            self:freshBtnPos(self._UpgradeButton, cc.p(-40 + justX, justY))
            self:freshBtnPos(self._HelpButton, cc.p(40 + justX, justY))
            self:freshBtnPos(self._qunxiong, cc.p(115 + justX, justY))
        end
        local _currentGID = getGuideManager():getCurrentGID()
        if _currentGID == GuideKey.KEY_12505 then
            self:enterHouseGuideFunc(self._qunxiong)
        else
            self:enterHouseGuideFunc(self._HelpButton)
        end
    elseif _houseId == 15 then --中间人物副本建筑
        local function _checkHelp()
            if not APP_REVIEW and zc.getFunctionStatus(19) then
               return
            end
            for k,v in pairs(self._bottomButtonList) do
                if v == self._HelpButton then
                    table.remove(self._bottomButtonList, k)
                    break
                end
            end
            self._HelpButton:removeFromParent()
            self._HelpButton = nil  
        end
        if _status == 1 then
            _createStatus1()
            _checkHelp()
        elseif _status == 2 then   --2 正在升级中
            _createNormal(true, false)
            _checkHelp()
            self:getWuTowerBtn()
            self:getMingTowerBtn()
            self:getWeaponCopyBtn()
            self:getLimitChallengeCopyBtn()
            self:getHeroCopyBtn()

            self._DetailsButton:setPosition(-185 + justX, justY)
            self._speedUpPopButton:setPosition(-115 + justX, justY)
            self._speedUpButton:setPosition(-40 + justX, justY)

            self:freshBtnPos(self._HelpButton, cc.p(40 + justX, justY))
            self:freshBtnPos(self._wushenTower, cc.p(70 + justX, justY))
            self:freshBtnPos(self._tollgateHeroTower, cc.p(115 + justX, justY))
            self:freshBtnPos(self._weponCopy, cc.p(185+75 + justX, justY))
            self:freshBtnPos(self._limitChallenge, cc.p(195+75 + justX, justY))
            self:freshBtnPos(self._HeroCopy, cc.p(225+75 + justX, justY))
        else
            _createNormal(false, not _flag)
            _checkHelp()
            self:getWuTowerBtn()
            self:getMingTowerBtn()
            self:getWeaponCopyBtn()
            self:getLimitChallengeCopyBtn()
            self:getHeroCopyBtn()
            self._DetailsButton:setPosition(-150 + justX, justY)

            self:freshBtnPos(self._UpgradeButton, cc.p(-80 + justX, justY))
            self:freshBtnPos(self._HelpButton, cc.p(0 + justX, justY))
            self:freshBtnPos(self._wushenTower, cc.p(80 + justX, justY)) 
            self:freshBtnPos(self._tollgateHeroTower, cc.p(150 + justX, justY))
            self:freshBtnPos(self._weponCopy, cc.p(75+150 + justX, justY))
            self:freshBtnPos(self._limitChallenge, cc.p(195+75 + justX, justY))
            self:freshBtnPos(self._HeroCopy, cc.p(225 + 75 + justX, justY))
        end
        --新手引导
        local _currentGID = getGuideManager():getCurrentGID()
        print("_currentGID" .. _currentGID)
        if _currentGID == GuideKey.KEY_12303 then
            self:enterHouseGuideFunc(self._wushenTower)
        elseif _currentGID == GuideKey.KEY_11605 then
            self:enterHouseGuideFunc(self._tollgateHeroTower)
        elseif _currentGID == GuideKey.KEY_13203 then
            self:enterHouseGuideFunc(self._weponCopy)
        elseif _currentGID == GuideKey.KEY_13903 then
            self:enterHouseGuideFunc(self._limitChallenge)
        elseif _currentGID == GuideKey.KEY_15004 then
            self:enterHouseGuideFunc(self._HeroCopy)
        else
            self:enterHouseGuideFunc(self._HelpButton)
        end
    elseif _houseId == 16 then --市政  
        if _status == 2 then
            _doUpingNormal()
        elseif _status == 1 then
            _createStatus1()
        else
            _doNormal()
        end
        --新手引导
        self:enterHouseGuideFunc(self._HelpButton)
    elseif _build:isResourcesBuild() then
        --可收获资源类建筑  
        if _status == 2 or _status == 1 then
            _createStatus1() 
        else
            _createNormal(false)
            local _chaiBtn = self:getBtnByInfo({
                text = zc.lang("dismantle"),
                callback = function () 
                    local comfirm = ZCConfirmDialog:createWithParams({
                        title = zc.lang("prompt"),
                        msg = zc.lang("tips_sure_to_dismantle_house"),
                        showDi = true,
                        rightCallback = function()
                            zc.sendHttp({
                                apiName = "House_removal",
                                params = {id = _build._houseData.id},
                                successCallback = function() 
                                    _build:cleanHouse()
                                    getGuideManager():removeMaskLayer()
                                end,
                            })
                        end
                    })
                    self:addChild(comfirm, 10)
                end,
                icon = "home_icon_build.png",
            })
            self._HelpButton:setPositionX(-120 + justX)
            self._DetailsButton:setPositionX(-40 + justX)
            _chaiBtn:setPosition(40 + justX, justY)
            self:freshBtnPos(self._UpgradeButton, cc.p(120 + justX, justY))
        end
    end 
end

-- 展开动画
function HouseEntityPop:playOpenAnimate()
    self._isPlaying = true
    local _maskLayer = getGuideManager():getMaskLayer()
    self:addChild(_maskLayer, 10)
    local function callback()
        self._isPlaying = false
        _maskLayer:removeFromParent()
    end

    local _totleTime = 0.3
    for k,v in pairs(self._bottomButtonList) do
        local _scale_1 = cc.ScaleTo:create(0.1, 1.3)
        local _scale_2 = cc.ScaleTo:create(0.1, 0.8)
        local _scale_3 = cc.ScaleTo:create(0.1, 1.0)
        if table.nums(self._bottomButtonList) > 8 then
            _scale_3 = cc.ScaleTo:create(0.1, 0.9)
        end
        local _time = k/20
        _totleTime = _totleTime + _time
        local _delayTime = cc.DelayTime:create(_time)

        if k == #self._bottomButtonList then
            v:runAction(cc.Sequence:create(_delayTime, _scale_1, _scale_2, _scale_3, cc.CallFunc:create(callback)))
        else
            v:runAction(cc.Sequence:create(_delayTime, _scale_1, _scale_2, _scale_3))
        end
    end

    local _chatSp = self._mainCity.chatLayer
    if self._chatAction then
        _chatSp:stopAction(self._chatAction)
        self._chatAction = nil
    end
    _chatSp:setPositionY(5)
    self._chatAction = cc.Sequence:create(
        cc.MoveBy:create(0.3, cc.p(0, -300)),
        cc.CallFunc:create(function()
            _chatSp:setVisible(false)
            self._chatAction = nil
        end)
    )
    _chatSp:runAction(self._chatAction)
    local _bottomButtonLay = self._mainCity._bottomButtonLay
    _bottomButtonLay:stopAllActions()
    _bottomButtonLay:runAction(cc.Sequence:create(
        cc.MoveBy:create(0.3, cc.p(0, -200)),
        cc.CallFunc:create(function()
            _bottomButtonLay:setVisible(false)
        end)
    ))
end

function HouseEntityPop:resetAll( isAction )
    local _time = 0.2
    local _chatSp = self._mainCity.chatLayer
    if _chatSp then
        if self._chatAction then
            _chatSp:stopAction(self._chatAction)
        end
        _chatSp:setVisible(true)
        if isAction then
            _chatSp:setPositionY(5 - 300)
            self._chatAction = cc.MoveBy:create(_time, cc.p(0, 300))
            _chatSp:runAction(self._chatAction)
        else
            _chatSp:setPositionY(5)
        end
    end
    self._chatAction = nil

    local _bottomButtonLay = self._mainCity._bottomButtonLay
    if _bottomButtonLay then
        _bottomButtonLay:stopAllActions()
        _bottomButtonLay:setVisible(true)
        if isAction then
            _bottomButtonLay:setPositionY(0 - 200)
            _bottomButtonLay:runAction(cc.MoveBy:create(_time, cc.p(0, 200)))
        else
            _bottomButtonLay:setPositionY(0)
        end
    end
end

--功能按钮收起动画
function HouseEntityPop:playRetractAnimate( isNow )
    local function callback()
        if self._isOver then
            return
        end
        self._isOver = true
        self:resetAll()
	    zc.showEntityTouchPop()
    end
    if isNow then
        callback()
        return
    end
    if self._isPlaying then
        return
    end
    local _maskLayer = getGuideManager():getMaskLayer()
    self:addChild(_maskLayer, 10)
    self._isPlaying = true

    local num = #self._bottomButtonList + 1
    for k,v in pairs(self._bottomButtonList) do
        local _scale_1 = cc.ScaleTo:create(0.1, 1.3)
        local _scale_3 = cc.ScaleTo:create(0.1, 1.0)
        local _scale_4 = cc.ScaleTo:create(0.1, 0.0)

        local _delayTime = cc.DelayTime:create((num-k)/20)
        if k == #self._bottomButtonList then
            v:runAction(cc.Sequence:create(_delayTime,_scale_1,_scale_3,_scale_4,cc.CallFunc:create(callback)))
        else
            v:runAction(cc.Sequence:create(_delayTime,_scale_1,_scale_3,_scale_4))
        end
    end

    self:resetAll(true)
end

--进入具体功能页面
function HouseEntityPop:enterThisView()
    --新手引导
    local _currentGID = getGuideManager():getCurrentGID()
    if inArray(_currentGID, GuideGroup.BTN_JINRU) then
        zc.setGuideFuncNextStep(_currentGID, false)
    end

	local _houseId = self._build:getHouseId()
	local _houseData = self._build._houseData
	zc.showEntityTouchPop()
	if _houseId == 1 then       --主城
        zc.createTalentScene()
	-- elseif _houseId == 3 then   --码头
 --        --zc.tipInfo(zc.lang("tips_function_not_open","功能未开启"))
 --        zc.createWharfScene()
	elseif _houseId == 4 then   --传承塔
        zc.createInheritanceTowerLayer()
	elseif _houseId == 8 then   --校场
        zc.createDrillFieldLayer()
	elseif _houseId == 9 then   --酒馆
        zc.createCardExtract()
	elseif _houseId == 10 then  --贸易
        zc.createHeroSoul()
	elseif _houseId == 11 then  --铁匠铺
        zc.createSmithGodWeaponLayer()
    elseif _houseId == 12 then  --仓库
        zc.createShopLayer()
    elseif _houseId == 13 then  --演武榜
        zc.createArenaScene()
    elseif _houseId == 14 then  --研究院
        zc.createResearchBingFa()
    elseif _houseId == 15 then  --多人副本
        zc.createMultiCopyMainScene()
    elseif _houseId == 16 then  --征收
       --征收入口
       zc.createLevy(_houseData)
	end
end

-- 检查提速状态
function HouseEntityPop:checkSpeedTimeState( _btn )
	if not self._build:isResourcesBuild() then
		return
	end
    if not _btn._di then
        _btn._di = zc.getSprite({
            src = "house_entityResDi.png",
            plist = true,
            ap = cc.p(0.5, 0),
            pos = cc.p(_btn:getContentSize().width*0.5, 0),
        })
        _btn:addChild(_btn._di)
    end
    local _size = _btn._di:getContentSize()


	local function setSpeedState()
        -- _btn:setString("提速")
        local _price, _type = 0, 1
        local priceTa = gameData.getDataFromCacheWithPrimaryKey("consume_price", (103 + self._build._houseData.level) or 133)
	    if priceTa and priceTa.price then
	        _price = priceTa.price
	    end
        local consumeImg = zc.createSprite(zc.getImgByType(_type))
        consumeImg:setAnchorPoint(0, 0.5)
        _btn._di:addChild(consumeImg)
        consumeImg:setScale(0.8)
        local consumeLab = zc.createLabel({
            text = _price or "",
            outLine = true,
            fontSize = 18,
            ap = cc.p(0, 0.5),
        })
        _btn._di:addChild(consumeLab)
        
        local _totleWith = consumeImg:getContentSize().width + consumeLab:getContentSize().width
        consumeImg:setPosition(_size.width*0.5 - _totleWith*0.5, _size.height*0.5)
        consumeLab:setPosition(consumeImg:getPositionX() + consumeImg:getContentSize().width, consumeImg:getPositionY())
    end

	if not self._build._isSpeeding then --正在加速
        setSpeedState()
		return
	end

    -- _btn:setString("提速还剩")
    local _speedTime = self._build:getSurplusTime()
    local _speedTimeLab = zc.createLabel({
        fontSize = 18,
        outLine = true,
        pos = cc.pMul(cc.pFromSize(_size), 0.5),
    })
    _btn._di:addChild(_speedTimeLab)

    local function _doSpeed(_sTime)
        local _day = math.floor(_sTime/(24*60*60))
        local _hour = math.floor((_sTime)/(60*60))
        local _minute = math.floor(_sTime/(60))
        local _second = _sTime
        local _speedStr = ""
        if _day > 0 then
            _speedStr = _day.. zc.lang("date_day")
        elseif _hour > 0 then
            _speedStr = _hour..zc.lang("date_hours")
        elseif _minute > 0 then
            _speedStr = _minute..zc.lang("date_minute")
        elseif _second > 0 then
            _speedStr = _second..zc.lang("date_seconds")
        end
        _speedTimeLab:setText(_speedStr)
    end
    _doSpeed(_speedTime)
    schedule(_speedTimeLab,function()
        _speedTime = _speedTime - 1
        _doSpeed(_speedTime)
        if _speedTime <= 0 then
            self._build._isSpeeding = false
            _speedTimeLab:removeFromParent()
            setSpeedState()
        end
    end, 1.0)
end


------------------------------------创建各种按钮-----------------------------------
--[[
	{
		img1 = 按钮图1, 
		img2 = 按钮图2,
		text = 按钮文字,
		callback = 点击回调,
        icon = 按钮icon,
        iconPos = 按钮icon位置,
	}
]]
function HouseEntityPop:getBtnByInfo( info )
	local _btn = zc.createPushButton({
        normalFile = "house_entityDi_normal.png",
        selectedFile = "house_entityDi_selected.png",
        disableFile = "house_entityDi_disable.png",
        text = info.text,
        plist = true,
        outLine = true,
        fontColor = cc.c3b(255, 203, 0),
        fontColor2 = cc.c3b(63, 5, 19),
        fontSize = 20,
        needEnableWhenMoving = true,
        -- text_pos = cc.p(75, 40),
        endCallback = info.callback,
    })
    local _label = _btn:getLabel()
    if _label then
        _label:setPosition(_btn:getContentSize().width*0.5, 40)
    end
    
    if info.icon then
        local _flag = info.plist == nil and true or info.plist
        local _func = _flag and zc.createSpriteWithFrameName or zc.createSprite
	    local _icon = _func(info.icon)
        _icon:setPosition(_btn:getContentSize().width*0.5, _btn:getContentSize().height*0.5 + 10)
	    _btn:addChild(_icon)
	end

	_btn:setScale(0)
	self:addChild(_btn)
    local _insert = info.insert == nil and true or info.insert
    if _insert then
        table.insert(self._bottomButtonList, _btn)
    end
	return _btn
end

-- 详情
function HouseEntityPop:getDetailBtn()
	local _btn = self:getBtnByInfo({
		text = zc.lang("details"),
		callback = function () 
			local _build = self._build
			zc.showEntityTouchPop()
            _build:showButtonAction()
        end,
        icon = "home_icon_info.png",
	})
    self._DetailsButton = _btn
    return _btn
end

-- 道具加速
function HouseEntityPop:getTSpeedBtn()
	local _btn = self:getBtnByInfo({
		text = zc.lang("prop_speed_up"),
		callback = function () 
            --跳转加速道具选择界面
			local _build = self._build
			zc.showEntityTouchPop()
            _build:showButtonAction(2)
        end,
        icon = "home_icon_speedUp.png",
	})
	self._speedUpPopButton = _btn
    return _btn
end

-- 元宝加速
function HouseEntityPop:getGSpeedBtn()
	local _btn = self:getBtnByInfo({
		text = zc.lang("finish"),
		callback = function () 
            --跳转加速道具选择界面
            local _build = self._build
            zc.showEntityTouchPop()
            zc.sendHttp({
                apiName = "House_accelerate",
                params = {id = _build._houseData.id, type = 2, itemId = 0, itemNum = 0},
                successCallback = function (data) 
            		-- 加速完成
                    PlayerData:updataData(data)
                    PlayerData:updateHouseInfo(data)
                    PlayerData:setCurBuildingInfo(data.queueInfo)
                    _build:updateHouseData(data)
                    _build:updateHouseTime()
            	end,
            })
        end,
        icon = "res/Main/common/common_icon_gold.png",
        plist = false,
	})
	--加速话费
    local _gold_num = self._build:getGoldNumSpeedHouse()
    _btn._di = zc.getSprite({
        src = "house_entityResDi.png",
        plist = true,
        ap = cc.p(0.5, 0),
        pos = cc.p(_btn:getContentSize().width*0.5, 0),
    })
    _btn:addChild(_btn._di)
    local _size = _btn._di:getContentSize()

    local consumeImg = zc.createSprite(zc.getImgByType(zc.dataTypeGold))
    consumeImg:setAnchorPoint(0, 0.5)
    _btn._di:addChild(consumeImg)
    consumeImg:setScale(0.8)
    local consumeLab = zc.createLabel({
        text = tostring(_gold_num),
        outLine = true,
        fontSize = 18,
        ap = cc.p(0, 0.5),
        color = display.COLOR_GOLD
    })
    _btn._di:addChild(consumeLab)
    self._gold_num_label = _gold_num_label
    
    local _totleWith = consumeImg:getContentSize().width + consumeLab:getContentSize().width
    consumeImg:setPosition(_size.width*0.5 - _totleWith*0.5, _size.height*0.5)
    consumeLab:setPosition(consumeImg:getPositionX() + consumeImg:getContentSize().width, consumeImg:getPositionY())

    self._speedUpButton = _btn
    return _btn
end

-- 升级
function HouseEntityPop:getUpLevelBtn()
	local _btn = self:getBtnByInfo({
		text = zc.lang("upgrade"),
		callback = function () 
			local _build = self._build
			zc.showEntityTouchPop()
            _build:showButtonAction(1)
        end,
        icon = "home_icon_upgrade.png",
	})
	self._UpgradeButton = _btn
	return _btn
end

-- 帮助
function HouseEntityPop:getHelpBtn(_str_text, _str_img)
	local function _call()
		if self._build._isSpeeding then
            return
        end 
        local _build = self._build
        if not _build:isResourcesBuild() then
            self:enterThisView()
        	return 
        end
        zc.showEntityTouchPop()
        local function doSpeeding(data)
            PlayerData:updataData(data)
            _build._houseData["info"]["lastFlushTime"]            = data["lastFlushTime"]
            _build._houseData["info"]["yieldAccelerateType"]      = data["yieldAccelerateType"]
            _build._houseData["info"]["yieldAccelerateTime"]      = data["yieldAccelerateTime"]
            _build._houseData["info"]["yieldAccelerateEndTime"]   = data["yieldAccelerateEndTime"]
            PlayerData:updateHouseInfo(_build._houseData) --更新建筑信息
            _build:isSpeeding()
        end

        local comfirm = ZCConfirmDialog:createWithParams({
            title = zc.lang("prompt", zc.lang("prompt")),
            showDi = true,
            msg = zc.lang("sure_to_double_in_1day") .. _build:getHouseName() .. zc.getLevelTipShow()..(_build._houseData["level"]) .. zc.lang("dechanliang"),
            rightCallback = function()
                zc.sendHttp({
                    apiName = "House_resourceYieldAccelerate",
                    params = {id = _build._houseData.id, type = 2},
                    successCallback = doSpeeding,
                })
            end
        })  
        comfirm._isRemoveLayout = true
        LayerManager.addNode(comfirm, {isPop = true})
	end

	local _btn = self:getBtnByInfo({
		text = _str_text,
		callback = _call,
        icon = _str_img,
	})
	self._HelpButton = _btn
    self:checkSpeedTimeState(_btn)
	return _btn
end

-- 武神
function HouseEntityPop:getWuTowerBtn()
    if not zc.getFunctionStatus(23) then
        return
    end
	local _btn = self:getBtnByInfo({
        text = zc.lang("cailiao_copy"),
		callback = function () 
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12303 then
                zc.setGuideFuncNextStep(_currentGID)
            end
            zc.showEntityTouchPop()
            zc.createWushenshilian()
        end,
        icon = "home_icon_wushentower.png",
	})
    self._wushenTower = _btn
	return _btn
end

-- 名将
function HouseEntityPop:getMingTowerBtn()
    if not zc.getFunctionStatus(16) then
        return
    end
	local _btn = self:getBtnByInfo({
        text = zc.lang("hero_copy"),
		callback = function () 
            zc.showEntityTouchPop()
            zc.createTollgateHeroMainLayer()
        end,
        icon = "home_icon_tollgatehero.png",
	})
    self._tollgateHeroTower = _btn
	return _btn
end

-- 兵器副本
function HouseEntityPop:getWeaponCopyBtn()
    if not zc.getFunctionStatus(32) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("weapon_copy"),
        callback = function ()
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_13203 then
                zc.setGuideFuncNextStep(_currentGID)
            end
            zc.showEntityTouchPop()
            zc.createWeaponCopy()
        end,
        icon = "home_icon_weaponCopy.png",
    })
    self._weponCopy = _btn
    return _btn
end

--英雄试炼
function HouseEntityPop:getHeroCopyBtn()
    if not zc.getFunctionStatus(50) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("heroCopy_copyName"),
        callback = function ()
            zc.showEntityTouchPop()
            zc.sendHttp({
                apiName = "Hero_CopyMain",
                params = {},
                successCallback = function(data)
                    zc.createSourceScene("HeroCopyPop", "src/layer/heroCopy/HeroCopyPop", {data = data})
                end,
            })
        end,
        icon = "res/Main/copy/heroCopy/home_icon_heroCopy.png",
        plist = false,
    })
    self._HeroCopy = _btn

    return _btn
end

--打造
function HouseEntityPop:getMakeBtn()
    if not zc.getFunctionStatus(49) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = "打造",
        callback = function ()
            zc.showEntityTouchPop()
            zc.sendHttp({
                apiName = "Make_Main",
                params = {type = 1},
                successCallback = function(data)
                    zc.createSourceScene("MakePop", "src/layer/makeUp/MakePop", {data = data})
                end,
            })
        end,
        icon = "res/Main/dazao/dazao.png",
        plist = false,
    })
    self._make = _btn

    return _btn
end

-- 群雄
function HouseEntityPop:getQunTower()
    if not zc.getFunctionStatus(25) then
        return
    end
	local _btn = self:getBtnByInfo({
		text = zc.lang("qunxiong_copy"),
		callback = function () 
            zc.showEntityTouchPop()
            zc.createResearchQunXiong()
        end,
        icon = "home_icon_qunxiong.png",
	})
    self._qunxiong = _btn
	return _btn
end

-- 好友度
function HouseEntityPop:getQinmiBtn()
    if not zc.getFunctionStatus(26) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("qinmidu"),
        callback = function () 
            zc.showEntityTouchPop()
            zc.createTradeFriendshipLayer()
        end,
        icon = "home_icon_friendship.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._qinmi = _btn
    return _btn
end

-- 神兵
function HouseEntityPop:getShenbingBtn()
    local _btn = self:getBtnByInfo({
        text = zc.lang("god_weapon"),
        callback = function () 
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_3008 then
                zc.setGuideFuncNextStep(_currentGID, false)
            end
            zc.showEntityTouchPop()
            zc.createSmithGodWeaponLayer()
        end,
        icon = "home_icon_godWeapon.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._shenbing = _btn
    return _btn
end

-- 洗练
function HouseEntityPop:getSmithyClearBtn()
    if not zc.getFunctionStatus(29) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("smithy_clear"),
        callback = function () 
            zc.showEntityTouchPop()
            zc.createSmithClearLayer()
        end,
        icon = "home_icon_smithyClear.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._smithyClear = _btn
    return _btn
end

-- 熟练度
function HouseEntityPop:getSmithyPracticeBtn()
    if not zc.getFunctionStatus(35) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("proficiency"),
        callback = function () 
            zc.showEntityTouchPop()
            zc.createSmithPracticeLayer()
        end,
        icon = "home_icon_proficiency.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._smithyPractice = _btn
    return _btn
end

-- 兵器谱
function HouseEntityPop:getSmithyBookBtn()
    if not zc.getFunctionStatus(12) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("smithy_book"),
        callback = function () 
            zc.showEntityTouchPop()
            zc.createSmithBookLayer()
        end,
        icon = "home_icon_smithyBook.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._smithyBook = _btn
    return _btn
end

-- 极限挑战副本
function HouseEntityPop:getLimitChallengeCopyBtn()
    if not zc.getFunctionStatus(39) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("limitChallenge"),
        callback = function () 
            zc.showEntityTouchPop()
            zc.createLimitChallengeCopy()
        end,
        icon = "home_icon_limitCopy.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._limitChallenge = _btn
    return _btn
end

-- 地域羁绊
function HouseEntityPop:getFetterRegionalMapBtn()
    -- if APP_SERVER ~= 0 then
    --     return
    -- end
    if not zc.getFunctionStatus(40) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("fetterRegionalMap"),
        callback = function() 
            zc.showEntityTouchPop()
            zc.createRoleFettersRegionalMapLayer()
        end,
        icon = "home_icon_fetterMap.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._fetterRegionalMap = _btn
    return _btn
end

-- 锻造
function HouseEntityPop:getWeaponCastBtn()
    if not zc.getFunctionStatus(42) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("weapon_cast"),
        callback = function() 
            zc.showEntityTouchPop()
            zc.createWeaponCastLayer()
        end,
        icon = "home_icon_weaponCast.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._weaponCastBtn = _btn
    return _btn
end

-- 图鉴
function HouseEntityPop:getGenralManualBtn()
    if not zc.getFunctionStatus(44) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("general_manual"),
        callback = function() 
            zc.showEntityTouchPop()
            zc.createGenralManualLayer()
        end,
        icon = "home_icon_tujian.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._genralManualBtn = _btn
    return _btn
end

-- 武神榜
function HouseEntityPop:getGodFightBtn()
    if not zc.getFunctionStatus(45) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("godfight"),
        callback = function() 
            zc.showEntityTouchPop()
            zc.createGodFightScene()
        end,
        icon = "home_icon_wushenbang.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._godFight = _btn
    return _btn
end

-- 魂祭
function HouseEntityPop:getSoulFeteBtn()
    if not zc.getFunctionStatus(47) then
        return
    end
    local _btn = self:getBtnByInfo({
        text = zc.lang("soulfete"),
        callback = function() 
            zc.showEntityTouchPop()
            zc.createHeroSoulRand()
        end,
        icon = "home_icon_liehun.png",
        insert = false,
    })
    local _size = #self._bottomButtonList
    table.insert(self._bottomButtonList, _size - 1, _btn)
    self._soulFete = _btn
    return _btn
end

-------------------判断functions------------
function HouseEntityPop:getHouseBuildLimit( houseId )
    local _houseDb = gameData.getDataFromCacheWithPrimaryKey("house", houseId)
    local _userLevel = PlayerData:getUserLevel()
    local _limitInfos = string.split(_houseDb.numLimit, ",")
    local _limitNum = 1
    for i=1, #_limitInfos do
        local _info = string.split(_limitInfos[i], "|")
        if tonumber(_info[1]) > _userLevel then
            break
        end
        _limitNum = tonumber(_info[2])
    end

    local _num = 0
    local _houseInfo = PlayerData:getHouseInfo().houses
    for k, v in pairs(_houseInfo) do
        if tonumber(v.houseId) == houseId then
            _num = _num + 1
        end
    end
    _num = _num > _limitNum and _limitNum or _num
    return _num, _limitNum
end


--建筑是否满级
function HouseEntityPop:isBuildingFullFevel(houseId, level)
    local _flag = true
    local _data = gameData.getDataFromCache("house_level", {houseId = houseId})
    if #_data < 1 and next(_data) ~= nil then
        _data = {_data}
    end
    local _level = tonumber(level) or 0
    for k,v in pairs(_data) do
        local __level = tonumber(v.level) or 0
        if __level > _level then
            _flag = false
            break
        end
    end
    return _flag
end

function HouseEntityPop:freshBtnPos( btn, pos )
    if not btn then
        return
    end
    btn:setPosition(pos)
end

---------------------引导---------------------

--新手引导 进入建筑
function HouseEntityPop:enterHouseGuideFunc(_btn)
    getGuideManager():addMaskLayer()
    performWithDelay(self, function()
        getGuideManager():removeMaskLayer()
        local _currentGID = getGuideManager():getCurrentGID()
        if inArray(_currentGID, GuideGroup.BTN_JINRU)
          or _currentGID == GuideKey.KEY_14503
          or _currentGID == GuideKey.KEY_11202
          or _currentGID == GuideKey.KEY_11605
          or _currentGID == GuideKey.KEY_12303
          or _currentGID == GuideKey.KEY_12505
          or _currentGID == GuideKey.KEY_12603
          or _currentGID == GuideKey.KEY_12705
          or _currentGID == GuideKey.KEY_13203
          or _currentGID == GuideKey.KEY_13502
          or _currentGID == GuideKey.KEY_13903
          or _currentGID == GuideKey.KEY_14403
          or _currentGID == GuideKey.KEY_14703
          or _currentGID == GuideKey.KEY_3008
          or _currentGID == GuideKey.KEY_6014
          or _currentGID == GuideKey.KEY_6017
          or _currentGID == GuideKey.KEY_15004
          or _currentGID == GuideKey.KEY_14904
          then
            getGuideManager():setObjTarget(_btn)
            getGuideManager():startGuide()
        elseif _currentGID == GuideKey.KEY_15104 then
            print("阿西吧22".._btn:getPositionX().."--".._btn:getPositionY())
            -- zc.setGuideFuncNextStep(_currentGID)
            getGuideManager():setObjTarget(_btn)
            getGuideManager():startGuide()
        end

    end, 0.3)
end

return HouseEntityPop