--[[
    FileName: BingFaResetPop.lua
    Author: andong
    Date: 2016-04-14
    Purpose: 兵法重置弹窗
]]
local BingFaResetPop = class( "BingFaResetPop", function ()
    return ZCPopLayer:create()
end)
function BingFaResetPop:create(params)
    return BingFaResetPop.new(params)
end
function BingFaResetPop:ctor(params)
    self:initData(params)
    self:initUI()
    self:show()
end
function BingFaResetPop:initData(params)
    self._params = params.info
    self._callback = params.callback
    local levelInfo = gameData.getDataFromCache("book_level", { ["bookId"]=self._params.bookId })
    local advanceInfo = gameData.getDataFromCache("book_advanced_level", { ["bookId"]=self._params.bookId })

    self._spend = {}
    local consumeType1 = 4
    local consumeType2 = 4
    -- 1：升级消耗、2：升阶消耗
    local spendInfo1 = levelInfo[1] or {}
    local spendInfo2 = advanceInfo[1] or {}
    local spendInfoStr1 = spendInfo1.spendNum or ""
    local spendInfoStr2 = spendInfo2.spendNum or ""
    local spendInfoTa1 = string.split(spendInfoStr1, "|")
    local spendInfoTa2 = string.split(spendInfoStr2, "|")
    self._spend[1] = {num=0,mainType=spendInfoTa1[1] or 1,type= spendInfoTa1[2] or 4} --消耗阅历(暂时用木头)
    self._spend[2] = {num=0,mainType=spendInfoTa2[1] or 1,type= spendInfoTa2[2] or 11} --消耗武魂

    for i = 2, tonumber(self._params.level) do
        local consum = string.split(tostring(levelInfo[i].spendNum), "|")
        local consumNum = tonumber(consum[3]) or 0
        if consumNum  > 0 then
            self._spend[1].num = self._spend[1].num + consumNum
        end
    end
    for i = 2, tonumber(self._params.advancedLevel) do
        local consum = string.split(tostring(advanceInfo[i].spendNum), "|")
        local consumNum = tonumber(consum[3]) or 0
        if consumNum  > 0 then
            self._spend[2].num = self._spend[2].num + consumNum
        end
    end
end

function BingFaResetPop:initUI()
    local popBg = zc.getSprite({
        src = "res/Main/common/popBg/popup_Bg_blue.png",
        pos = cc.p(zc.width*0.5, zc.height*0.5)
    })
    self:addContent(popBg)
    self._popBg = popBg
    local popSize = popBg:getContentSize()

    local titleLab = zc.getTipPopTitle( "jinjieyulan" )
    titleLab:setPosition( popSize.width/2, popSize.height - 30 )
    popBg:addChild(titleLab)

    -- 背景
    local middleBg = zc.getScaleNode("res/Main/common/popBg/di_1.png", cc.size(469, 250))
    middleBg:setAnchorPoint(cc.p(0.5,1))
    middleBg:setPosition(popSize.width*0.5, popSize.height-71)
    popBg:addChild(middleBg)

    --item
    local idx = 0
    for i = 1, #self._spend do
        if self._spend[i].num > 0 then
            idx = idx + 1
            local modI = idx <= 4 and (idx-1) or ((idx-1)%4)
            local posX = 52+41+(modI)*120
            local posY = popSize.height-90-41-120*( math.floor((idx-1)/4) )
            
            local item, info= zc.createIconByData({
                data = {
                    mainType = self._spend[i].mainType,
                    type = self._spend[i].type, 
                    id = self._spend[i].id,
                    num = self._spend[i].num,
                }, 
                showDetailPop = true,
                pos = cc.p(posX, posY), 
            })
            item:setScale(82/120)
            popBg:addChild(item)
            local name = zc.createLabel({
                text = info.name,
                outLine = true,
                fontSize = 20,
                ap = cc.p(0.5, 0),
                pos = cc.p(item:getPositionX(), item:getPositionY()-item:getContentSize().height/2-13),
                color = zc.nameColor(info.star),
                pixel = 1.3
            })
            popBg:addChild(name)
        end
    end

    local confirmBtn = zc.createCommomBtn({
        tag = 1,
        text = zc.lang("confirm2"),
        needSwallow = false,
        endCallback = function()
            local function doReset()
                local mainId = self._params.bookId
                zc.sendHttp({
                    apiName = "Captain_reset",
                    params = {id=mainId},
                    successCallback = function (net_data)
                        PlayerData:updataData(net_data)
                        if self._callback and type(self._callback) == "function" then
                            self._callback(net_data)
                        end
                        self:hide()
                    end,
                })
            end
            local tipContent = zc.createSprite()
            local conSize = cc.size(350, 150)
            tipContent:setContentSize(conSize)
            local lab1 = zc.createLabel({
                text = zc.lang("tips_sure_to_reset_bingfa"),
                outLine = true,
                fontSize = 22,
                ap = cc.p(0.5, 0.5),
                pos = cc.p(conSize.width/2, conSize.height/2+20),
                color = display.COLOR_WHITE,
                pixel = 1.3
            })
            tipContent:addChild(lab1)
            
            local lab2 = zc.createLabel({
                text = zc.lang("reset_will_back_all_resource"),
                outLine = true,
                fontSize = 22,
                ap = cc.p(0.5, 0.5),
                pos = cc.p(conSize.width/2, conSize.height/2-20),
                color = display.COLOR_GOLD,
                pixel = 1.3
            })
            tipContent:addChild(lab2)
            

            local comfirm = ZCConfirmDialog:createWithParams({
                title = zc.lang("prompt"),
                rightText = zc.lang("reset_2"),
                showDi = true,
                contentNode = tipContent,
                rightCallback = function()
                    doReset()
                end
            })  
            self:addChild(comfirm, 11)

            local comfirmBtn = comfirm:getRightButton()

            local payInfo = gameData.getDataFromCache("consume_price", {type=9} )
            if not payInfo.price and next(payInfo) then
                payInfo = consume_price[1] or {}
            end
            local gold = zc.createSprite("res/Main/common/common_icon_gold.png")
            gold:setAnchorPoint(0.5, 0.5)
            gold:setPosition(60, comfirmBtn:getContentSize().height+17)
            comfirmBtn:addChild(gold)

            local price = zc.createLabel({
                text = payInfo.price or "",
                outLine = true,
                fontSize = 22,
                ap = cc.p(0, 0.5),
                pos = cc.p(gold:getContentSize().width/2+gold:getPositionX(), gold:getPositionY()),
                pixel = 1.3
            })
            comfirmBtn:addChild(price)
            
        end,
        pos = cc.p(popSize.width/2, 50)
    })
    popBg:addChild(confirmBtn)

end

return BingFaResetPop