--[[
    FileName: SmithyClearLayer.lua
    Author: andong
    Date: 2016-07-06
    Purpose: 兵器洗练界面
]]
local SmithyClearLayer = class( "SmithyClearLayer", function ()
    return zc.createNormalDialog({
        closeCallBack = function()
            local _currentGID = getGuideManager():getCurrentGID()
            if _currentGID == GuideKey.KEY_12910 then
                getGuideManager():setFuncGuideOver()
            end
            LayerManager.removeLayout()
        end
    })
end)
function SmithyClearLayer:create(parmas)
    return SmithyClearLayer.new(parmas)
end
function SmithyClearLayer:ctor(parmas)
    self._removeHeroList = {} --需要清理的武将列表
    self:initData(parmas)
    self:initUI()
end

function SmithyClearLayer:initData(parmas)
    local parmas = parmas or {}
    if parmas.callback then
        self._callback = parmas.callback
    end
    if parmas.id then --目标武将
        self._targetId = parmas.id
    end
    self:refreshHeroInfo()
    self:refreshWeaponInfo()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12903 then
        table.sort(self._heroList or {}, function(a, b)
            if not a or not b then
                return false
            end
    
            if a.heroId == GuideHeroId.KEY_12903 then
                return true
            elseif b.heroId == GuideHeroId.KEY_12903 then
                return false
            end
            return a.heroId < b.heroId
        end)
        self._targetHero = self._heroList[1]
        local mapToHeroList = {}
        for i = 1, #self._heroList do
            local heroId = tonumber(self._heroList[i]["id"])
            mapToHeroList[heroId] = i
        end
        self._mapToHeroList = mapToHeroList
        self:refreshState()
    end
end
--刷新武将信息
function SmithyClearLayer:refreshHeroInfo()
    local mainHeroId = PlayerData["info"]["heroId"]
    local heroListInfo = table.copy(PlayerData:getGeneralInfo())
    local heroList = {}

    local _hasTargetHero = false
    if self._targetHero and self._targetHero["id"] then
        _hasTargetHero = true
    end

    for i = 1,#heroListInfo do
        if tonumber(heroListInfo[i]["id"]) ~= tonumber(mainHeroId) then
            local idx = #heroList+1
            heroList[idx] = table.copy(heroListInfo[i])
            if _hasTargetHero then
                if tonumber(heroListInfo[i]["id"]) == tonumber(self._targetHero["id"]) then
                    self._targetHero = {}
                    self._targetHero = heroList[idx]
                end
            end
        end
    end
    self._heroList = heroList
    table.sort( heroList, function(a, b)
        return tonumber(a.fighting) > tonumber(b.fighting)
    end)
    
    if not _hasTargetHero then
        self._targetHero = {}
        if self._heroList[1] then
            self._targetHero = self._heroList[1]
        end
    end
    local mapToHeroList = {}
    for i = 1, #heroList do
        local heroId = tonumber(heroList[i]["id"])
        mapToHeroList[heroId] = i
        if self._targetId and heroId == tonumber(self._targetId) then
            self._targetId = nil
            self._toTargetHeroIdx = i
            self._heroIdx = heroId
            self._targetHero = nil 
            self._targetHero = heroList[i] --更换目标武将
        end
    end
    self._mapToHeroList = mapToHeroList
end
--刷新所有兵器信息
function SmithyClearLayer:refreshWeaponInfo()
    local weaponInfo = PlayerData:getWeaponsInfo()
    local weaponList = {}
    for i = 1, #weaponInfo do
        if tonumber(weaponInfo[i]["isUser"]) == 0 then
            local heroId = tonumber(weaponInfo[i]["heroId"])
            if heroId > 0 then
                local mapIndx = self._mapToHeroList[heroId]
                if mapIndx then
                    self._heroList[mapIndx]["weaponInfo"] = nil
                    self._heroList[mapIndx]["weaponInfo"] = table.copy(weaponInfo[i])
                end
            else
                local idx = #weaponList+1
                weaponList[idx] = table.copy(weaponInfo[i])
            end
        end
    end

    self._weaponList = weaponList
    if not weaponList or not next(weaponList) then
        if self._tipNoItemLab then
            self._tipNoItemLab:setVisible(true)
        end
    elseif weaponList and next(weaponList) then
        if self._tipNoItemLab then
            self._tipNoItemLab:setVisible(false)
        end
    end
    self:refreshState()
end
--刷新兵器状态
function SmithyClearLayer:refreshState()
   --设置兵器状态（可装备、可洗练）
    local targetWeapon = self._targetHero["weaponInfo"] or {}
    --目标角色兵器类型
    local targetHeroWeaponType = tonumber(self._targetHero["weaponType"]) or 1
    --目标角色等级
    local targetHeroLevel = tonumber(self._targetHero["level"]) or 1
    --目标角色转生等级
    local targetHeroReincarnate = tonumber(self._targetHero["reincarnate"]) or 0
    local targetEffInfo = {}
    for i = 1, 6 do
        if targetWeapon then
            if targetWeapon["effectInfo"..i] and targetWeapon["effectInfo"..i]["effectId"] then
                local _effid = tonumber(targetWeapon["effectInfo"..i]["effectId"])
                local _value = tonumber(targetWeapon["effectValue"..i]) or 0 
                targetEffInfo[_effid] = _value
            end
        end
    end
    for i = 1, #self._weaponList do
        local _v = self._weaponList[i]
        _v["nowState"] = 3 --1表示可洗练、2表示可装备、3无
        if tonumber(_v["type"]) == targetHeroWeaponType then
            if targetWeapon and targetWeapon["weaponId"] then
                _v["nowState"] = 1
                local needReincarnate = tonumber(_v["needReincarnate"]) or 0
                local needLevel = tonumber(_v["needLevel"]) or 0
                if needLevel <= targetHeroLevel and needReincarnate <= targetHeroReincarnate then
                    --基础属性
                    for j = 1, 6 do
                        local _effid = tonumber(_v["effectInfo"..j]["effectId"])
                        local _value = tonumber(_v["effectValue"..j]) or 0 
                        if targetEffInfo[_effid] then
                            if _value > targetEffInfo[_effid] then
                                _v["nowState"] = 2
                                break
                            end
                        end
                    end
                else
                    _v["nowState"] = 3
                end
            else
                --如果需求等级满足,则可装备
                if tonumber(_v["needLevel"]) <= targetHeroLevel and tonumber(_v["needReincarnate"]) <= targetHeroReincarnate then
                    _v["nowState"] = 2
                end
            end
        else
            --如果武将穿戴的有兵器,则可以洗练
            if targetWeapon and targetWeapon["weaponId"] then
                _v["nowState"] = 1
            end
        end
    end
    --兵器排序
    --相同类型排前面
    local targetType = 0
    if self._targetHero and self._targetHero["weaponType"] then
        targetType = tonumber(self._targetHero["weaponType"])
    end
    local _xlTag, _zbTag
    local _currentGID = getGuideManager():getCurrentGID()
    table.sort(self._weaponList,function(a,b)
        if _currentGID >= GuideKey.KEY_12903 and _currentGID <= GuideKey.KEY_12909 then
            if (not _xlTag and a.weaponId == GuideWeaponId.weapone3)
              or _xlTag == a.id then
                _xlTag = a.id
                return true
            end
            if (not _xlTag and b.weaponId == GuideWeaponId.weapone3) 
              or _xlTag == b.id then
                _xlTag = b.id
                return false
            end
            if (not _zbTag and a.weaponId == GuideWeaponId.weapone1) 
              or _zbTag == a.id then
                _zbTag = a.id
                return true
            end 
            if (not _zbTag and b.weaponId == GuideWeaponId.weapone1)
              or _zbTag == b.id then
                _zbTag = b.id
                return false
            end 
        end
        local _aType = tonumber(a.type) == targetType and (tonumber(a.type) + 10000) or tonumber(a.type)
        local _bType = tonumber(b.type) == targetType and (tonumber(b.type) + 10000) or tonumber(b.type)
        if _aType ~= _bType then
            return _aType > _bType
        else
            local _aColor = tonumber(a.color)
            local _bColor = tonumber(b.color)
            if _aColor ~= _bColor then
                return _aColor > _bColor
            else
                return tonumber(a.weaponId) < tonumber(b.weaponId) 
            end
        end
    end)
    dump()
end
function SmithyClearLayer:initUI()
    local bg = zc.createSprite()
    bg:setContentSize( cc.size(1100,550) )
    bg:setPosition(zc.width/2+15, zc.height/2)
    self:addChild(bg, 6)
    self._bg = bg

    local left_bg = zc.createNormalPop({
        srcTag = 3,
        width = 403,
        height = 500+31,
    })
    left_bg:setAnchorPoint(0, 0.5)
    left_bg:setPosition(0, 500/2)
    bg:addChild(left_bg)
    self._left_bg = left_bg

    local right_bg = zc.createNormalPop({
        width = 621+0,
        height = 500+31,
        srcTag = 2,
    })
    right_bg:setAnchorPoint(cc.p(0, 0.5))
    right_bg:setPosition(cc.p(left_bg:getPositionX()+left_bg:getContentSize().width+40, 500/2))
    bg:addChild(right_bg)
    self._infoBg = right_bg

    local _shadowInfobg = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
    _shadowInfobg:setContentSize( cc.size(595, 320) )
    _shadowInfobg:setAnchorPoint( 0.5, 0 )
    _shadowInfobg:setPosition( right_bg:getContentSize().width/2, 134 )
    right_bg:addChild( _shadowInfobg )
    self._shadowInfobg = _shadowInfobg

    local _shadowHeroListbg = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
    _shadowHeroListbg:setContentSize( cc.size(595, 112) )
    _shadowHeroListbg:setAnchorPoint( 0.5, 0 )
    _shadowHeroListbg:setPosition( right_bg:getContentSize().width/2, 12 )
    right_bg:addChild( _shadowHeroListbg )

    self._shadowHeroListbg = _shadowHeroListbg

    -- 顶部
    local _topBg = cc.Sprite:create( "res/Main/role/common/top_bg.jpg" )
    _topBg:setAnchorPoint( 0.5, 1 )
    _topBg:setPosition( cc.p(right_bg:getContentSize().width/2,right_bg:getContentSize().height-5 ) )
    right_bg:addChild( _topBg )
    _topBg:setScaleX( 613/_topBg:getContentSize().width )

    local nameBg = zc.getScaleNode("res/Main/role/common/name_bg.png", cc.size(408,32) )
    nameBg:setPosition(cc.p(_topBg:getContentSize().width/2, _topBg:getContentSize().height/2))
    _topBg:addChild(nameBg)
    self._nameBg = nameBg

    local _spine = zc.getSpine( "jsxxyxg" )
    _spine:setPosition( 155, 200 )
    _spine:playAction( "animation", true )
    _shadowInfobg:addChild( _spine )

    -- 战斗力
    local _fightBg = cc.Sprite:create( "res/Main/role/common/fight_bg.png" )
    _fightBg:setAnchorPoint( 0.5, 0 )
    _fightBg:setPosition( 166, 1 )
    _shadowInfobg:addChild( _fightBg, 2 )
    local _fightNum = zc.createFntLabel({
        fnt = "res/Main/common/fnt/fight_change.fnt",
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 90, _fightBg:getContentSize().height/2 ),
        addwidth = -8,
    })
    _fightNum:setScale( 0.7 )
    _fightBg:addChild( _fightNum )
    self._fightNum = _fightNum

    local nameLab = zc.createLabel({
        outLine = true,
        fontSize = 22,
        ap = cc.p(0.5, 0.5),
        pos = cc.p(51, nameBg:getContentSize().height/2 ),
    })
    nameBg:addChild(nameLab)
    self._heroNameLab = nameLab

    local titleName = zc.createLabel({
        outLine = true,
        fontSize = 22,
        ap = cc.p(0, 0.5),
        pos = cc.p(0, nameLab:getPositionY()),
        color = zc.COLOR_PURPLE,
    })
    nameBg:addChild(titleName)
    self._titleName = titleName

    -- 武器图标
    local _weaponIconBg = cc.Sprite:create( "res/Main/role/common/weapon_icon_bg.png" )
    _weaponIconBg:setAnchorPoint( 0, 0 )
    _weaponIconBg:setPosition( 0, 0 )
    _topBg:addChild( _weaponIconBg ,1)
    local _weaponIcon = cc.Sprite:create()
    _weaponIcon:setPosition( _weaponIconBg:getContentSize().width/2 + 2, -10 )
    _weaponIconBg:addChild( _weaponIcon )
    self._weaponIcon = _weaponIcon

    
    local weaponNameBg = zc.createSprite("res/Main/smithy/clear/weaponNameBg.png")
    weaponNameBg:setAnchorPoint(0.5, 1)
    weaponNameBg:setPosition(_weaponIconBg:getPositionX()+_weaponIconBg:getContentSize().width/2, -30)
    _topBg:addChild(weaponNameBg)

    local weaponName = zc.createLabel({
        outLine = true,
        fontSize = 22,
        ap = cc.p(0.5, 1),
        pos = cc.p(weaponNameBg:getContentSize().width/2, weaponNameBg:getContentSize().height-22),
        pixel = 1.3,
        width = 22,
    })
    weaponNameBg:addChild(weaponName)
    self._weaponName = weaponName
    

    --属性背景
    local base_attr_bg = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
    base_attr_bg:setContentSize( cc.size(293, 120) )
    base_attr_bg:setAnchorPoint( 1, 0 )
    base_attr_bg:setPosition( _shadowInfobg:getContentSize().width-14, 167 )
    _shadowInfobg:addChild( base_attr_bg )
    self._base_attr_bg = base_attr_bg

    local baseAttrBg = zc.createSprite("res/Main/smithy/clear/baseAttrBg.png")
    baseAttrBg:setAnchorPoint(0, 0.5)
    baseAttrBg:setPosition(-2+base_attr_bg:getPositionX()-base_attr_bg:getContentSize().width, base_attr_bg:getPositionY() + base_attr_bg:getContentSize().height+7)
    _shadowInfobg:addChild(baseAttrBg, 10)

    local base_attr_name = zc.createLabel({
        text = zc.lang("base_attribute"),
        outLine = true,
        fontSize = 18,
        ap = cc.p(0, 0.5),
        pos = cc.p(13, baseAttrBg:getContentSize().height/2+2),
        color = cc.c3b(219,212,167),
    })
    baseAttrBg:addChild(base_attr_name)

    local add_attr_bg = ccui.Scale9Sprite:create( cc.rect( 11, 10, 30, 30 ), "res/Main/role/common/shadow_bg.png" )
    add_attr_bg:setContentSize( cc.size(293, 120) )
    add_attr_bg:setAnchorPoint( 1, 0 )
    add_attr_bg:setPosition( _shadowInfobg:getContentSize().width-14, 11 )
    _shadowInfobg:addChild( add_attr_bg )
    self._add_attr_bg = add_attr_bg

    local addAttr = zc.createSprite("res/Main/smithy/clear/addAttr.png")
    addAttr:setAnchorPoint(0, 0.5)
    addAttr:setPosition(-5+add_attr_bg:getPositionX()-add_attr_bg:getContentSize().width, add_attr_bg:getPositionY() + add_attr_bg:getContentSize().height+12)
    _shadowInfobg:addChild(addAttr)

    --
    self:createHeroListTable()

    self:createWeaponListTable()
end
function SmithyClearLayer:createHeroListTable()
    local myTableBg = self._shadowHeroListbg
    local tableSize = myTableBg:getContentSize()
    local myTable = zc.ZCTableView:create( tableSize )
    myTable:setPosition(0,0)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(cc.SCROLLVIEW_DIRECTION_HORIZONTAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(cc.TABLEVIEW_FILL_TOPDOWN)
    
    myTableBg:addChild(myTable)
    
    local function cellSizeForTable(table,idx)
        return tableSize.height, 105
    end
    local function numberOfCellsInTableView(table)
        return #self._heroList
    end
    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(cc.size(105, tableSize.height))
        else
            if self._heroIdx == nowIdx then
                if not tolua.isnull(self._selectImg) then
                    self._selectImg:removeFromParent()
                    self._selectImg = nil
                end
            end
            cell:removeAllChildren()
        end
        self:updateHeroCell(cell, nowIdx)
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    
    myTable:reloadData()
    self._myHeroListTable = myTable
    if self._toTargetHeroIdx then
        myTable:scrollToCell(self._toTargetHeroIdx - 1, false)
        self._toTargetHeroIdx = nil
    end
end
function SmithyClearLayer:updateHeroCell(cell, nowIdx)
    local cellSize = cell:getContentSize()
    local cellData = self._heroList[nowIdx]
    local function refreRightInfo( ... )
        -- body
        if self._weaponTable then
            --刷新左信息
            self._targetHero = cellData
            self:refreshState()
            self._weaponTable:reloadData()
        end
    end
    local heroIcon = zc.createIconByData({
        data = {
            mainType = zc.mainTypeSoldier,
            type = cellData.heroId, 
            id = cellData.heroId,
            quality = 1,
            level = zc.getLevelTipShow()..cellData["level"],
            reincarnate = cellData["reincarnate"],
        },
        quality = cellData.quality,
        showLevel = true,
        pos = cc.p( cellSize.width/2, cellSize.height/2 ), 
        listener = function()
            if self._isPlayingChangeWeaponAction then
                return
            end
            if self._heroIdx == tonumber(cellData["id"]) then
                return
            end
            refreRightInfo()
            self._heroIdx = tonumber(cellData["id"])
            self:createRightHeroInfo(cellData)
            if not tolua.isnull(self._selectImg) then
                self._selectImg:removeFromParent()
                self._selectImg = nil
            end
            local selectImg = zc.getItemClickEffect(2)
            selectImg:setPosition(cc.p(cellSize.width/2, cellSize.height/2))
            cell:addChild(selectImg)
            selectImg:setScale(84/120)
            self._selectImg = selectImg
        end,
    })
    heroIcon:setScale( 84/120 )
    cell:addChild( heroIcon )

    if not self._heroIdx then
        self._heroIdx = tonumber(cellData["id"])
    end
    if not self._secondIn and self._heroIdx == tonumber(cellData["id"]) then
        self:createRightHeroInfo(cellData)
    end
    --选中
    if self._heroIdx == tonumber(cellData["id"]) then
        if not tolua.isnull(self._selectImg) then
            self._selectImg:removeFromParent()
            self._selectImg = nil
        end
        local selectImg = zc.getItemClickEffect(2)
        selectImg:setPosition(cc.p(cellSize.width/2, cellSize.height/2))
        cell:addChild(selectImg)
        selectImg:setScale(84/120)
        self._selectImg = selectImg
    end

end
function SmithyClearLayer:createRightHeroInfo(_heroInfo,_noRefreshHero)
    
    if not _heroInfo then
        return
    end
    local infoBg = self._shadowInfobg

    -- 动画
    if not _noRefreshHero then
        if self._armature then
            self._armature:removeFromParent()
        end
        local _modeId = _heroInfo["modelId"]
        if not self._removeHeroList[_modeId] then
            self._removeHeroList[_modeId] = _modeId
        end
        local armature = zc.battle.createHeroArmature({
            fileName = _heroInfo["modelId"] , 
            async = true, 
            asyncCallback = function ( _armature )
                if not tolua.isnull(infoBg)  then
                    if _armature then
                        _armature:setOpacity(0)
                        _armature:runAction(cc.Sequence:create(cc.FadeIn:create(0.2),cc.CallFunc:create(function()
                            _armature:getAnimation():play("idle", -1, 1)
                        end)))
                        --换兵器
                        if _heroInfo["weaponInfo"] and _heroInfo["weaponInfo"]["weaponId"] then
                            zc.soldierChangeWeapon(_armature, _heroInfo["weaponInfo"]["weaponId"])
                        end
                    end
                end
            end,
        })
        armature:setScaleX( -1.0 )
        local pos = infoBg:convertToWorldSpace(cc.p(149, 100))
        armature:setPosition(cc.p(pos))
        -- infoBg:addChild(armature, 100)
        self:addChild(armature, 100)
        self._armature = armature

        -- 按钮
        if not self._heroBtn then
            local scaleSize = cc.size(120, 150)
            local myScale9 = zc.getScaleNode("res/Main/setting/scale9_1.png", scaleSize)
            local heroBtn = zc.createPushButton({
                touchSize = cc.size( 120, 150 ),
                -- normalNode = myScale9,
                pos = cc.p(  self._armature:getPositionX() , self._armature:getPositionY()+60 ),
                endCallback = function()
                    local _action = zc.random(1, 3)
                    if self._action and self._action == _action then
                        if _action < 3 then
                            _action = _action + 1
                        else 
                           _action = 1 
                        end
                    end
                    self._action = _action
                    local _actions = {"atk3", "atk", "atk0"}
                    self._armature:getAnimation():play( _actions[_action], -1, 0 )
                    self._armature:getAnimation():setMovementEventCallFunc(function(_armature, movementType, movementID)
                        if 1 == tonumber(movementType) then
                            self._armature:getAnimation():play("idle", -1, 1)
                        end
                    end)
                end
            })
            self:addChild( heroBtn )
            self._heroBtn = heroBtn
        end
    end

    local _reincarnate = ""
    if _heroInfo.reincarnate and tonumber(_heroInfo.reincarnate) > 0 then
        _reincarnate = _heroInfo.reincarnate..zc.lang("turn")
    end
    local nameStr = _reincarnate..zc.getLevelTipShow().._heroInfo["level"].." ".._heroInfo["name"]
    local _newAdvance = tonumber(_heroInfo.newAdvance) or 0
    if _newAdvance > 0 then
        nameStr = nameStr .. "+" .. _newAdvance
    end
    self._heroNameLab:setString(nameStr)

    local titleStr = "<".._heroInfo["title"]..">"
    self._titleName:setString(titleStr)
    self._heroNameLab:setPositionX(204-self._titleName:getContentSize().width/2)
    self._titleName:setPositionX(self._heroNameLab:getPositionX()+self._heroNameLab:getContentSize().width/2)

    local powerNum = self._fightNum
    powerNum:setString(_heroInfo.fighting)

    if self._changeFight then
        self._changeFight = false
       zc.numChangeAnimation({
            label = powerNum,
            pos = cc.p( powerNum:getContentSize().width/2, 20 ),
            callback = function()
            end
        })
    end

    local heroTypeImg = zc.getHeroTypeBigImg( _heroInfo["weaponType"] )
    self._weaponIcon:setTexture(heroTypeImg)

    local nameStr = zc.lang("no")
    local nameColor = display.COLOR_WHITE
    if _heroInfo["weaponInfo"] and _heroInfo["weaponInfo"]["name"] then
        nameStr = _heroInfo["weaponInfo"]["name"]
        nameColor = zc.getColorByQuality(_heroInfo["weaponInfo"]["color"])
    end
    self._weaponName:setString(nameStr)
    self._weaponName:setColor(nameColor)

    self:createAttr(_heroInfo)
end
function SmithyClearLayer:createAttr(_heroInfo)
    local base_attr_bg = self._base_attr_bg
    local add_attr_bg = self._add_attr_bg
    base_attr_bg:removeAllChildren()
    add_attr_bg:removeAllChildren()
    if _heroInfo["weaponInfo"] and _heroInfo["weaponInfo"]["type"] then
        local weaponData = _heroInfo["weaponInfo"]
        --组织数据
        local effectInfoList = {}
        local teffectInfoList = {}
        for i = 1, 6 do
            local effectInfo = weaponData["effectInfo"..i]
            if effectInfo and  effectInfo["effectId"] then
                local idx = #effectInfoList + 1
                effectInfoList[idx] = {}
                effectInfoList[idx].effectId    = effectInfo["effectId"]
                local addValue = PlayerData:getSkilfulAddInfoByEffectId(1,tonumber(effectInfo["effectId"]), weaponData.quality)
                effectInfoList[idx].effectValue = weaponData["effectValue"..i] + addValue
            end
        end
        for i = 1, 6 do
            local teffectId = weaponData["teffectId"..i]
            if teffectId and tonumber(teffectId) > 0 then
                local idx = #teffectInfoList + 1
                teffectInfoList[idx] = {}
                teffectInfoList[idx].teffectId    = weaponData["teffectId"..i]
                local addValue = PlayerData:getSkilfulAddInfoByEffectId(2,tonumber(teffectId), weaponData.quality)
                teffectInfoList[idx].teffectValue = weaponData["teffectValue"..i] + addValue
                teffectInfoList[idx].teffectColor = weaponData["teffectColor"..i]
                teffectInfoList[idx].hasChange = false
                if self._changeIdx and self._changeIdx == i then
                    self._changeIdx = nil
                    teffectInfoList[idx].hasChange = true
                end
            end
        end
        table.sort( teffectInfoList, function( a,b )
            local _aColor = tonumber(a.teffectColor)
            local _bColor = tonumber(b.teffectColor)
            if  _aColor ~= _bColor then
                return _aColor > _bColor
            else
                return tonumber(a.teffectId) < tonumber(b.teffectId)
            end
        end)

        local posX_left = base_attr_bg:getContentSize().width/4
        local posX_right = posX_left*3
        local posH = 92

        for i = 1, #effectInfoList do
            local posx = i % 2 == 1 and posX_left or posX_right
            local attrDi = zc.getScaleNode("res/Main/role/trinket/attrDi.png", cc.size(125, 30))
            attrDi:setPosition(cc.p(posx, posH - (math.floor((i-1)/2)*35)))
            base_attr_bg:addChild(attrDi)
            local effectInfo = effectInfoList[i]
            local effectId = effectInfo["effectId"]
            local effectValue = effectInfo["effectValue"] or 0
            local effectStr = LANGUAGE_getAttributeTextById(effectId)
            local effectNum = zc.getAttributeNumById(effectId,effectValue)

            local effectStrLab = zc.createRichLabel({
                text = effectStr.."：",
                fontSize = 20,
            })
            effectStrLab:setAnchorPoint(0, 0.5)
            effectStrLab:setPosition(6, 15)
            effectStrLab:setGradientColor(cc.c4b(244, 159, 8, 255), cc.c4b(255, 255, 124, 255), cc.p(0, -1))
            attrDi:addChild(effectStrLab)

            local effectLab = zc.createLabel({
                text = effectNum,
                stroke = true,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(effectStrLab:getPositionX()+effectStrLab:getContentSize().width, 30/2),
                color = cc.c3b(238,98,3),
                pixel = 1.3
            })
            attrDi:addChild(effectLab)
        end
        
        -- posH = 102
        for i = 1, #teffectInfoList do
            local posx = i % 2 == 1 and posX_left or posX_right
            local attrDi = zc.getScaleNode("res/Main/role/trinket/attrDi.png", cc.size(125, 30))
            attrDi:setPosition(cc.p(posx, posH - (math.floor((i-1)/2)*35)))
            add_attr_bg:addChild(attrDi)
            local teffectInfo = teffectInfoList[i]
            local teffectId     = teffectInfo["teffectId"]
            local teffectValue  = teffectInfo["teffectValue"]
            local teffectColor  = teffectInfo["teffectColor"]
            local effectStr = LANGUAGE_getAttributeTextById(teffectId)
            local effectNum = zc.getAttributeNumById(teffectId,teffectValue)
            local effectLab = zc.createLabel({
                text = effectStr.."："..effectNum,
                stroke = true,
                fontSize = 20,
                ap = cc.p(0, 0.5),
                pos = cc.p(6, 30/2) ,
                color = zc.getColorByQuality(teffectColor),
                pixel = 1.3
            })
            attrDi:addChild(effectLab)
            if teffectInfo["hasChange"] then
                zc.numChangeAnimation({
                    label = effectLab,
                    pos = cc.p( effectLab:getContentSize().width/2, 20 ),
                    callback = function()
                    end
                })
            end
        end
    else
        local noEffect1 = zc.createLabel({
            text = zc.lang("no"),
            stroke = true,
            fontSize = 26,
            ap = cc.p(0, 0.5),
            pos = cc.p(30, 75),
            pixel = 1.3
        })
        base_attr_bg:addChild(noEffect1)
        local noEffect2 = zc.createLabel({
            text = zc.lang("no"),
            stroke = true,
            fontSize = 26,
            ap = cc.p(0, 0.5),
            pos = cc.p(30, 75),
            pixel = 1.3
        })
        add_attr_bg:addChild(noEffect2)
    end
end
--设置属性变化的idx
function SmithyClearLayer:setChangeIdx(_idx)
    self._changeIdx = _idx
end
function SmithyClearLayer:createWeaponListTable()
    local tableSize = cc.size(480, 446)
    local tableNode =  self._bg
    local myTableBg = self._left_bg
    local tableSize = myTableBg:getContentSize()
    local tipNoItemLab = zc.createSprite("res/Main/common/empty.png")
    tipNoItemLab:setPosition(tableSize.width/2, tableSize.height/2)
    myTableBg:addChild(tipNoItemLab)
    tipNoItemLab:setVisible(false)
    self._tipNoItemLab = tipNoItemLab

    if not self._weaponList or not next(self._weaponList) then
        self._tipNoItemLab:setVisible(true)
    end
    
    local myTable = zc.ZCTableView:create(cc.size(myTableBg:getContentSize().width,myTableBg:getContentSize().height-20))
    myTable:setPosition(5,10)
    myTable:setInertia(true) --设置惯性
    myTable:setBounceable(true)
    myTable:setDirection(zctech.SCROLLVIEW_DIRECTION_VERTICAL) --设置横向纵向
    myTable:setDelegate()
    myTable:setVerticalFillOrder(zctech.TABLEVIEW_FILL_TOPDOWN)
    
    myTableBg:addChild(myTable)
    
    local function cellSizeForTable(table,idx)
        return 90, tableSize.width-4
    end
    local function numberOfCellsInTableView(table)
        return math.floor(#self._weaponList+3)/4
    end
    local function tableCellAtIndex(table,idx)
        local nowIdx = idx + 1
        local cell = table:dequeueCell()
        if cell == nil then
            cell = zc.ZCTableViewCell:new()
            cell:setContentSize(cc.size(tableSize.width-4, 90))
            self:createWeaponCell(cell,nowIdx)
        else
            self:updateWeaponCell(cell, nowIdx)
        end
        return cell
    end
    myTable:registerScriptHandler(numberOfCellsInTableView,cc.NUMBER_OF_CELLS_IN_TABLEVIEW)
    myTable:registerScriptHandler(cellSizeForTable,cc.TABLECELL_SIZE_FOR_INDEX)
    myTable:registerScriptHandler(tableCellAtIndex,cc.TABLECELL_SIZE_AT_INDEX)
    
    myTable:reloadData()
    self._weaponTable = myTable
end

function SmithyClearLayer:changeEquipAction(_refresh)
    if tolua.isnull(self._armature) then
        return
    end
    self._armature:getAnimation():play("change",-1,0)
    local function animationEvent(armature,movementType,movementID)
        if movementType == ccs.MovementEventType.complete then
            self._armature:getAnimation():play("idle")
        end
    end
    self._armature:getAnimation():setMovementEventCallFunc(animationEvent)
    local _bone = self._armature:getBone("change")
    if tolua.isnull(_bone) then
        return
    end
    self._armature:getAnimation():setFrameEventCallFunc(function(bone, frameName)
        if frameName == "change" then
            local armature = zc.battle.createBattleEffect({fileName = "change" , actName = "change" , autoRemove = true})
            _bone:addDisplay(armature, 0)
            _bone:changeDisplayWithIndex( 0, true )
            _bone:getDisplayRenderNode():setCascadeOpacityEnabled( false )
            _bone:setOpacity( 255 )
            if _refresh then
                self._changeFight = true
                _refresh()
            end
        end
    end)
end
function SmithyClearLayer:createClearInfoPop(weaponData)
    if self._isPlayingChangeWeaponAction then
        return
    end
    local function doEquip( ... )
        zc.sendHttp({
            apiName = "Weapon_equip",
            params = {
                heroId = self._targetHero["id"],
                weaponId = weaponData.id
            },
            successCallback = function(data) 
                --新手引导
                local _currentGID = getGuideManager():getCurrentGID()
                if _currentGID == GuideKey.KEY_12909 then
                    getGuideManager():guideOver()
                    self._guideXL_btn = nil
                    self._guideZB_btn = nil
                    getGuideManager():addMaskLayer()
                end
                PlayerData:updateWeaponsByHeroIdAndWeaponId(self._targetHero["id"],weaponData.id)
                PlayerData:updateWeaponsInfoById(data.weaponEtt)
                PlayerData:updataData(data)
                PlayerData:setGeneralInfoById(self._targetHero["id"], data.hero)
                musicManager.playEffect( zc.effect.weaponOn )
                -- 刷新总览红点
                zc.dispatchEvent({name = CUSTOM_EVENT.EVENT_ROLELAYER_CHANGE, data = {id = 1}})
                self._isPlayingChangeWeaponAction = true --在播动画的时候，不能点击兵器
                self:changeEquipAction(function()
                    --刷新武将信息
                    self:refreshHeroInfo()
                    if self._weaponTable then
                        --刷新左信息
                        self:refreshWeaponInfo()
                        self._weaponTable:reloadData()
                        self:createRightHeroInfo(self._targetHero, true)
                        --刷新兵器
                        if self._targetHero["weaponInfo"] and self._targetHero["weaponInfo"]["weaponId"] then
                            zc.soldierChangeWeapon(self._armature, self._targetHero["weaponInfo"]["weaponId"])
                        end
                    end
                    self._myHeroListTable:reloadData()
                    self._isPlayingChangeWeaponAction = false
                    local _currentGID = getGuideManager():getCurrentGID()
                    if _currentGID == GuideKey.KEY_12909 then
                        zc.setGuideFuncNextStep(_currentGID)
                        performWithDelay(self, function()
                            getGuideManager():removeMaskLayer()
                            self:addBtnGuide()
                        end, 0.1)
                    end
                end)
            end,
        })
    end
    zc.createSourcePop("SmithyClearInfo", "src/layer/smithyHouse/SmithyClearInfoPop.lua", {
        weaponInfo = weaponData,
        taargetHero = self._targetHero,
        doEquip = doEquip,
    })
end
function SmithyClearLayer:createWeaponCell(cell, nowIdx)
    for i = 1, 4 do
        local idx = (nowIdx-1)*4 + i
        local weaponData = self._weaponList[idx]
        if weaponData and weaponData.color then
            local _level = zc.getWeaponLevel(weaponData.id)
            local item = zc.createIconByData({
                data = {
                    mainType = zc.mainTypeWeapon,
                    type = 1,
                    id = weaponData.weaponId,
                    quality = weaponData.color,
                    grade = weaponData.grade,
                    level = zc.getLevelTipShow().._level, --主键id
                }, 
                -- showDetailPop = true,
                showLevel = true,
                primaryId = weaponData.id,
                pos = cc.p( 55+(i-1)*94, 50), 
                listener = function ()
                    self:createClearInfoPop(weaponData)
                end
            })
            item:setScale(80/120)
            item:setName("item"..i)
            cell:addChild(item)
            cell["item"..i] = item

            local xilian = zc.createSprite("res/Main/role/trinket/can_replace.png")
            xilian:setAnchorPoint(0.5, 0.5)
            xilian:setPosition(item:getPositionX()-15, item:getPositionY()+15)
            cell:addChild(xilian)
            local zhuangbei = zc.createSprite("res/Main/role/trinket/can_equip.png")
            zhuangbei:setAnchorPoint(0.5, 0.5)
            zhuangbei:setPosition(item:getPositionX()-15, item:getPositionY()+15)
            cell:addChild(zhuangbei)
            xilian:setVisible(false)
            zhuangbei:setVisible(false)
            cell["xilian"..i] = xilian
            cell["zhuangbei"..i] = zhuangbei
            if weaponData["nowState"] == 1 then
                xilian:setVisible(true)
                if not self._guideXL_btn and weaponData.weaponId == GuideWeaponId.weapone3 then
                    self._guideXL_btn = item
                end
            elseif weaponData["nowState"] == 2 then
                zhuangbei:setVisible(true)
                if not self._guideZB_btn and weaponData.weaponId == GuideWeaponId.weapone1 then
                    self._guideZB_btn = item
                end
            end
        end
    end   
end
function SmithyClearLayer:updateWeaponCell(cell, nowIdx)
    for i = 1, 4 do
        local idx = (nowIdx-1)*4 + i 
        local weaponData = self._weaponList[idx]
        local item = cell["item"..i]
        local xilian = cell["xilian"..i]
        local zhuangbei = cell["zhuangbei"..i]
        if weaponData and weaponData.color then
            local _level = zc.getWeaponLevel(weaponData.id)
            if item then
                item:setVisible(true)
                local newParmas = {
                    data = {
                        mainType = zc.mainTypeWeapon,
                        type = 1,
                        id = weaponData.weaponId,
                        quality = weaponData.color,
                        grade = weaponData.grade,
                        level = zc.getLevelTipShow().._level, --主键id
                    },
                    -- showDetailPop = true,
                    showLevel = true,
                    primaryId = weaponData.id,
                    pos = cc.p( 55+(i-1)*94, 50), 
                    listener = function ()
                        self:createClearInfoPop(weaponData)
                    end
                }
                zc.updateIconByData(item,newParmas)


                xilian:setVisible(false)
                zhuangbei:setVisible(false)
                if weaponData["nowState"] == 1 then
                    xilian:setVisible(true)
                elseif weaponData["nowState"] == 2 then
                    zhuangbei:setVisible(true)
                end
            else
                local item = zc.createIconByData({
                    data = {
                        mainType = zc.mainTypeWeapon,
                        type = 1,
                        id = weaponData.weaponId,
                        quality = weaponData.color,
                        level = zc.getLevelTipShow().._level, --主键id
                    }, 
                    -- showDetailPop = true,
                    showLevel = true,
                    primaryId = weaponData.id,
                    pos = cc.p( 55+(i-1)*94, 50), 
                    listener = function ()
                        self:createClearInfoPop(weaponData)
                    end
                })
                item:setScale(80/120)
                item:setName("item"..i)
                cell:addChild(item)
                cell["item"..i] = item

                local xilian = zc.createSprite("res/Main/role/trinket/can_replace.png")
                xilian:setAnchorPoint(0.5, 0.5)
                xilian:setPosition(item:getPositionX()-15, item:getPositionY()+15)
                cell:addChild(xilian)
                local zhuangbei = zc.createSprite("res/Main/role/trinket/can_equip.png")
                zhuangbei:setAnchorPoint(0.5, 0.5)
                zhuangbei:setPosition(item:getPositionX()-15, item:getPositionY()+15)
                cell:addChild(zhuangbei)
                xilian:setVisible(false)
                zhuangbei:setVisible(false)
                cell["xilian"..i] = xilian
                cell["zhuangbei"..i] = zhuangbei
                if weaponData["nowState"] == 1 then
                    xilian:setVisible(true)
                elseif weaponData["nowState"] == 2 then
                    zhuangbei:setVisible(true)
                end
            end
            if not self._guideXL_btn and weaponData.weaponId == GuideWeaponId.weapone3 then
                self._guideXL_btn = item
            end
            if not self._guideZB_btn and weaponData.weaponId == GuideWeaponId.weapone1 then
                self._guideZB_btn = item
            end
        else
            if item then
                item:setVisible(false)
            end
            if xilian then
                xilian:setVisible(false)
            end
            if zhuangbei then
                zhuangbei:setVisible(false)
            end
        end
    end
end



function SmithyClearLayer:onCleanup()
    for k,v in pairs(self._removeHeroList) do
        local path = "res/image/battle/hero/" .. v .. ".csb"
        ccs.ArmatureDataManager:getInstance():removeArmatureFileInfo( path )
    end
    if self._callback and type(self._callback) == "function" then
        self._callback()
    end
end
function SmithyClearLayer:onEnter( ... )
    if self._secondIn then
        self:refreshWeaponInfo()
        if self._weaponTable then
            self._weaponTable:reloadData()
        end
        local newGeneral = PlayerData:getGeneralInfoById(self._targetHero["id"])
        if newGeneral["fighting"] and tonumber(newGeneral["fighting"]) > tonumber(self._targetHero["fighting"]) then
            self._targetHero["fighting"] = newGeneral["fighting"]
            self._changeFight = true
        end
        self:createRightHeroInfo(self._targetHero)
    end
    self._secondIn = true
    self:addGuide()
end

function SmithyClearLayer:addGuide()
    local _currentGID = getGuideManager():getCurrentGID()
    if _currentGID == GuideKey.KEY_12903 then
        self:addBtnGuide()
    elseif _currentGID == GuideKey.KEY_12910 then
        getGuideManager():setObjTarget(self._closeBtn)
        getGuideManager():startGuide()
    end
end

function SmithyClearLayer:addBtnGuide()
    if self._guideXL_btn then
        getGuideManager():setCurrentGID(GuideKey.KEY_12904)
        getGuideManager():setObjTarget(self._guideXL_btn)
        getGuideManager():startGuide()
    elseif self._guideZB_btn then
        getGuideManager():setCurrentGID(GuideKey.KEY_12908)
        getGuideManager():setObjTarget(self._guideZB_btn)
        getGuideManager():startGuide()
    else
        getGuideManager():setCurrentGID(GuideKey.KEY_12910)
        self:addGuide()
    end
end

return SmithyClearLayer