--[[
	名将副本关卡界面
	唐实聪
	2016.4.6
]]
local TollgateHeroChapterLayer = class("TollgateHeroChapterLayer", function()
	return ZCDialog:create()
end)

function TollgateHeroChapterLayer:create( params )
	return self.new( params )
end

function TollgateHeroChapterLayer:ctor( params )
	self._exist = true
	self:initData( params )
	self:initUI()
	self:refresh()
	self:refreshChallengeNum()
end

function TollgateHeroChapterLayer:onEnter()
	if self._init then
		local _lastSceneData = PlayerData:getLastSceneData()
		-- dump(_lastSceneData,"_lastSceneData")
		PlayerData:setLastSceneData({})
		if _lastSceneData.lastScene and _lastSceneData.lastScene == "TollgateHero" then
			-- 已挑战次数
		    self._challengeNum = _lastSceneData.challengeNum
		    if _lastSceneData.battleStatus then
		    	-- 赢了刷新
		    	if tonumber( _lastSceneData.chapterId ) == tonumber( self._data.chapterId ) then

			    	local tollgateId = tonumber( _lastSceneData.tollgateId ) or 0
			    	local _flag = false
			    	for i, v in ipairs( self._data.tollgates or {} ) do
			    		local _tollgateId = tonumber( v.tollgateId ) or 0
			    		if _tollgateId == tollgateId then
			    			_flag = true
			    			v.num = 1
			    		end
					end
					if not _flag then
						self._data.tollgates = self._data.tollgates or {}
						self._data.tollgates[#self._data.tollgates + 1] = {
							tollgateId = tollgateId,
							num = 1,
						}
					end
					self:refresh()
			    end
		    end
		    self:refreshChallengeNum()
		end
	else
		self._init = true
	end
	--功能引导 
	local _currentGID = getGuideManager():getCurrentGID()
	if _currentGID == GuideKey.KEY_11608 then
		getGuideManager():addMaskLayer()
        performWithDelay(self, function ()
        	getGuideManager():removeMaskLayer()
	        getGuideManager():setObjTarget(self._guide_btn)
	        getGuideManager():startGuide()
        end, 0.3) 
    end
end

function TollgateHeroChapterLayer:onCleanup()
	self._exist = false
	if self._callback then
		self._callback({
			challengeNum = self._challengeNum,
			data = self._data,
		})
	end
end

function TollgateHeroChapterLayer:initData( params )
	dump( params, "params" )
	self._data = params.data
	self._data.chapterId = self._data.chapterId or self._data.id
	local _db = gameData.getDataFromCacheWithPrimaryKey("hero_chapter", self._data.chapterId)
	self._bgType = tonumber(_db.scene) or 0
	self._list = {}
	for i = 1, 5 do
		self._list[i] = params.list[i]
	end
	-- self._list = params.list
	self._challengeNum = params.challengeNum
	self._challengeNumLimit = params.challengeNumLimit

	if self._bgType == 0 then
		self._pos = {
			cc.p( 203, 302 ),
			cc.p( 409, 365 ),
			cc.p( 540, 226 ),
			cc.p( 629, 478 ),
			cc.p( 771, 325 ),
			cc.p( 913, 450 ),
		}
	else
		self._pos = {
			cc.p( 190, 300 ),
			cc.p( 390, 390 ),
			cc.p( 630, 460 ),
			cc.p( 545, 230 ),
			cc.p( 780, 320 ),
			cc.p( 950, 425 ),
		}
	end

	self._scale = 0.85

	self._hero = {}
	self._heroBtn = {}

	self._size = self:getContentSize()

	self._record = params.record or {}

	self._callback = params.callback
end

function TollgateHeroChapterLayer:initUI()
    -- 云
    zc.getYunDongTai(nil, 3,function(armUp, armDown)
        if not tolua.isnull(self) then
            self:addChild( armUp )
            self:addChild( armDown )
        end
    end)
	-- 标题
	local title = zc.createSprite( "res/Main/tollgateHero/title.png" )
	title:setAnchorPoint( 0, 1 )
	title:setPosition( 0, self._size.height )
	self:addChild( title, 1 )
	-- 关闭按钮
	local close = zc.createTopBackButton({
		-- pos = cc.p( self._size.width - 42, self._size.height - 40 ),
		listener = function ()
			LayerManager.removeLayout()
		end
	})
	self:addChild( close, 1 )

	-- 主场景
	local _file = "res/Main/tollgateHero/mainLand.jpg"
	if self._bgType ~= 0 then
		_file = "res/Main/tollgateHero/newLand" .. self._bgType .. ".jpg"
	end
	local mainLand = zc.createSprite( _file )
	mainLand:setPosition( self._size.width/2, self._size.height/2 )
	self:addChild( mainLand )
	self._mainLand = mainLand
    zc.setBgSize( mainLand )

	-- 箭头
	local arrow = cc.Sprite:create( "res/Main/wushenTower/arrow.png" )
    arrow:setScale( 0.8 )
    mainLand:addChild( arrow, 2 )
    self._arrow = arrow
    arrow:runAction(
    	cc.RepeatForever:create(
	        cc.Sequence:create(
	            cc.MoveBy:create( 0.7, cc.p( 0, 20 ) ),
	            cc.MoveBy:create( 0.7, cc.p( 0, -20 ) )
	        )
        )
    )

    -- 今日可挑战背景
	local challengeBg = cc.Sprite:create( "res/Main/copy/leftTimesBg.png" )
	challengeBg:setPosition( 100, 27 )
	self:addChild( challengeBg )
	-- 今日可挑战文字
	local challengeText = zc.createLabel({
        text = LANGUAGE_TOLLGATEHERO.challenge_times_today..":",
        fontSize = 20,
        ttf = zc.getFont( 1 ),
        stroke = true,
        pixel = 2,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( 30, challengeBg:getContentSize().height/2 ),
	})
	challengeBg:addChild( challengeText )
	-- 今日可挑战数字
	local challengeNum = zc.createLabel({
        fontSize = 23,
        ttf = zc.getFont( 1 ),
        color = display.COLOR_GREEN,
        outLine = true,
        pixel = 1.5,
        ap = cc.p( 0, 0.5 ),
        pos = cc.p( challengeText:getPositionX() + challengeText:getContentSize().width + 7, challengeText:getPositionY() - 2 ),
	})
	challengeBg:addChild( challengeNum )
	self._challenge = challengeNum


	-- 英雄
	for i, v in ipairs( self._list ) do
		local heroBtn = zc.createPushButton({
        	touchSize = cc.size( 90, 125 ),
        	pos = cc.p( self._pos[i].x, self._pos[i].y + 60 ),
			endCallback = function()
				local passData = {}
				for j, u in ipairs( self._data.tollgates or {} ) do
					passData[tostring( u.tollgateId )] = u.num
				end
				v.open = false
				v.first = true
				v.times = 0
				if passData[tostring( v.id )] then
					-- 已经打过了
					v.open = true
					v.first = false
					v.times = passData[tostring( v.id )] or 0
				elseif v.activateId and ( ( tonumber( v.activateId ) ~= 0 and passData[tostring( v.activateId )] ) or tonumber( v.activateId ) == 0 ) then
					-- 首杀
					v.open = true
					v.first = true
					v.times = 0
				else
					-- 没打过
					v.open = false
					v.first = false
					v.times = 0
				end
				-- 挑战次数
				if self._challengeNum < self._challengeNumLimit then
					v.challengable = true
				else
					v.challengable = false
				end
				-- 体力
				local _energy = tonumber( v.expend ) or 0
				local _myEnergy = tonumber( PlayerData.resourcesInfo.energy ) or 0
				if _energy > _myEnergy then
					v.energyEnable = false
				else
					v.energyEnable = true
				end
				--功能引导结束
		    	local _currentGID = getGuideManager():getCurrentGID()
		    	if _currentGID == GuideKey.KEY_11608 then
			        zc.setGuideFuncNextStep(_currentGID)
			    end

				-- 挑战次数限制，测试用
				-- v.challengable = true
				v.chapterId = self._data.chapterId
				zc.createSourcePop( "TollgateHeroEnemy", "src/layer/tollgateHero/TollgateHeroEnemyPop.lua", v )
			end
		})
		self._mainLand:addChild( heroBtn )
		self._heroBtn[i] = heroBtn
		heroBtn:setContentSize( 90, 125 )
		--功能引导
		if i == 1 then
			local passData = {}
			for j, u in ipairs( self._data.tollgates or {} ) do
				passData[tostring( u.tollgateId )] = u.num
			end
			v.open = false
			v.first = true
			v.times = 0
			if passData[tostring( v.id )] then
				-- 已经打过了
				v.open = true
				v.first = false
				v.times = passData[tostring( v.id )] or 0
			else
				self._guide_btn = heroBtn
			end
		end
	end
	-- 箱子
    local armature = zc.getSpine("missionbox")
    armature:playAction("box3_lock", true)
    armature:setPosition( self._pos[#self._pos] )
	self._mainLand:addChild( armature )
    self._box = armature
	local boxBtn = zc.createPushButton({
		touchSize = cc.size( 80, 80 ),
		ap = cc.p( 0.5, 0 ),
		pos = cc.p( self._pos[#self._pos] ),
		endCallback = function()
			local fetchable = false
			if self._data.tollgates and #self._data.tollgates == #self._list then
				fetchable = true
			end
			local fetched = false
			if tonumber( self._data.drawPass ) == 1 then
				fetched = true
			end
			if fetchable and not fetched then
				-- 奖励领取弹窗
				zc.sendHttp({
					apiName = "TollgateHero_drawReward",
					params = {chapterId = self._data.chapterId},
					successCallback = function( data )
		                data.callback = function()
		                	local armature = zc.createArmature({
								parentPath = "res/animation/zhangjietongguan/",
			            		fileName = "zhangjietongguan",
			            		actName = "idle",
			            		completeCallback = function()
						        end
					        })
					        armature:setPosition( self._size.width/2, self._size.height/2 )
					        self:addChild( armature, 2 )
					        local armatureLayer = zc.createPushButton({
					        	touchSize = self._size,
					        	pos = cc.p( self._size.width/2, self._size.height/2 ),
					        	endCallback = function()
					        		LayerManager.removeLayout()
					        	end
				        	})
				        	self:addChild( armatureLayer, 2 )
		                end
		                zc.createShowReward(data)
		                data.noAnimation = true
		                PlayerData:updataData(data)
		                self._data.drawPass = 1
		                self:refresh()
		                self:refreshChallengeNum()
	            	end,
	            })
			else
				-- 奖励预览弹窗
				zc.createSourcePop( "TollgateHeroRewardPreviewPop", "src/layer/tollgateHero/TollgateHeroRewardPreviewPop.lua", {
					chapterId = self._data.chapterId,
					drawPass = self._data.drawPass or 0,
					fetchable = fetchable,
				})
			end
		end
	})
	self._mainLand:addChild( boxBtn )
	self._boxBtn = boxBtn
end
-- 刷新函数
function TollgateHeroChapterLayer:refresh()
	local nextIndex = 6
	-- 通关数据
	local passData = {}
	for i, v in ipairs( self._data.tollgates or {} ) do
		passData[tostring( v.tollgateId )] = true
	end
	for i, v in ipairs( self._list ) do
		if not passData[tostring( v.id )] then
			nextIndex = nextIndex <= i and nextIndex or i
		end
	end
	-- 箭头
	if nextIndex == 6 and tonumber( self._data.drawPass or 0 ) == 1  then
		self._arrow:setVisible( false )
	else
		self._arrow:setVisible( true ) 
	end
	self._arrow:setPosition( self._pos[nextIndex].x, self._pos[nextIndex].y + 170 )
	-- 武将显示
	for i = 1, nextIndex > 5 and 5 or nextIndex do
		if self._hero[i] then
			self._hero[i]:setVisible( true )
		else
			local modelId = gameData.getDataFromCacheWithPrimaryKey("hero", self._list[i].icon).modelId
			zc.createArmature({
				fileName = modelId,
				actName = "idle",
				loop = true,
				async = true,
				asyncCallback = function()
					if self._exist then
						local armature = ccs.Armature:create( modelId )
						self._record[modelId] = true
				        armature:setPosition( self._pos[i] )
				        armature:setScale( self._scale )
				        armature:getAnimation():play( "idle" )
						self._mainLand:addChild( armature )
						self._hero[i] = armature
					end
				end
			})
		end
		self._heroBtn[i]:setEnable( true )
	end
	for i = nextIndex + 1, 5 do
		if self._hero[i] then
			self._hero[i]:setVisible( false )
		end
		self._heroBtn[i]:setEnable( false )
	end
	-- 箱子，能否预览
	if nextIndex < 6 then
		-- 不可领取
		self._box:playAction("box3_lock", true)
	elseif nextIndex == 6 and tonumber( self._data.drawPass or 0 ) == 0 then
		-- 可领取
		self._box:playAction("box3_closer", true)
	elseif nextIndex == 6 and tonumber( self._data.drawPass or 0 ) == 1 then
		-- 已领取
		self._box:playAction("box3_open", true)
	end
end

function TollgateHeroChapterLayer:refreshChallengeNum()
	-- 挑战次数
	local leftTimes = tonumber( self._challengeNumLimit ) - tonumber( self._challengeNum )
	leftTimes = leftTimes > 0 and leftTimes or 0
	self._challenge:setText( leftTimes.."/"..self._challengeNumLimit )
end

return TollgateHeroChapterLayer